import { OnDestroy, OnChanges, SimpleChanges, EventEmitter } from '@angular/core';
import { Component } from '../models/index';
import { ComponentService } from './component.service';
/**
 * The Component Directive provides access to a specific Component model including
 * the configuration of its properties and access to its ports.
 *
 * @example
 * <div [arComponent]="'DCE:...'" [(arModel)]="my_model">
 */
export declare class ComponentDirective implements OnDestroy, OnChanges {
    service: ComponentService;
    /**
     * Sets the ID for the underlying service
     */
    componentId: string;
    /** Setter for "Banana in a Box Syntax"  */
    model: Component;
    /** Emitter for "Banana in a Box Syntax"  */
    modelChange: EventEmitter<Component>;
    /** Internal subscription for the model */
    private subscription;
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    constructor(service: ComponentService);
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    ngOnDestroy(): void;
}
