import { HttpClient } from '@angular/common/http';
import { Observable, Subscription } from 'rxjs';
import { Component, PropertySet } from '../models/index';
import { PortBearingService } from '../base/index';
import { RestPythonService } from '../rest-python/rest-python.module';
import { WaveformService } from '../waveform/waveform.module';
/**
 * The Component Service provides the service interface to a specific Component
 * model in a REDHAWK system.
 */
export declare class ComponentService extends PortBearingService<Component> {
    protected http: HttpClient;
    protected restPython: RestPythonService;
    protected waveformService: WaveformService;
    waveformConfigSub: Subscription;
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param waveformService The Waveform service that has this Component in it
     */
    constructor(http: HttpClient, restPython: RestPythonService, waveformService: WaveformService);
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    setBaseUrl(url: string): void;
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    uniqueQuery$(): Observable<Component>;
    /**
     * Calls 'configure' on the Component and then pulls an update of the model.
     * @param properties The properties to 'configure' on the Component
     * @param delayResponseMs The optional model update delay after sending the
     * changes.
     */
    configure$(properties: PropertySet, delayResponseMs?: number): Observable<any>;
    cleanUp(): void;
}
