import { OnDestroy, OnChanges, SimpleChanges, EventEmitter } from '@angular/core';
import { Device } from '../models/index';
import { DeviceService } from './device.service';
/**
 * The Device Directive provides access to a specific Device model including
 * the configuration, allocation, and deallocation of its properties and access
 * to its ports.
 *
 * @example
 * <div [arDevice]="'DCE:...'" [(arModel)]="my_model">
 */
export declare class DeviceDirective implements OnDestroy, OnChanges {
    service: DeviceService;
    /**
     * Sets the ID for the underlying service
     */
    deviceId: string;
    /** Setter for "Banana in a Box Syntax"  */
    model: Device;
    /** Emitter for "Banana in a Box Syntax"  */
    modelChange: EventEmitter<Device>;
    /** Internal subscription for the model */
    private subscription;
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    constructor(service: DeviceService);
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    ngOnDestroy(): void;
}
