import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { PropertySet, Device } from '../models/index';
import { PortBearingService } from '../base/index';
import { RestPythonService } from '../rest-python/rest-python.module';
import { DeviceManagerService } from '../devicemanager/device-manager.module';
import { IDevicePropertyCommandResponse } from './device-property-command-response';
/**
 * The Device Service provides access to the Device Model on the REST server as well as
 * serves as methods for controlling it and its ports and properties.
 */
export declare class DeviceService extends PortBearingService<Device> {
    protected http: HttpClient;
    protected restPython: RestPythonService;
    protected dmService: DeviceManagerService;
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param dmService The DeviceManager service that has this Device in it
     */
    constructor(http: HttpClient, restPython: RestPythonService, dmService: DeviceManagerService);
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    setBaseUrl(url: string): void;
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    uniqueQuery$(): Observable<Device>;
    /**
     * Calls 'configure' on the Device and then pulls an update of the model.
     * @param properties The properties to 'configure' on the Device
     * @param responseDelayMs The optional model update delay after sending the
     * changes.
     */
    configure$(properties: PropertySet, responseDelayMs?: number): Observable<IDevicePropertyCommandResponse>;
    /**
     * Calls 'allocate' on the Device and then pulls an update of the model.
     * @param properties The properties to 'allocate' on the Device
     * @param responseDelayMs The optional model update delay after sending the
     * changes.
     */
    allocate$(properties: PropertySet, responseDelayMs?: number): Observable<IDevicePropertyCommandResponse>;
    /**
     * Calls 'deallocate' on the Device and then pulls an update of the model.
     * @param properties The properties to 'deallocate' on the Device
     * @param responseDelayMs The optional model update delay after sending the
     * changes (default is 5000 Ms)
     */
    deallocate$(properties: PropertySet, responseDelayMs?: number): Observable<IDevicePropertyCommandResponse>;
}
