import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { DeviceManager, ResourceRefs, Device } from '../models/index';
import { RestPythonService } from '../rest-python/rest-python.module';
import { DomainService } from '../domain/domain.module';
import { BaseService } from '../base/index';
/**
 * The DeviceManagerService provides access to methods for retrieving the DeviceManager model
 * as well as models of its devices and services.
 */
export declare class DeviceManagerService extends BaseService<DeviceManager> {
    protected http: HttpClient;
    protected restPython: RestPythonService;
    protected domainService: DomainService;
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param domainService The Domain service that has this DeviceManager in it
     */
    constructor(http: HttpClient, restPython: RestPythonService, domainService: DomainService);
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    setBaseUrl(url: string): void;
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @returns Observable DeviceManager
     */
    uniqueQuery$(): Observable<DeviceManager>;
    /**
     * Retrieve a specific device or a list of devices in the Device Manager
     * @param [deviceId] The Device model to fetch.  If none, a list is returned.
     * @returns Observable Device or ResourceRefs
     */
    devs$(deviceId?: string): Observable<Device> | Observable<ResourceRefs>;
    /**
     * Retrieve a specific service model or list of services in the Device Manager
     * **Note:** Services are not fully supported at this time.
     *
     * @param [serviceId] The Service model to fetch.  If none, a list is returned.
     * @returns Observable any or list of anys.
     */
    services$(serviceId?: string): Observable<any> | Observable<any[]>;
}
