import { OnDestroy, OnChanges, SimpleChanges, EventEmitter } from '@angular/core';
import { Domain } from '../models/index';
import { DomainService } from './domain.service';
/**
 * The Domain Directive provides access to a specific Domain model
 *
 * @example
 * <div [arDomain]="'DCE:...'" [(arModel)]="my_model">
 */
export declare class DomainDirective implements OnDestroy, OnChanges {
    service: DomainService;
    /**
     * Sets the ID for the underlying service
     */
    domainId: string;
    /** Setter for "Banana in a Box Syntax"  */
    model: Domain;
    /** Emitter for "Banana in a Box Syntax"  */
    modelChange: EventEmitter<Domain>;
    /** Internal subscription for the model */
    private subscription;
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    constructor(service: DomainService);
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    ngOnDestroy(): void;
}
