import { ISerializable } from '../../serialization/index';
import { ISimpleProperty, ISimpleProperties } from './simple-property';
/**
 * REDHAWK Message Events are simplified Struct properties that only convey
 * ID-Value combinations with the struct's value being a list of ID-Value
 * pairs we're calling ISimpleProperties.
 */
export declare class RhMessage implements ISerializable<RhMessage> {
    /** ID of the related property defining the message */
    id: string;
    /** the fields of this message */
    value: ISimpleProperties;
    /** Deserializes a JSON object into a REDHAWK Message format */
    deserialize(input: any): this;
    /**
     * Get the field IDs of the structure
     * @return {string[]} List of field IDs in this structure
     */
    getFields(): string[];
    /**
     * Helper function to get individual fields from the struct's list of fields.
     * @param {string} id The ID of the field/member to return
     */
    field(id: string): ISimpleProperty;
    /**
     * Convenience method for taking structures that have a 'value' that is a list
     * of id-value pairs like RhMessage and turning them into a 'normal' object
     * whose members are created using the de-namespaced 'id'.
     *
     * For example, an id of TestMessage::something on a field results in an object
     * with a 'something' member set to that field's value.
     * @return A populated Object from this message's members.
     */
    asObject<T>(): T;
}
