import { ISerializable } from '../serialization/index';
import { Property } from './property';
import { StructValueType } from './struct-value-type';
import { ScaStructType } from './sca-types';
import { SimpleProperty } from './simple-property';
import { SimpleSeqProperty } from './simple-seq-property';
/**
 * Serializable REDHAWK 'struct' Property Model
 */
export declare class StructProperty extends Property implements ISerializable<StructProperty> {
    /** The value (fields listing) of the structure */
    value: StructValueType;
    /** The SCA Type of the property ('struct') */
    scaType: ScaStructType;
    /**
     * Get the structure's fields (members) IDs.
     * @return {string[]} List of field IDs in this structure
     */
    getFields(): string[];
    /**
     * Helper function to get individual fields from the struct's list of fields.
     * @param {string} id The ID of the field/member to return
     */
    field(id: string): SimpleProperty | SimpleSeqProperty;
    /** Deserializes a JSON object into this class */
    deserialize(input: any): this;
    /**
     * Create a copy of the property
     */
    copy(): StructProperty;
    /**
     * Convenience method for taking structures that have a 'value' that is a list
     * of id-value pairs like StructProperty and turning them into a 'normal' object
     * whose members are created using the de-namespaced 'id'.
     *
     * For example, an id of TestMessage::something on a field results in an object
     * with a 'something' member set to that field's value.
     * @return A populated Object from this message's members.
     */
    asObject<T>(): T;
}
