import { ISerializable } from '../serialization/index';
import * as prop from '../property/index';
import * as port from '../port/index';
import { ResourceRef } from './resource-ref';
/**
 * Base class for Resource subclasses (Device, Component) that represents the
 * actual server-side model (properties, etc.).
 */
export declare class Resource extends ResourceRef implements ISerializable<Resource> {
    /** Indicates if the resource is started */
    started: boolean;
    /** Property listing of the resource */
    properties: prop.PropertySet;
    /** Port listing of the resource */
    ports: port.Ports;
    /** Constructor */
    constructor();
    /**
     * Iterates over the 'properties' list to return the property matching the ID
     * @param id The ID of the property to return
     * @returns {prop.Property} The Property model (or undefined if invalid).
     */
    property(id: string): prop.Property;
    /**
     * Iterates over the 'ports' list to return the port maching the ID (name)
     * @param id The unique identifier of the port (i.e., its name).
     * @returns {port.Port} The Port model (or undefined if invalid)
     */
    getPort(id: string): port.Port;
    /** Deserializes a JSON object into this class */
    deserialize(input: any): this;
}
