import { OnDestroy, OnChanges, SimpleChanges, EventEmitter } from '@angular/core';
import { Port } from '../models/index';
import { PortService } from './port.service';
/**
 * The Port directive provides access to the variety of port types in REDHAWK.
 * Port-specific features can be accessed through the 'service'.
 *
 * @example
 * <div [arPort]="'dataShort_out'" [(arModel)]="my_model">
 */
export declare class PortDirective implements OnDestroy, OnChanges {
    service: PortService;
    /**
     * Sets the ID for the underlying service
     */
    portId: string;
    /** Setter for "Banana in a Box Syntax"  */
    model: Port;
    /** Emitter for "Banana in a Box Syntax"  */
    modelChange: EventEmitter<Port>;
    /** Internal subscription for the model */
    private subscription;
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    constructor(service: PortService);
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    ngOnDestroy(): void;
}
