import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Port } from '../models/index';
import { RestPythonService } from '../rest-python/rest-python.module';
import { WaveformService } from '../waveform/waveform.module';
import { DeviceService } from '../device/device.module';
import { ComponentService } from '../component/component.module';
import { BaseService } from '../base/index';
import { PortRef } from './refs/index';
/**
 * The Port Service provides unique interfaces to different types of ports
 * through the 'ref' member.  That member is a sub-service which may
 * include REST callbacks for FEI ports vs. websocket controls for BULKIO.
 */
export declare class PortService extends BaseService<Port> {
    protected http: HttpClient;
    protected restPython: RestPythonService;
    /** Reference to the parent service */
    protected parent: WaveformService | DeviceService | ComponentService;
    /** The internal port "reference" controller */
    private _ref;
    /** Cached previous Unique ID for managing a change in the ref */
    private _previousUniqueId;
    /**
     * Flag for tracking upstream URI changes that impact the port
     * if its unique ID does not appear to change.
     */
    private _forceReconfigRef;
    /**
     * Constructor
     * **NOTE:** One of _wave, _device, or _component must be provided!
     *
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param [_wave] The Waveform service that has this Port in it
     * @param [_device] The Device service that has this Port in it
     * @param [_component] The Component service that has this Port in it
     */
    constructor(http: HttpClient, restPython: RestPythonService, _wave: WaveformService, _device: DeviceService, _component: ComponentService);
    /**
     * The port's sub-reference interfaces.  For BulkIO, this will be a
     * BulkioRef giving connectPort and disconnectPort.  For FEI, these will
     * be interfaces that look like those defined in the associated IDL.
     *
     * Use model.hasBulkioWebsocket to determine if this is a BulkioRef.
     * Use model.isFEIControllable to determine if this is one of the FEI Refs.
     *
     * Then use model.idl.type to determine the sub-type (either the data type
     * of the BulkioRef, or the FeiXXXXRef ref type).
     */
    readonly ref: PortRef;
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    setBaseUrl(url: string): void;
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    uniqueQuery$(): Observable<Port>;
    /**
     * Scans the model to determine the type of 'ref' to create for any subfeatures.
     * @param model The new Port model from the recent refresh
     */
    modelUpdated(model: Port): void;
}
