import { OnInit, OnDestroy, EventEmitter } from '@angular/core';
import { Redhawk } from '../models/index';
import { RedhawkService } from './redhawk.service';
/**
 * The REDHAWK Directive is the entry point, top-level directive for dependency
 * injection when accessing the REST services for a REDHAWK Domain.
 *
 * @example
 * <div arRedhawk [(arModel)]="my_model">
 */
export declare class RedhawkDirective implements OnInit, OnDestroy {
    service: RedhawkService;
    /** The name to apply to the REDHAWK Service */
    serviceName: string;
    /** Setter for "Banana in a Box Syntax"  */
    model: Redhawk;
    /** Emitter for "Banana in a Box Syntax" */
    modelChange: EventEmitter<Redhawk>;
    /** Internal subscription for the model */
    private subscription;
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    constructor(service: RedhawkService);
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    ngOnInit(): void;
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    ngOnDestroy(): void;
}
