import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Domain, Redhawk } from '../models/index';
import { RestPythonService } from '../rest-python/rest-python.module';
import { BaseService } from '../base/index';
import { RedhawkListenerService } from '../sockets/sockets.module';
/**
 * The REDHAWK Service provides access to the REDHAWK Model on the REST server as well as
 * serves as the starting point for the Depenency Injection (DI) hierarchy of other services
 * such as {@link DomainService}, {@link DeviceManagerService}, and so on.
 */
export declare class RedhawkService extends BaseService<Redhawk> {
    protected http: HttpClient;
    protected restPython: RestPythonService;
    protected rhListenerService: RedhawkListenerService;
    /**
     * Constructor
     * @param http The HTTP service for REST calls
     * @param restPython The REST Python URL service
     * @param rhListenerService The REDHAWK (Domain) Listener Service
     */
    constructor(http: HttpClient, restPython: RestPythonService, rhListenerService: RedhawkListenerService);
    /**
     * Internal, sets up the base URL
     * @param url IGNORED
     */
    setBaseUrl(url: string): void;
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    uniqueQuery$(): Observable<Redhawk>;
    /** Get a list of online domain names */
    scan$(): Observable<string[]>;
    /**
     * Retrieves a Domain model
     * @param domainId The Domain model to fetch (this corresponds to the Domain's "name")
     */
    attach$(domainId: string): Observable<Domain>;
    /** Get a list of online Event Channels */
    scanChannels$(): Observable<string[]>;
}
