import { Observable } from 'rxjs';
import { OdmEvent, IdmEvent, RhMessage } from '../../../models/index';
import { RestPythonService } from '../../../rest-python/rest-python.module';
/**
 * The EventChannelService is a basic event channel interface.  You can
 * subscribe to any channel (WebSocket topics) based on domain ID.
 */
export declare class EventChannelService {
    /** All events and "send" interface */
    private socketInterface;
    /**
     * All events coming from this web socket
     */
    readonly events$: Observable<OdmEvent | IdmEvent | RhMessage>;
    /**
     * Connects to the named event channel per the provided domain ID
     * @param {string} domainId The Domain ID for the event channel
     * @param {string} channelName The event channel to listen to
     */
    connect(domainId: string, channelName: string): void;
    /**
     * Disconnects from the named event channel per the provided domain ID
     * @param {string} domainId The Domain ID for the event channel
     * @param {string} channelName The event channel to stop listening to
     */
    disconnect(domainId: string, channelName: string): void;
    /**
     * FUTURE USE
     * @param payload The object to send across the socket.
     */
    send(payload: Object): void;
    /**
     * Constructor
     * @param restPython The REST Python service for mapping to the socket interface
     */
    constructor(restPython: RestPythonService);
}
