import { Observable } from 'rxjs';
import { IdmEvent, UsageStateEvent, AdministrativeStateEvent, OperationalStateEvent, AbnormalComponentTerminationEvent } from '../../../models/index';
import { EventChannelService } from '../generic/index';
/**
 * Provides an instantiation of the IDM Listener Service
 * @param ecs An EventChannelService instance to utilize
 */
export declare function configureIdmListenerService(ecs: EventChannelService): IdmListenerService;
/**
 * Returns providers for a pre-configured ODM Listener Service
 */
export declare function idmListenerServiceProvider(): any;
/**
 * The IdmListenerService is similar to the IDMListener in the REDHAWK sandbox.
 */
export declare class IdmListenerService {
    private eventChannel;
    /**
     * Observable for all possible events on the IDM Channel
     */
    readonly allEvents$: Observable<IdmEvent>;
    /**
     * Observable for specifically Administrative State Changed events.
     */
    readonly administrativeStateChanged$: Observable<AdministrativeStateEvent>;
    /**
     * Observable for specifically Operational State Changed events.
     */
    readonly operationalStateChanged$: Observable<OperationalStateEvent>;
    /**
     * Observable for specifically Usage State Changed events.
     */
    readonly usageStateChanged$: Observable<UsageStateEvent>;
    /**
     * Observable for specifically Abnormal Component Termination Changed events.
     */
    readonly abnormalComponentTerminationChanged$: Observable<AbnormalComponentTerminationEvent>;
    /** All events */
    private allEvents;
    /** Administrative state events */
    private administrativeStateChanged;
    /** Operational state events */
    private operationalStateChanged;
    /** Usage State events */
    private usageStateChanged;
    /** Abnormal termination events */
    private abnormalComponentTerminationChanged;
    /**
     * Connect to a Domain's IDM Event Channel
     * @param domainId The Domain ID (Name)
     */
    connect(domainId: string): void;
    /**
     * Disconnect from a Domain's IDM Event Channel
     * @param domainId The Domain ID (Name)
     */
    disconnect(domainId: string): void;
    /**
     * Constructor
     * @param eventChannel The Event Channel (Service) to use for connections
     */
    constructor(eventChannel: EventChannelService);
}
