import { Provider } from '@angular/core';
import { Observable } from 'rxjs';
import { OdmEvent, DomainManagementObjectAddedEvent, DomainManagementObjectRemovedEvent } from '../../../models/index';
import { EventChannelService } from '../generic/index';
/**
 * The ODM Event Channel name
 */
export declare const ODM_CHANNEL_NAME: string;
/**
 * Provides an instantiation of the ODM Listener Service
 * @param ecs An EventChannelService instance to utilize
 */
export declare function configureOdmListenerService(ecs: EventChannelService): OdmListenerService;
/**
 * Returns providers for a pre-configured ODM Listener Service
 */
export declare function odmListenerServiceProvider(): Provider[];
/**
 * The OdmListenerService is similar to the ODMListener in the REDHAWK sandbox.
 */
export declare class OdmListenerService {
    private eventChannel;
    /**
     * Obsevable for all possible events on the ODM Event Channel
     */
    readonly allEvents$: Observable<OdmEvent>;
    /**
     * Observable for specifically Device Manager Added events.
     */
    readonly deviceManagerAdded$: Observable<DomainManagementObjectAddedEvent>;
    /**
     * Observable for specifically DeviceManager Removed events.
     */
    readonly deviceManagerRemoved$: Observable<DomainManagementObjectRemovedEvent>;
    /**
     * Observable for specifically Device Added events.
     */
    readonly deviceAdded$: Observable<DomainManagementObjectAddedEvent>;
    /**
     * Observable for specifically Device Removed events.
     */
    readonly deviceRemoved$: Observable<DomainManagementObjectRemovedEvent>;
    /**
     * Observable for specifically Application Factory Added events.
     */
    readonly applicationFactoryAdded$: Observable<DomainManagementObjectAddedEvent>;
    /**
     * Observable for specifically Application Factory Removed events.
     */
    readonly applicationFactoryRemoved$: Observable<DomainManagementObjectRemovedEvent>;
    /**
     * Observable for specifically Application Added events.
     */
    readonly applicationAdded$: Observable<DomainManagementObjectAddedEvent>;
    /**
     * Observable for specifically Application Removed events.
     */
    readonly applicationRemoved$: Observable<DomainManagementObjectRemovedEvent>;
    /**
     * Observable for specifically Service Added events.
     */
    readonly serviceAdded$: Observable<DomainManagementObjectAddedEvent>;
    /**
     * Observable for specifically Service Removed events.
     */
    readonly serviceRemoved$: Observable<DomainManagementObjectRemovedEvent>;
    /** All events */
    private allEvents;
    /** device manager added */
    private deviceManagerAdded;
    /** device manager removed */
    private deviceManagerRemoved;
    /** device added */
    private deviceAdded;
    /** device removed */
    private deviceRemoved;
    /** application factory added */
    private applicationFactoryAdded;
    /** application factory removed */
    private applicationFactoryRemoved;
    /** application added */
    private applicationAdded;
    /** application removed */
    private applicationRemoved;
    /** servce added */
    private serviceAdded;
    /** service removed */
    private serviceRemoved;
    /**
     * Connect to a Domain's ODM Event Channel
     * @param domainId The Domain ID (Name)
     */
    connect(domainId: string): void;
    /**
     * Disconnect from a Domain's ODM Event Channel
     * @param domainId The Domain ID (Name)
     */
    disconnect(domainId: string): void;
    /**
     * Constructor
     * @param eventChannel The Event Channel (Service) to use for connections
     */
    constructor(eventChannel: EventChannelService);
    /**
     * Uses the event's source category to determine the subject to update.
     * @param event The Event to handle
     */
    private handleAdd;
    /**
     * Uses the event's source category to determine the subject to update.
     * @param event The Event to handle
     */
    private handleRemove;
}
