import { Injector } from '@angular/core';
import { RedhawkService } from '../redhawk/redhawk.module';
import { Redhawk, Domain, DeviceManager, Waveform } from '../models/index';
import { DeviceManagerSubsystem, SystemBuilderConfig } from './config/index';
import { WaveformSubsystem } from './config/waveform-subsystem';
/**
 * This Directive must be instantiated once in your application where the 'provideSystemBuilderConfig' was
 * added to the providers.  This directive serves two purposes.  First, it is a nice visual queue in your
 * template that you're using the SystemBuilder.  Second, it acts as a background service for updating
 * your services.  If you need to know whether your service is up or down, observe the 'configured$'
 * member.
 */
export declare class SystemBuilderDirective {
    /** The Injector for fetching services */
    private injector;
    /** The SystemBuilder configuration being managed */
    private config;
    /** The REDHAWK service used for model look-ups */
    private redhawk;
    /**
     * Constructor
     * @param injector The parent injector for finding the pre-loaded services
     * @param redhawk The REDHAWK Service for locating the entities related to the services
     * @param config The user's SystemBuilder configuration for this directive to manage
     */
    constructor(injector: Injector, redhawk: RedhawkService, config: SystemBuilderConfig);
    /**
     * This method handles REDHAWK Model updates which indicate changes in the
     * domain listing.  If the DomainService in the config is already configured,
     * this method exits.  Otherwise, it tries to locate the specified domain
     * and configure the service.
     *
     * @param rh The REDHAWK model from the update.
     */
    checkDomains(rh: Redhawk): void;
    /**
     * This method checks the device manager configurations against the updated
     * domain model and configures the services as needed.
     * @param domain The domain model to check
     */
    checkDeviceManagers(domain: Domain): void;
    /**
     * This method checks the device configurations in the device manager's config
     * against the devices listing in the device manager model (dm).
     * @param dm The device manager model
     * @param config The device manager configuration related to this model.
     */
    checkDevices(dm: DeviceManager, config: DeviceManagerSubsystem): void;
    /**
     * This method checks the waveform configurations against the updated
     * domain model and configures the services as needed.
     * @param domain The domain model to check
     */
    checkWaveforms(domain: Domain): void;
    /**
     * This method checks the component configurations in the waveform's config
     * against the components listing in the waveform model (wave).
     * @param wave The waveform model
     * @param config The waveform configuration related to the model
     */
    checkComponents(wave: Waveform, config: WaveformSubsystem): void;
}
