import { OnDestroy, OnChanges, SimpleChanges, EventEmitter } from '@angular/core';
import { Waveform } from '../models/index';
import { WaveformService } from './waveform.service';
/**
 * The Waveform directive provides the dependency injection start point for
 * a running Waveform (Application) in the Domain
 *
 * @example
 * <div [arWaveform]="'DCE:...'" [(arModel)]="my_model">
 */
export declare class WaveformDirective implements OnDestroy, OnChanges {
    service: WaveformService;
    /**
     * Sets the ID for the underlying service
     */
    waveformId: string;
    /** Setter for "Banana in a Box Syntax"  */
    model: Waveform;
    /** Emitter for "Banana in a Box Syntax"  */
    modelChange: EventEmitter<Waveform>;
    /** Internal subscription for the model */
    private subscription;
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    constructor(service: WaveformService);
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    ngOnDestroy(): void;
}
