import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Waveform, Component, ResourceRefs, PropertySet } from '../models/index';
import { RestPythonService } from '../rest-python/rest-python.module';
import { PortBearingService } from '../base/index';
import { DomainService } from '../domain/domain.module';
import { IWaveformControlCommandResponse } from './waveform-control-command-response';
import { IWaveformReleaseResponse } from './waveform-release-response';
/**
 * The Waveform Service provides access to the Waveform Model on the REST server as well as
 * access to its components, ports, and properties.
 */
export declare class WaveformService extends PortBearingService<Waveform> {
    protected http: HttpClient;
    protected restPython: RestPythonService;
    protected domainService: DomainService;
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param domainService The Domain service that can contains this Waveform
     */
    constructor(http: HttpClient, restPython: RestPythonService, domainService: DomainService);
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    setBaseUrl(url: string): void;
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    uniqueQuery$(): Observable<Waveform>;
    /**
     * Returns an observable Component model if the Component ID is provided and exists.
     * If no ID is provided, this provides a reference listing of the components in the
     * Waveform.
     * @param [componentId] The Component ID to retrieve
     */
    comps$(componentId?: string): Observable<Component> | Observable<ResourceRefs>;
    /**
     * Starts the Waveform and returns the success/failure of that command.
     */
    start$(): Observable<IWaveformControlCommandResponse>;
    /**
     * Stops the Waveform and returns the success/failure of that command.
     */
    stop$(): Observable<IWaveformControlCommandResponse>;
    /**
     * Releases (removes) the Waveform and returns confirmation.
     */
    release$(): Observable<IWaveformReleaseResponse>;
    /**
     * Calls 'configure' on the Application and then pulls an update of the model.
     * @param properties The properties to 'configure' on the Application
     * @param delayResponseMs The optional model update delay after sending the
     * changes.
     */
    configure$(properties: PropertySet, delayResponseMs?: number): Observable<any>;
    /**
     * Common method shared by start and stop for issuing the command to the server.
     * @param command The command to issue (start/stop)
     */
    private controlCommand$;
}
