(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('@angular/common/http'), require('rxjs'), require('rxjs/operators')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common', '@angular/common/http', 'rxjs', 'rxjs/operators'], factory) :
	(factory((global['angular-redhawk'] = {}),global.core,global.common,global.http,global.rxjs,global.operators));
}(this, (function (exports,core,common,http,rxjs,operators) { 'use strict';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REST Python's location information.
 * @record
 */

/**
 * Pre-configure the REST-Python service by adding this to your application's
 * providers
 * @type {?}
 */
var REST_PYTHON_CONFIG = new core.InjectionToken('REST_PYTHON_CONFIG');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The REST Python (URL) Service provides generation of the URL end points of the
 * REST Python server.  Aided by dependency injection between services, this service
 * builds URL structures so that a Device Manager can infer its Domain's end point,
 * a Device can infer the Device Manager's end point, and so on.
 */
var RestPythonService = /** @class */ (function () {
    /**
     * Constructor
     * @param config The REST Python Configuration
     */
    function RestPythonService(config) {
        /**
         * Subject for indicating if the REST configuration changed at runtime
         */
        this._changed = new rxjs.Subject();
        this.setConfiguration(config);
    }
    Object.defineProperty(RestPythonService.prototype, "baseUrl", {
        /** Base URL of the REST Python Service */
        get: /**
         * Base URL of the REST Python Service
         * @private
         * @return {?}
         */
        function () {
            return this.host + ':' + this.port + this.apiUrl;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RestPythonService.prototype, "changed$", {
        /**
         * Be notified when the REST Python Service's URL changes in any way.
         */
        get: /**
         * Be notified when the REST Python Service's URL changes in any way.
         * @return {?}
         */
        function () { return this._changed.asObservable(); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RestPythonService.prototype, "host", {
        /** The configured host address for the REST-Python server */
        get: /**
         * The configured host address for the REST-Python server
         * @return {?}
         */
        function () { return this._host; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RestPythonService.prototype, "port", {
        /** The configured port for the REST-Python server */
        get: /**
         * The configured port for the REST-Python server
         * @return {?}
         */
        function () { return this._port; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RestPythonService.prototype, "apiUrl", {
        /** The configured API URL for the REST-Python server */
        get: /**
         * The configured API URL for the REST-Python server
         * @return {?}
         */
        function () { return this._apiUrl; },
        enumerable: true,
        configurable: true
    });
    /**
     * Reconfigure the REST-Python Service to a new service address
     */
    /**
     * Reconfigure the REST-Python Service to a new service address
     * @param {?} config
     * @return {?}
     */
    RestPythonService.prototype.setConfiguration = /**
     * Reconfigure the REST-Python Service to a new service address
     * @param {?} config
     * @return {?}
     */
    function (config) {
        /** @type {?} */
        var changed = false;
        config = config || {};
        if (config.host !== undefined && config.host !== this.host) {
            changed = true;
            this._host = config.host;
        }
        else if (this.host === undefined) {
            changed = true;
            this._host = window.location.hostname;
        }
        if (config.port !== undefined && config.port !== this.port) {
            changed = true;
            this._port = config.port;
        }
        else if (this.port === undefined) {
            changed = true;
            this._port = 8080;
        }
        if (config.apiUrl !== undefined && config.apiUrl !== this.apiUrl) {
            changed = true;
            this._apiUrl = config.apiUrl;
        }
        else if (this.apiUrl === undefined) {
            changed = true;
            this._apiUrl = '/redhawk/rest';
        }
        if (changed === true) {
            this._changed.next();
        }
    };
    /** URL for the REDHAWK interface */
    /**
     * URL for the REDHAWK interface
     * @return {?}
     */
    RestPythonService.prototype.redhawkUrl = /**
     * URL for the REDHAWK interface
     * @return {?}
     */
    function () {
        return this.baseRestUrl('');
    };
    /** URL for the Event Channels listing */
    /**
     * URL for the Event Channels listing
     * @return {?}
     */
    RestPythonService.prototype.eventChannelsUrl = /**
     * URL for the Event Channels listing
     * @return {?}
     */
    function () {
        return this.baseRestUrl('/events/');
    };
    /** URL for the/a Domain's interface */
    /**
     * URL for the/a Domain's interface
     * @param {?} parentUrl
     * @param {?=} domainId
     * @return {?}
     */
    RestPythonService.prototype.domainUrl = /**
     * URL for the/a Domain's interface
     * @param {?} parentUrl
     * @param {?=} domainId
     * @return {?}
     */
    function (parentUrl, domainId) {
        return this.baseRestUrl(parentUrl, '/domains', domainId);
    };
    /** URL for a FIle System interface */
    /**
     * URL for a FIle System interface
     * @param {?} parentUrl
     * @param {?=} path
     * @return {?}
     */
    RestPythonService.prototype.fileSystemUrl = /**
     * URL for a FIle System interface
     * @param {?} parentUrl
     * @param {?=} path
     * @return {?}
     */
    function (parentUrl, path) {
        return this.baseRestUrl(parentUrl, '/fs', path);
    };
    /** URL for a Device Manager listing or a specific instance */
    /**
     * URL for a Device Manager listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} deviceManagerId
     * @return {?}
     */
    RestPythonService.prototype.deviceManagerUrl = /**
     * URL for a Device Manager listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} deviceManagerId
     * @return {?}
     */
    function (parentUrl, deviceManagerId) {
        return this.baseRestUrl(parentUrl, '/deviceManagers', deviceManagerId);
    };
    /** URL for a Device listing or a specific instance */
    /**
     * URL for a Device listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} deviceId
     * @return {?}
     */
    RestPythonService.prototype.deviceUrl = /**
     * URL for a Device listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} deviceId
     * @return {?}
     */
    function (parentUrl, deviceId) {
        return this.baseRestUrl(parentUrl, '/devices', deviceId);
    };
    /** URL for a Service listing or a specific instance */
    /**
     * URL for a Service listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} serviceId
     * @return {?}
     */
    RestPythonService.prototype.serviceUrl = /**
     * URL for a Service listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} serviceId
     * @return {?}
     */
    function (parentUrl, serviceId) {
        return this.baseRestUrl(parentUrl, '/services', serviceId);
    };
    /** URL for a Waveform listing or a specific instance */
    /**
     * URL for a Waveform listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} waveformId
     * @return {?}
     */
    RestPythonService.prototype.waveformUrl = /**
     * URL for a Waveform listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} waveformId
     * @return {?}
     */
    function (parentUrl, waveformId) {
        return this.baseRestUrl(parentUrl, '/applications', waveformId);
    };
    /** URL for a Component listing or a specific instance */
    /**
     * URL for a Component listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} componentId
     * @return {?}
     */
    RestPythonService.prototype.componentUrl = /**
     * URL for a Component listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} componentId
     * @return {?}
     */
    function (parentUrl, componentId) {
        return this.baseRestUrl(parentUrl, '/components', componentId);
    };
    /** URL for the properties listing on an interface */
    /**
     * URL for the properties listing on an interface
     * @param {?} parentUrl
     * @return {?}
     */
    RestPythonService.prototype.propertyUrl = /**
     * URL for the properties listing on an interface
     * @param {?} parentUrl
     * @return {?}
     */
    function (parentUrl) {
        return this.baseRestUrl(parentUrl, '/properties');
    };
    /** URL for a Port listing or a specific instance */
    /**
     * URL for a Port listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} portId
     * @return {?}
     */
    RestPythonService.prototype.portUrl = /**
     * URL for a Port listing or a specific instance
     * @param {?} parentUrl
     * @param {?=} portId
     * @return {?}
     */
    function (parentUrl, portId) {
        return this.baseRestUrl(parentUrl, '/ports', portId);
    };
    /** URL for a port's BULKIO WebSocket interface (if applicable) */
    /**
     * URL for a port's BULKIO WebSocket interface (if applicable)
     * @param {?} portUrl
     * @return {?}
     */
    RestPythonService.prototype.bulkioSocketUrl = /**
     * URL for a port's BULKIO WebSocket interface (if applicable)
     * @param {?} portUrl
     * @return {?}
     */
    function (portUrl) {
        // Pop service off the front, if present.
        /** @type {?} */
        var baseUrlRE = new RegExp(this.baseUrl.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, '\\$&'));
        /** @type {?} */
        var svcRE = /^https?\:\/{1,2}/i;
        portUrl = portUrl.replace(baseUrlRE, '');
        portUrl = portUrl.replace(svcRE, '');
        return this.baseWebsocketUrl(portUrl, '/bulkio');
    };
    /** URL of the REDHAWK (Domain) Listener WebSocket (i.e., Domains coming and going) */
    /**
     * URL of the REDHAWK (Domain) Listener WebSocket (i.e., Domains coming and going)
     * @return {?}
     */
    RestPythonService.prototype.redhawkSocketUrl = /**
     * URL of the REDHAWK (Domain) Listener WebSocket (i.e., Domains coming and going)
     * @return {?}
     */
    function () {
        return this.baseWebsocketUrl('/redhawk');
    };
    /** URL for subscribing to Event Channels (WebSocket) */
    /**
     * URL for subscribing to Event Channels (WebSocket)
     * @return {?}
     */
    RestPythonService.prototype.eventSocketUrl = /**
     * URL for subscribing to Event Channels (WebSocket)
     * @return {?}
     */
    function () {
        return this.baseWebsocketUrl('/events');
    };
    /**
     * Returns a websocket URL from the provided URL and path
     * @param parentUrl The parent (service) URL
     * @param [subPath] A sub-path to extend on the URL
     */
    /**
     * Returns a websocket URL from the provided URL and path
     * @private
     * @param {?} parentUrl The parent (service) URL
     * @param {?=} subPath
     * @return {?}
     */
    RestPythonService.prototype.baseWebsocketUrl = /**
     * Returns a websocket URL from the provided URL and path
     * @private
     * @param {?} parentUrl The parent (service) URL
     * @param {?=} subPath
     * @return {?}
     */
    function (parentUrl, subPath) {
        /** @type {?} */
        var path = ((window.location.protocol === 'https:') ? 'wss:' : 'ws:') + '//';
        path += this.baseUrl + parentUrl;
        if (subPath) {
            path += subPath;
        }
        return path;
    };
    /**
     * Creates a URL from the parent's and some new end point details.
     * @param parentUrl The parent (service's) URL
     * @param [subPath] A sub-path extending off the parent's URL
     * @param [target] A REST end point combining the above URL elements.
     */
    /**
     * Creates a URL from the parent's and some new end point details.
     * @private
     * @param {?} parentUrl The parent (service's) URL
     * @param {?=} subPath
     * @param {?=} target
     * @return {?}
     */
    RestPythonService.prototype.baseRestUrl = /**
     * Creates a URL from the parent's and some new end point details.
     * @private
     * @param {?} parentUrl The parent (service's) URL
     * @param {?=} subPath
     * @param {?=} target
     * @return {?}
     */
    function (parentUrl, subPath, target) {
        /** @type {?} */
        var server = window.location.protocol + '//' + this.baseUrl;
        if (parentUrl.lastIndexOf(server) >= 0) {
            server = ''; // Already added.
        }
        if (subPath) {
            if (target) {
                return server + parentUrl + subPath + '/' + target;
            }
            return server + parentUrl + subPath;
        }
        return server + parentUrl;
    };
    RestPythonService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    RestPythonService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Optional }, { type: core.Inject, args: [REST_PYTHON_CONFIG,] }] }
    ]; };
    return RestPythonService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The REST-Python Module provides the RestPythonService to the application, which
 * is the primary back-end for communicating with the REST-Python REDHAWK server.
 */
var RestPythonModule = /** @class */ (function () {
    function RestPythonModule() {
    }
    RestPythonModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [http.HttpClientModule],
                    providers: [RestPythonService]
                },] },
    ];
    return RestPythonModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var BulkioDataType = {
    // dataOctet,
    dataShort: 0,
    dataLong: 1,
    dataLongLong: 2,
    dataULong: 3,
    dataULongLong: 4,
    dataFloat: 5,
    dataDouble: 6,
    UNKNOWN: 7,
};
BulkioDataType[BulkioDataType.dataShort] = 'dataShort';
BulkioDataType[BulkioDataType.dataLong] = 'dataLong';
BulkioDataType[BulkioDataType.dataLongLong] = 'dataLongLong';
BulkioDataType[BulkioDataType.dataULong] = 'dataULong';
BulkioDataType[BulkioDataType.dataULongLong] = 'dataULongLong';
BulkioDataType[BulkioDataType.dataFloat] = 'dataFloat';
BulkioDataType[BulkioDataType.dataDouble] = 'dataDouble';
BulkioDataType[BulkioDataType.UNKNOWN] = 'UNKNOWN';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK BULKIO Enumerations
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var deserializeKeywords;
deserializeKeywords = (/**
 * @param {?=} inputs
 * @return {?}
 */
function (inputs) {
    /** @type {?} */
    var keys = new Map();
    if (inputs) {
        Object.keys(inputs).forEach((/**
         * @param {?} key
         * @return {?}
         */
        function (key) {
            keys.set(key, inputs[key]);
        }));
    }
    return keys;
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK SRI (Signal Related Information) Structure
 */
var SRI = /** @class */ (function () {
    function SRI() {
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    SRI.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).hversion = input.hversion;
        (/** @type {?} */ (this)).xstart = input.xstart;
        (/** @type {?} */ (this)).xdelta = input.xdelta;
        (/** @type {?} */ (this)).xunits = input.xunits;
        (/** @type {?} */ (this)).subsize = input.subsize;
        (/** @type {?} */ (this)).ystart = input.ystart;
        (/** @type {?} */ (this)).ydelta = input.ydelta;
        (/** @type {?} */ (this)).yunits = input.yunits;
        (/** @type {?} */ (this)).mode = input.mode;
        (/** @type {?} */ (this)).streamID = input.streamID;
        (/** @type {?} */ (this)).blocking = input.blocking;
        (/** @type {?} */ (this)).keywords = deserializeKeywords(input.keywords);
        return (/** @type {?} */ (this));
    };
    return SRI;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK BULKIO Precision UTC Time model
 */
var PrecisionUTCTime = /** @class */ (function () {
    function PrecisionUTCTime() {
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    PrecisionUTCTime.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).tcmode = input.tcmode;
        (/** @type {?} */ (this)).tcstatus = input.tcstatus;
        (/** @type {?} */ (this)).toff = input.toff;
        (/** @type {?} */ (this)).twsec = input.twsec;
        (/** @type {?} */ (this)).tfsec = input.tfsec;
        return (/** @type {?} */ (this));
    };
    return PrecisionUTCTime;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK BULKIO Packet model
 */
var BulkioPacket = /** @class */ (function () {
    function BulkioPacket() {
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    BulkioPacket.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).streamID = input.streamID;
        (/** @type {?} */ (this)).T = new PrecisionUTCTime().deserialize(input.T);
        (/** @type {?} */ (this)).EOS = input.EOS;
        (/** @type {?} */ (this)).sriChanged = input.sriChanged;
        (/** @type {?} */ (this)).SRI = new SRI().deserialize(input.SRI);
        (/** @type {?} */ (this)).type = resolve(input.type);
        (/** @type {?} */ (this)).dataBuffer = input.dataBuffer;
        return (/** @type {?} */ (this));
    };
    return BulkioPacket;
}());
/**
 * @param {?} dataType
 * @return {?}
 */
function resolve(dataType) {
    switch (dataType) {
        // case 'dataOctet':
        //     return BulkioDataType.dataOctet;
        case 'dataShort':
            return BulkioDataType.dataShort;
        case 'dataLong':
            return BulkioDataType.dataLong;
        case 'dataLongLong':
            return BulkioDataType.dataLongLong;
        case 'dataULong':
            return BulkioDataType.dataULong;
        case 'dataULongLong':
            return BulkioDataType.dataULongLong;
        case 'dataFloat':
            return BulkioDataType.dataFloat;
        case 'dataDouble':
            return BulkioDataType.dataDouble;
        default:
            return BulkioDataType.UNKNOWN;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK BULKIO Model(s)
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Base class reference to a Resource (Device, Component, etc.).  This object is
 * only the id-name pair one would find in a Device Manager's devices array,
 * not the full model.
 *
 * NOTE: This is not related to the Core Framework Resource class!  The English
 * word made sense for these objects that are ID-name pairs since they are
 * resource references (ResourceRef) on the REST server that resolve into actual
 * resource entities at the server.
 */
var ResourceRef = /** @class */ (function () {
    function ResourceRef() {
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    ResourceRef.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).name = input.name;
        (/** @type {?} */ (this)).id = input.id;
        return (/** @type {?} */ (this));
    };
    return ResourceRef;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Abstract base class for a serializable REDHAWK Property model
 * @abstract
 */
var Property = /** @class */ (function () {
    /**
     * Constructor
     * @param [id] The property's ID
     * @param [name] The property's Name
     * @param [value] The value of the property
    */
    function Property(id, name, value) {
        /**
         * The 'kinds' of the property
         */
        this.kinds = 'property';
        /**
         * Access mode
         */
        this.mode = 'readwrite';
        this.id = id;
        this.name = name;
        this.value = value;
        this.kinds = [];
    }
    /**
     * **WARNING:** This is a partial deserialization.
     * Used the derived classes instead:
     *  * {@link SimpleProperty}
     *  * {@link SimpleSeqProperty}
     *  * {@link StructProperty}
     *  * {@link StructSeqProperty}
     * @param input The JSON object to deserialize into this property's members.
     */
    /**
     * **WARNING:** This is a partial deserialization.
     * Used the derived classes instead:
     *  * {\@link SimpleProperty}
     *  * {\@link SimpleSeqProperty}
     *  * {\@link StructProperty}
     *  * {\@link StructSeqProperty}
     * @template THIS
     * @this {THIS}
     * @param {?} input The JSON object to deserialize into this property's members.
     * @return {THIS}
     */
    Property.prototype.deserialize = /**
     * **WARNING:** This is a partial deserialization.
     * Used the derived classes instead:
     *  * {\@link SimpleProperty}
     *  * {\@link SimpleSeqProperty}
     *  * {\@link StructProperty}
     *  * {\@link StructSeqProperty}
     * @template THIS
     * @this {THIS}
     * @param {?} input The JSON object to deserialize into this property's members.
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).id = input.id;
        (/** @type {?} */ (this)).name = input.name;
        (/** @type {?} */ (this)).mode = input.mode;
        (/** @type {?} */ (this)).kinds = input.kinds;
        return (/** @type {?} */ (this));
    };
    return Property;
}());

var __extends$3 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Common base class for Simple and SimpleSeq types which have
 * the ability to express values as enumerations
 */
var SimpleCommon = /** @class */ (function (_super) {
    __extends$3(SimpleCommon, _super);
    function SimpleCommon() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Common string-to-value (data)type conversion.
     * @param val Value to convert (string)
     * @param type Data type (string, long, ulong, etc.)
     */
    /**
     * Common string-to-value (data)type conversion.
     * @param {?} val Value to convert (string)
     * @param {?} type Data type (string, long, ulong, etc.)
     * @return {?}
     */
    SimpleCommon.valueFromString = /**
     * Common string-to-value (data)type conversion.
     * @param {?} val Value to convert (string)
     * @param {?} type Data type (string, long, ulong, etc.)
     * @return {?}
     */
    function (val, type) {
        /** @type {?} */
        var value = val;
        switch (type) {
            case 'long':
            case 'ulong':
            case 'longlong':
            case 'ulonglong':
            case 'short':
            case 'ushort':
            case 'octet':
            case 'float':
            case 'double':
                // Not a typo, converts to a number
                value = +val;
                break;
            case 'boolean':
                value = val.toLowerCase() === 'true' ? true : false;
                break;
            case 'string':
            case 'char':
                break;
            default:
                console.warn("Unknown data type (" + type + "); treating as string.");
                value = '' + val;
                break;
        }
        return value;
    };
    /**
     * Create a copy of the property
     */
    /**
     * Create a copy of the property
     * @return {?}
     */
    SimpleCommon.prototype.copy = /**
     * Create a copy of the property
     * @return {?}
     */
    function () {
        /** @type {?} */
        var p = new SimpleCommon().deserialize(this);
        p.kinds = (this.kinds instanceof Array) ? this.kinds.slice() : this.kinds;
        p.type = this.type;
        // Copy the map if it exists
        if (this.enumerations !== undefined) {
            p.enumerations = {};
            for (var i in this.enumerations) {
                if (this.enumerations.hasOwnProperty(i)) {
                    p.enumerations[i] = this.enumerations[i];
                }
            }
        }
        return p;
    };
    return SimpleCommon;
}(Property));

var __extends$2 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK 'simple' Property Model
 */
var SimpleProperty = /** @class */ (function (_super) {
    __extends$2(SimpleProperty, _super);
    function SimpleProperty() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /**
         * SCA Type ('simple')
         */
        _this.scaType = 'simple';
        return _this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    SimpleProperty.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).scaType = input.scaType;
        (/** @type {?} */ (this)).type = input.type;
        (/** @type {?} */ (this)).enumerations = input.enumerations;
        if (!input.value) {
            (/** @type {?} */ (this)).valueFromString('');
        }
        else {
            (/** @type {?} */ (this)).value = input.value;
        }
        return (/** @type {?} */ (this));
    };
    /**
     * Create a copy of the property.
     */
    /**
     * Create a copy of the property.
     * @return {?}
     */
    SimpleProperty.prototype.copy = /**
     * Create a copy of the property.
     * @return {?}
     */
    function () {
        // SimpleCommon handles type, enumerations
        // This creates an initial copy as the base class,
        // merges this instance's changes and then deserializes
        // a copy as this class.
        /** @type {?} */
        var p = _super.prototype.copy.call(this);
        p.scaType = this.scaType;
        p.value = this.value;
        return new SimpleProperty().deserialize(p);
    };
    /**
     * Update the value from the string vs. type off this property
     * @param val The string value to convert based on the type
     */
    /**
     * Update the value from the string vs. type off this property
     * @param {?} val The string value to convert based on the type
     * @return {?}
     */
    SimpleProperty.prototype.valueFromString = /**
     * Update the value from the string vs. type off this property
     * @param {?} val The string value to convert based on the type
     * @return {?}
     */
    function (val) {
        this.value = SimpleCommon.valueFromString(val, this.type);
    };
    return SimpleProperty;
}(SimpleCommon));

var __extends$4 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 *  A 'simpleSeq' Property
 */
var SimpleSeqProperty = /** @class */ (function (_super) {
    __extends$4(SimpleSeqProperty, _super);
    function SimpleSeqProperty() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /**
         * SCA Type ('simpleSeq')
         */
        _this.scaType = 'simpleSeq';
        return _this;
    }
    /**
     * Deserializes a JSON object into this class
     * @param input JSON Object
     */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input JSON Object
     * @return {THIS}
     */
    SimpleSeqProperty.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input JSON Object
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).scaType = input.scaType;
        (/** @type {?} */ (this)).type = input.type;
        (/** @type {?} */ (this)).enumerations = input.enumerations;
        (/** @type {?} */ (this)).value = input.value || [];
        return (/** @type {?} */ (this));
    };
    /**
     * Create a copy of the property.
     */
    /**
     * Create a copy of the property.
     * @return {?}
     */
    SimpleSeqProperty.prototype.copy = /**
     * Create a copy of the property.
     * @return {?}
     */
    function () {
        // SimpleCommon handles type, enumerations
        // This creates an initial copy as the base class,
        // merges this instance's changes and then deserializes
        // a copy as this class.
        /** @type {?} */
        var p = _super.prototype.copy.call(this);
        p.scaType = this.scaType;
        p.value = this.value.slice();
        return new SimpleSeqProperty().deserialize(p);
    };
    /**
     * Update the value from the string representation
     * @param vals Comma-spaced values to convert to this property's value
     */
    /**
     * Update the value from the string representation
     * @param {?} vals Comma-spaced values to convert to this property's value
     * @return {?}
     */
    SimpleSeqProperty.prototype.valueFromString = /**
     * Update the value from the string representation
     * @param {?} vals Comma-spaced values to convert to this property's value
     * @return {?}
     */
    function (vals) {
        this.value.length = 0;
        if (vals.length > 0) {
            /** @type {?} */
            var values = vals.trim().split(',');
            for (var _i = 0, values_1 = values; _i < values_1.length; _i++) {
                var val = values_1[_i];
                this.value.push(SimpleCommon.valueFromString(val, this.type));
            }
        }
    };
    return SimpleSeqProperty;
}(SimpleCommon));

var __extends$5 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK 'struct' Property Model
 */
var StructProperty = /** @class */ (function (_super) {
    __extends$5(StructProperty, _super);
    function StructProperty() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /**
         * The SCA Type of the property ('struct')
         */
        _this.scaType = 'struct';
        return _this;
    }
    /**
     * Get the structure's fields (members) IDs.
     * @return {string[]} List of field IDs in this structure
     */
    /**
     * Get the structure's fields (members) IDs.
     * @return {?}
     */
    StructProperty.prototype.getFields = /**
     * Get the structure's fields (members) IDs.
     * @return {?}
     */
    function () {
        /** @type {?} */
        var fields = [];
        for (var _i = 0, _a = this.value; _i < _a.length; _i++) {
            var field = _a[_i];
            fields.push(field.id);
        }
        return fields;
    };
    /**
     * Helper function to get individual fields from the struct's list of fields.
     * @param {string} id The ID of the field/member to return
     */
    /**
     * Helper function to get individual fields from the struct's list of fields.
     * @param {?} id
     * @return {?}
     */
    StructProperty.prototype.field = /**
     * Helper function to get individual fields from the struct's list of fields.
     * @param {?} id
     * @return {?}
     */
    function (id) {
        for (var _i = 0, _a = this.value; _i < _a.length; _i++) {
            var field = _a[_i];
            if (field.id === id) {
                return field;
            }
        }
        return undefined;
    };
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    StructProperty.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).scaType = input.scaType;
        (/** @type {?} */ (this)).value = (/** @type {?} */ ([]));
        for (var _i = 0, _a = input.value; _i < _a.length; _i++) {
            var field = _a[_i];
            if (field.scaType === 'simple') {
                (/** @type {?} */ (this)).value.push(new SimpleProperty().deserialize(field));
            }
            else if (field.scaType === 'simpleSeq') {
                (/** @type {?} */ (this)).value.push(new SimpleSeqProperty().deserialize(field));
            }
        }
        return (/** @type {?} */ (this));
    };
    /**
     * Create a copy of the property
     */
    /**
     * Create a copy of the property
     * @return {?}
     */
    StructProperty.prototype.copy = /**
     * Create a copy of the property
     * @return {?}
     */
    function () {
        /** @type {?} */
        var p = new StructProperty().deserialize(this);
        p.kinds = (this.kinds instanceof Array) ? this.kinds.slice() : this.kinds;
        return p;
    };
    /**
     * Convenience method for taking structures that have a 'value' that is a list
     * of id-value pairs like StructProperty and turning them into a 'normal' object
     * whose members are created using the de-namespaced 'id'.
     *
     * For example, an id of TestMessage::something on a field results in an object
     * with a 'something' member set to that field's value.
     * @return A populated Object from this message's members.
     */
    /**
     * Convenience method for taking structures that have a 'value' that is a list
     * of id-value pairs like StructProperty and turning them into a 'normal' object
     * whose members are created using the de-namespaced 'id'.
     *
     * For example, an id of TestMessage::something on a field results in an object
     * with a 'something' member set to that field's value.
     * @template T
     * @return {?} A populated Object from this message's members.
     */
    StructProperty.prototype.asObject = /**
     * Convenience method for taking structures that have a 'value' that is a list
     * of id-value pairs like StructProperty and turning them into a 'normal' object
     * whose members are created using the de-namespaced 'id'.
     *
     * For example, an id of TestMessage::something on a field results in an object
     * with a 'something' member set to that field's value.
     * @template T
     * @return {?} A populated Object from this message's members.
     */
    function () {
        /** @type {?} */
        var obj = (/** @type {?} */ ({}));
        for (var _i = 0, _a = this.value; _i < _a.length; _i++) {
            var field = _a[_i];
            /** @type {?} */
            var id = field.id.split('::').pop();
            obj[id] = field.value;
        }
        return obj;
    };
    return StructProperty;
}(Property));

var __extends$6 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK 'structSeq' Property Model
 */
var StructSeqProperty = /** @class */ (function (_super) {
    __extends$6(StructSeqProperty, _super);
    function StructSeqProperty() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /**
         * The SCA Type ('structseq')
         */
        _this.scaType = 'structSeq';
        return _this;
    }
    /**
     * Find a StructProperty having a field whose value matches the provided one.
     *
     * @param { string } fieldId The field ID in the StructProprety to use in the match.
     * @param { string } value The value to locate at fieldId
     */
    /**
     * Find a StructProperty having a field whose value matches the provided one.
     *
     * @param {?} fieldId
     * @param {?} value
     * @return {?}
     */
    StructSeqProperty.prototype.find = /**
     * Find a StructProperty having a field whose value matches the provided one.
     *
     * @param {?} fieldId
     * @param {?} value
     * @return {?}
     */
    function (fieldId, value) {
        for (var _i = 0, _a = this.value; _i < _a.length; _i++) {
            var item = _a[_i];
            /** @type {?} */
            var field = item.field(fieldId);
            if (field && field.value === value) {
                return item;
            }
        }
        return undefined;
    };
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    StructSeqProperty.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).scaType = input.scaType;
        (/** @type {?} */ (this)).value = (/** @type {?} */ ([]));
        for (var _i = 0, _a = input.value; _i < _a.length; _i++) {
            var sub = _a[_i];
            (/** @type {?} */ (this)).value.push(new StructProperty().deserialize(sub));
        }
        return (/** @type {?} */ (this));
    };
    /**
     * Create a copy of the property.
     */
    /**
     * Create a copy of the property.
     * @return {?}
     */
    StructSeqProperty.prototype.copy = /**
     * Create a copy of the property.
     * @return {?}
     */
    function () {
        /** @type {?} */
        var p = new StructSeqProperty().deserialize(this);
        p.kinds = (this.kinds instanceof Array) ? this.kinds.slice() : this.kinds;
        return p;
    };
    return StructSeqProperty;
}(Property));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Helper method to deserialize JSON properties into a REDHAWK PropertySet.
 *
 * @param {?=} inputs
 * @return {?}
 */
function deserializeProperties(inputs) {
    if (inputs === void 0) { inputs = []; }
    /** @type {?} */
    var props = [];
    for (var _i = 0, inputs_1 = inputs; _i < inputs_1.length; _i++) {
        var input = inputs_1[_i];
        if (input !== undefined) {
            /** @type {?} */
            var p = void 0;
            switch (input.scaType) {
                case 'simpleSeq':
                    p = new SimpleSeqProperty().deserialize(input);
                    break;
                case 'struct':
                    p = new StructProperty().deserialize(input);
                    break;
                case 'structSeq':
                    p = new StructSeqProperty().deserialize(input);
                    break;
                case 'simple':
                // tslint:disable-next-line:no-switch-case-fall-through
                default:
                    p = new SimpleProperty().deserialize(input);
                    break;
            }
            props.push(p);
        }
    }
    return props;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK Property Models, enumerations, types and serialization interfaces
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var PortIDLNameSpace = {
    UNKNOWN: 0,
    BULKIO: 1,
    FRONTEND: 2,
    ExtendedEvent: 3,
    CosEventChannelAdmin: 4,
};
PortIDLNameSpace[PortIDLNameSpace.UNKNOWN] = 'UNKNOWN';
PortIDLNameSpace[PortIDLNameSpace.BULKIO] = 'BULKIO';
PortIDLNameSpace[PortIDLNameSpace.FRONTEND] = 'FRONTEND';
PortIDLNameSpace[PortIDLNameSpace.ExtendedEvent] = 'ExtendedEvent';
PortIDLNameSpace[PortIDLNameSpace.CosEventChannelAdmin] = 'CosEventChannelAdmin';

/**
 * Function for converting a string name to the port IDL namespace enumeration.
 * @param {?} val The value to resolve to the enumeration
 * @return {?}
 */
function resolvePortIDLNameSpace(val) {
    /** @type {?} */
    var namespace = PortIDLNameSpace.UNKNOWN;
    switch (val) {
        case 'BULKIO':
            namespace = PortIDLNameSpace.BULKIO;
            break;
        case 'FRONTEND':
            namespace = PortIDLNameSpace.FRONTEND;
            break;
        case 'ExtendedEvent':
            namespace = PortIDLNameSpace.ExtendedEvent;
            break;
        case 'CosEventChannelAdmin':
            namespace = PortIDLNameSpace.CosEventChannelAdmin;
            break;
        default:
            namespace = PortIDLNameSpace.UNKNOWN;
            break;
    }
    return namespace;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var PortUnknownIDLType = {
    UNKNOWN: -1,
};
PortUnknownIDLType[PortUnknownIDLType.UNKNOWN] = 'UNKNOWN';
/** @enum {number} */
var PortBulkIOIDLType = {
    UNKNOWN: -1,
    dataShort: 0,
    dataUShort: 1,
    dataOctet: 2,
    dataLong: 3,
    dataLongLong: 4,
    dataULong: 5,
    dataULongLong: 6,
    dataFloat: 7,
    dataDouble: 8,
};
PortBulkIOIDLType[PortBulkIOIDLType.UNKNOWN] = 'UNKNOWN';
PortBulkIOIDLType[PortBulkIOIDLType.dataShort] = 'dataShort';
PortBulkIOIDLType[PortBulkIOIDLType.dataUShort] = 'dataUShort';
PortBulkIOIDLType[PortBulkIOIDLType.dataOctet] = 'dataOctet';
PortBulkIOIDLType[PortBulkIOIDLType.dataLong] = 'dataLong';
PortBulkIOIDLType[PortBulkIOIDLType.dataLongLong] = 'dataLongLong';
PortBulkIOIDLType[PortBulkIOIDLType.dataULong] = 'dataULong';
PortBulkIOIDLType[PortBulkIOIDLType.dataULongLong] = 'dataULongLong';
PortBulkIOIDLType[PortBulkIOIDLType.dataFloat] = 'dataFloat';
PortBulkIOIDLType[PortBulkIOIDLType.dataDouble] = 'dataDouble';

/** @enum {number} */
var PortFEIIDLType = {
    UNKNOWN: -1,
    DigitalTuner: 9,
    AnalogTuner: 10,
    RFInfo: 11,
    RFSource: 12,
    GPS: 13,
    NavData: 14,
};
PortFEIIDLType[PortFEIIDLType.UNKNOWN] = 'UNKNOWN';
PortFEIIDLType[PortFEIIDLType.DigitalTuner] = 'DigitalTuner';
PortFEIIDLType[PortFEIIDLType.AnalogTuner] = 'AnalogTuner';
PortFEIIDLType[PortFEIIDLType.RFInfo] = 'RFInfo';
PortFEIIDLType[PortFEIIDLType.RFSource] = 'RFSource';
PortFEIIDLType[PortFEIIDLType.GPS] = 'GPS';
PortFEIIDLType[PortFEIIDLType.NavData] = 'NavData';

/**
 * Deserialization function for Port IDL types received from the server.
 *
 * End users should not need this method as it's used by PortIDL to ensure
 * the resulting enumeration maps to one of the above enumerations.
 * @param {?} val
 * @return {?}
 */
function resolvePortIDLType(val) {
    /** @type {?} */
    var idlType = PortBulkIOIDLType.UNKNOWN;
    switch (val) {
        case 'dataShort':
            idlType = PortBulkIOIDLType.dataShort;
            break;
        case 'dataUShort':
            idlType = PortBulkIOIDLType.dataUShort;
            break;
        case 'dataOctet':
            idlType = PortBulkIOIDLType.dataOctet;
            break;
        case 'dataLong':
            idlType = PortBulkIOIDLType.dataLong;
            break;
        case 'dataULong':
            idlType = PortBulkIOIDLType.dataULong;
            break;
        case 'dataLongLong':
            idlType = PortBulkIOIDLType.dataLongLong;
            break;
        case 'dataULongLong':
            idlType = PortBulkIOIDLType.dataULongLong;
            break;
        case 'dataFloat':
            idlType = PortBulkIOIDLType.dataFloat;
            break;
        case 'dataDouble':
            idlType = PortBulkIOIDLType.dataDouble;
            break;
        case 'DigitalTuner':
            idlType = PortFEIIDLType.DigitalTuner;
            break;
        case 'AnalogTuner':
            idlType = PortFEIIDLType.AnalogTuner;
            break;
        case 'RFInfo':
            idlType = PortFEIIDLType.RFInfo;
            break;
        case 'RFSource':
            idlType = PortFEIIDLType.RFSource;
            break;
        case 'GPS':
            idlType = PortFEIIDLType.GPS;
            break;
        case 'NavData':
            idlType = PortFEIIDLType.NavData;
            break;
        default:
            break;
    }
    return idlType;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var PortDirection = {
    UNKNOWN: 0,
    Uses: 1,
    Provides: 2,
};
PortDirection[PortDirection.UNKNOWN] = 'UNKNOWN';
PortDirection[PortDirection.Uses] = 'Uses';
PortDirection[PortDirection.Provides] = 'Provides';

/**
 * Convenience function for converting the string direction returned from the
 * server to the enumeration.
 *
 * @param {?} val - The string name of the port direction.
 * @return {?}
 */
function resolvePortDirection(val) {
    /** @type {?} */
    var direction = PortDirection.UNKNOWN;
    switch (val) {
        case 'Uses':
            direction = PortDirection.Uses;
            break;
        case 'Provides':
            direction = PortDirection.Provides;
            break;
        default:
            break;
    }
    return direction;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK Port enumerations and conversion methods
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Port IDL Model
 */
var PortIDL = /** @class */ (function () {
    function PortIDL() {
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    PortIDL.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).namespace = resolvePortIDLNameSpace(input.namespace);
        (/** @type {?} */ (this)).version = input.version;
        (/** @type {?} */ (this)).type = resolvePortIDLType(input.type);
        return (/** @type {?} */ (this));
    };
    return PortIDL;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Port Model
 */
var Port = /** @class */ (function () {
    function Port() {
    }
    Object.defineProperty(Port.prototype, "hasBulkioWebsocket", {
        /** Indicates this is a BULKIO port that supports the websocket interface. */
        get: /**
         * Indicates this is a BULKIO port that supports the websocket interface.
         * @return {?}
         */
        function () {
            return (this.direction === PortDirection.Uses &&
                this.idl.namespace === PortIDLNameSpace.BULKIO &&
                this.idl.type !== PortBulkIOIDLType.dataOctet);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Port.prototype, "isFEIControllable", {
        /** Indicates this is an FEI port that supports the control interface. */
        get: /**
         * Indicates this is an FEI port that supports the control interface.
         * @return {?}
         */
        function () {
            return (this.direction === PortDirection.Provides &&
                this.idl.namespace === PortIDLNameSpace.FRONTEND);
        },
        enumerable: true,
        configurable: true
    });
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    Port.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).name = input.name;
        (/** @type {?} */ (this)).repId = input.repId;
        (/** @type {?} */ (this)).direction = resolvePortDirection(input.direction);
        (/** @type {?} */ (this)).idl = new PortIDL().deserialize(input.idl);
        return (/** @type {?} */ (this));
    };
    return Port;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Module for REDHAWK Port-related models and interfaces.
 */
/**
 * Deserializes a JSON object into a single port
 *
 * @param {?} input
 * @return {?}
 */
function deserializePort(input) {
    return new Port().deserialize(input);
}
/**
 * Deserializes a JSON object into a port listing.
 *
 * @param {?=} inputs
 * @return {?}
 */
function deserializePorts(inputs) {
    if (!inputs) {
        return [];
    }
    /** @type {?} */
    var ports = [];
    for (var _i = 0, inputs_1 = inputs; _i < inputs_1.length; _i++) {
        var port = inputs_1[_i];
        ports.push(deserializePort(port));
    }
    return ports;
}

var __extends$1 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Base class for Resource subclasses (Device, Component) that represents the
 * actual server-side model (properties, etc.).
 */
var Resource = /** @class */ (function (_super) {
    __extends$1(Resource, _super);
    /** Constructor */
    function Resource() {
        var _this = _super.call(this) || this;
        _this.properties = [];
        _this.ports = [];
        return _this;
    }
    /**
     * Iterates over the 'properties' list to return the property matching the ID
     * @param id The ID of the property to return
     * @returns {prop.Property} The Property model (or undefined if invalid).
     */
    /**
     * Iterates over the 'properties' list to return the property matching the ID
     * @param {?} id The ID of the property to return
     * @return {?}
     */
    Resource.prototype.property = /**
     * Iterates over the 'properties' list to return the property matching the ID
     * @param {?} id The ID of the property to return
     * @return {?}
     */
    function (id) {
        for (var _i = 0, _a = this.properties; _i < _a.length; _i++) {
            var p = _a[_i];
            if (p.id === id) {
                return p;
            }
        }
        return undefined;
    };
    /**
     * Iterates over the 'ports' list to return the port maching the ID (name)
     * @param id The unique identifier of the port (i.e., its name).
     * @returns {port.Port} The Port model (or undefined if invalid)
     */
    /**
     * Iterates over the 'ports' list to return the port maching the ID (name)
     * @param {?} id The unique identifier of the port (i.e., its name).
     * @return {?}
     */
    Resource.prototype.getPort = /**
     * Iterates over the 'ports' list to return the port maching the ID (name)
     * @param {?} id The unique identifier of the port (i.e., its name).
     * @return {?}
     */
    function (id) {
        for (var _i = 0, _a = this.ports; _i < _a.length; _i++) {
            var p = _a[_i];
            if (p.name === id) {
                return p;
            }
        }
        return undefined;
    };
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    Resource.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).started = input.started;
        (/** @type {?} */ (this)).ports = deserializePorts(input.ports);
        (/** @type {?} */ (this)).properties = deserializeProperties(input.properties);
        return (/** @type {?} */ (this));
    };
    return Resource;
}(ResourceRef));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Resource models module represent the serializable base classes for references
 * to the server side models as well as the models themselves (i.e., Devices and
 * Components).  This is also used in the Waveform, DeviceManager, and Domain
 * because the reference listings are all id-name lists of endpoints.
 */
/**
 * Utility function for deserializing a list of resource refs.
 * @param {?=} inputs
 * @return {?}
 */
function deserializeResourceRefs(inputs) {
    if (inputs === void 0) { inputs = []; }
    /** @type {?} */
    var refs = [];
    for (var _i = 0, inputs_1 = inputs; _i < inputs_1.length; _i++) {
        var ref = inputs_1[_i];
        refs.push(new ResourceRef().deserialize(ref));
    }
    return refs;
}

var __extends = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Component server model
 */
var Component = /** @class */ (function (_super) {
    __extends(Component, _super);
    function Component() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Component;
}(Resource));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Component Model(s) module
 */

var __extends$7 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable Device model
 */
var Device = /** @class */ (function (_super) {
    __extends$7(Device, _super);
    function Device() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Device;
}(Resource));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK Device models and interfaces
 */

var __extends$8 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Reference to a device manager (Node), typicall on the Domain model
 */
var DeviceManagerRef = /** @class */ (function (_super) {
    __extends$8(DeviceManagerRef, _super);
    function DeviceManagerRef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return DeviceManagerRef;
}(ResourceRef));

var __extends$9 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Device manager model
 */
var DeviceManager = /** @class */ (function (_super) {
    __extends$9(DeviceManager, _super);
    /** Constructor */
    function DeviceManager() {
        var _this = _super.call(this) || this;
        _this.properties = [];
        _this.devices = [];
        _this.services = [];
        return _this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    DeviceManager.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).properties = deserializeProperties(input.properties);
        (/** @type {?} */ (this)).devices = deserializeResourceRefs(input.devices);
        (/** @type {?} */ (this)).services = deserializeResourceRefs(input.services);
        return (/** @type {?} */ (this));
    };
    return DeviceManager;
}(DeviceManagerRef));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Function for deserializing a list of device manager refs, typically used
 * by the Domain.
 * @param {?=} inputs
 * @return {?}
 */
function deserializeDeviceManagerRefs(inputs) {
    if (!inputs) {
        return [];
    }
    /** @type {?} */
    var refs = [];
    for (var _i = 0, inputs_1 = inputs; _i < inputs_1.length; _i++) {
        var ref = inputs_1[_i];
        refs.push(new DeviceManagerRef().deserialize(ref));
    }
    return refs;
}

var __extends$10 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Waveform model
 */
var Waveform = /** @class */ (function (_super) {
    __extends$10(Waveform, _super);
    /** Constructor */
    function Waveform() {
        var _this = _super.call(this) || this;
        _this.components = [];
        return _this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    Waveform.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).components = deserializeResourceRefs(input.components);
        return (/** @type {?} */ (this));
    };
    return Waveform;
}(Resource));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Waveform SAD model (i.e., a reference to an
 * available Waveform/Application that can be launched).
 */
var WaveformSAD = /** @class */ (function () {
    function WaveformSAD() {
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    WaveformSAD.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).name = input.name;
        (/** @type {?} */ (this)).sad = input.sad;
        return (/** @type {?} */ (this));
    };
    return WaveformSAD;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Helper function to convert a JSON object into a list of Waveform SAD refs
 * @param {?=} inputs
 * @return {?}
 */
function deserializeWaveformSADRefs(inputs) {
    if (!inputs) {
        return [];
    }
    /** @type {?} */
    var refs = [];
    for (var _i = 0, inputs_1 = inputs; _i < inputs_1.length; _i++) {
        var ref = inputs_1[_i];
        refs.push(new WaveformSAD().deserialize(ref));
    }
    return refs;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK Waveform and SAD model(s)
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Domain model
 */
var Domain = /** @class */ (function () {
    /** Constructor */
    function Domain() {
        this.properties = [];
        this.applications = [];
        this.waveforms = [];
        this.deviceManagers = [];
        this.eventChannels = [];
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    Domain.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).name = input.name;
        (/** @type {?} */ (this)).id = input.id;
        (/** @type {?} */ (this)).properties = deserializeProperties(input.properties);
        (/** @type {?} */ (this)).applications = deserializeResourceRefs(input.applications);
        (/** @type {?} */ (this)).waveforms = deserializeWaveformSADRefs(input.waveforms);
        (/** @type {?} */ (this)).deviceManagers = deserializeDeviceManagerRefs(input.deviceManagers);
        (/** @type {?} */ (this)).eventChannels = input.eventChannels;
        return (/** @type {?} */ (this));
    };
    return Domain;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK Domain Model(s) interfaces
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var AdministrativeState = {
    LOCKED: 0,
    UNLOCKED: 1,
    SHUTTING_DOWN: 2,
    UNKNOWN: 3,
};
AdministrativeState[AdministrativeState.LOCKED] = 'LOCKED';
AdministrativeState[AdministrativeState.UNLOCKED] = 'UNLOCKED';
AdministrativeState[AdministrativeState.SHUTTING_DOWN] = 'SHUTTING_DOWN';
AdministrativeState[AdministrativeState.UNKNOWN] = 'UNKNOWN';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var OperationalState = {
    ENABLED: 0,
    DISABLED: 1,
    UNKNOWN: 2,
};
OperationalState[OperationalState.ENABLED] = 'ENABLED';
OperationalState[OperationalState.DISABLED] = 'DISABLED';
OperationalState[OperationalState.UNKNOWN] = 'UNKNOWN';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var StateChangeCategory = {
    ADMINISTRATIVE_STATE_EVENT: 0,
    OPERATIONAL_STATE_EVENT: 1,
    USAGE_STATE_EVENT: 2,
    UNKNOWN: 3,
};
StateChangeCategory[StateChangeCategory.ADMINISTRATIVE_STATE_EVENT] = 'ADMINISTRATIVE_STATE_EVENT';
StateChangeCategory[StateChangeCategory.OPERATIONAL_STATE_EVENT] = 'OPERATIONAL_STATE_EVENT';
StateChangeCategory[StateChangeCategory.USAGE_STATE_EVENT] = 'USAGE_STATE_EVENT';
StateChangeCategory[StateChangeCategory.UNKNOWN] = 'UNKNOWN';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var UsageState = {
    IDLE: 0,
    ACTIVE: 1,
    BUSY: 2,
    UNKNOWN: 3,
};
UsageState[UsageState.IDLE] = 'IDLE';
UsageState[UsageState.ACTIVE] = 'ACTIVE';
UsageState[UsageState.BUSY] = 'BUSY';
UsageState[UsageState.UNKNOWN] = 'UNKNOWN';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * IDM Event Enumerations
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This is a false "type" since AbnormalComponentTerminationEvent shares
 * nothing with the *StateEvent types.  We're doing this here because there is
 * no other appopriate way to describe this fact that Angular will accept
 * since union types do not become JS code.  Hence we use this abstract class
 * for the sake of simplifying downstream logic.
 * @abstract
 */
var IdmEvent = /** @class */ (function () {
    function IdmEvent() {
    }
    return IdmEvent;
}());
/**
 * Typeguard simply for interface parity between the ODM and IDM event
 * interfaces.  Yes, this is logically obvious at this time since all ODM
 * events thus far in the API can inherit from OdmEvent.
 * @param {?} event
 * @return {?}
 */
function isIdmEvent(event) {
    return event instanceof IdmEvent;
}

var __extends$11 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK IDM Abnormal Component Termination Event model
 */
var AbnormalComponentTerminationEvent = /** @class */ (function (_super) {
    __extends$11(AbnormalComponentTerminationEvent, _super);
    function AbnormalComponentTerminationEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    AbnormalComponentTerminationEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).deviceId = input.deviceId;
        (/** @type {?} */ (this)).componentId = input.componentId;
        (/** @type {?} */ (this)).applicationId = input.applicationId;
        return (/** @type {?} */ (this));
    };
    return AbnormalComponentTerminationEvent;
}(IdmEvent));

var __extends$13 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable, Generic IDM state event base class
 * @template T
 */
var IdmStateEvent = /** @class */ (function (_super) {
    __extends$13(IdmStateEvent, _super);
    function IdmStateEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    IdmStateEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).sourceId = input.sourceId;
        return (/** @type {?} */ (this));
    };
    return IdmStateEvent;
}(IdmEvent));

var __extends$12 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK IDM Administrative State Event
 */
var AdministrativeStateEvent = /** @class */ (function (_super) {
    __extends$12(AdministrativeStateEvent, _super);
    function AdministrativeStateEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    AdministrativeStateEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).stateChangeFrom = fromString(input.stateChangeFrom.value);
        (/** @type {?} */ (this)).stateChangeTo = fromString(input.stateChangeTo.value);
        return (/** @type {?} */ (this));
    };
    return AdministrativeStateEvent;
}(IdmStateEvent));
/**
 * Internal helper function for converting to the enumeration value.
 * @param {?} category
 * @return {?}
 */
function fromString(category) {
    /** @type {?} */
    var out = AdministrativeState.UNKNOWN;
    switch (category) {
        case 'LOCKED':
            out = AdministrativeState.LOCKED;
            break;
        case 'UNLOCKED':
            out = AdministrativeState.UNLOCKED;
            break;
        case 'SHUTTING_DOWN':
            out = AdministrativeState.SHUTTING_DOWN;
            break;
        default:
            console.error('Unknown AdministrativeState: ' + category);
            break;
    }
    return out;
}

var __extends$14 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK IDM Usage State Event model
 */
var UsageStateEvent = /** @class */ (function (_super) {
    __extends$14(UsageStateEvent, _super);
    function UsageStateEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    UsageStateEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).stateChangeFrom = fromString$2(input.stateChangeFrom.value);
        (/** @type {?} */ (this)).stateChangeTo = fromString$2(input.stateChangeTo.value);
        return (/** @type {?} */ (this));
    };
    return UsageStateEvent;
}(IdmStateEvent));
/**
 * @param {?} category
 * @return {?}
 */
function fromString$2(category) {
    /** @type {?} */
    var out = UsageState.UNKNOWN;
    switch (category) {
        case 'IDLE':
            out = UsageState.IDLE;
            break;
        case 'ACTIVE':
            out = UsageState.ACTIVE;
            break;
        case 'BUSY':
            out = UsageState.BUSY;
            break;
        default:
            console.error('Unknown UsageState: ' + category);
            break;
    }
    return out;
}

var __extends$15 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK IDM Operational State Event model
 */
var OperationalStateEvent = /** @class */ (function (_super) {
    __extends$15(OperationalStateEvent, _super);
    function OperationalStateEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this data type. */
    /**
     * Deserializes a JSON object into this data type.
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    OperationalStateEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this data type.
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).stateChangeFrom = fromString$3(input.stateChangeFrom.value);
        (/** @type {?} */ (this)).stateChangeTo = fromString$3(input.stateChangeTo.value);
        return (/** @type {?} */ (this));
    };
    return OperationalStateEvent;
}(IdmStateEvent));
/**
 * @param {?} category
 * @return {?}
 */
function fromString$3(category) {
    /** @type {?} */
    var out = OperationalState.UNKNOWN;
    switch (category) {
        case 'ENABLED':
            out = OperationalState.ENABLED;
            break;
        case 'DISABLED':
            out = OperationalState.DISABLED;
            break;
        default:
            console.error('Unknown OperationalState: ' + category);
            break;
    }
    return out;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
exports.deserializeIdmEvent = (/**
 * @param {?} input
 * @return {?}
 */
function (input) {
    /** @type {?} */
    var out = null;
    if (input.hasOwnProperty('stateChangeCategory')) {
        /** @type {?} */
        var catStr = (/** @type {?} */ (input.stateChangeCategory.value));
        /** @type {?} */
        var category = fromString$1(catStr);
        switch (category) {
            case StateChangeCategory.ADMINISTRATIVE_STATE_EVENT:
                out = new AdministrativeStateEvent().deserialize(input);
                break;
            case StateChangeCategory.OPERATIONAL_STATE_EVENT:
                out = new OperationalStateEvent().deserialize(input);
                break;
            case StateChangeCategory.USAGE_STATE_EVENT:
                out = new UsageStateEvent().deserialize(input);
                break;
            default:
                console.error('Unknown StateChangeCategory: ' + catStr);
                break;
        }
    }
    else if (input.hasOwnProperty('applicationId')) {
        out = new AbnormalComponentTerminationEvent().deserialize(input);
    }
    else {
        console.error('Unknown IDM Event structure; unable to deserialize');
    }
    return out;
});
/**
 * Helper function for converting StateChangeCategory to the enumeration
 * @param {?} category
 * @return {?}
 */
function fromString$1(category) {
    /** @type {?} */
    var out = StateChangeCategory.UNKNOWN;
    switch (category) {
        case 'ADMINISTRATIVE_STATE_EVENT':
            out = StateChangeCategory.ADMINISTRATIVE_STATE_EVENT;
            break;
        case 'OPERATIONAL_STATE_EVENT':
            out = StateChangeCategory.OPERATIONAL_STATE_EVENT;
            break;
        case 'USAGE_STATE_EVENT':
            out = StateChangeCategory.USAGE_STATE_EVENT;
            break;
        default:
            console.error('Unknown StateChangeCategory: ' + category);
            break;
    }
    return out;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK IDM Event model(s) and interfaces
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK Message Events are simplified Struct properties that only convey
 * ID-Value combinations with the struct's value being a list of ID-Value
 * pairs we're calling ISimpleProperties.
 */
var RhMessage = /** @class */ (function () {
    function RhMessage() {
    }
    /** Deserializes a JSON object into a REDHAWK Message format */
    /**
     * Deserializes a JSON object into a REDHAWK Message format
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    RhMessage.prototype.deserialize = /**
     * Deserializes a JSON object into a REDHAWK Message format
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).id = input.id;
        (/** @type {?} */ (this)).value = [];
        for (var _i = 0, _a = input.value; _i < _a.length; _i++) {
            var prop = _a[_i];
            (/** @type {?} */ (this)).value.push({
                id: prop.id,
                value: prop.value
            });
        }
        return (/** @type {?} */ (this));
    };
    /**
     * Get the field IDs of the structure
     * @return {string[]} List of field IDs in this structure
     */
    /**
     * Get the field IDs of the structure
     * @return {?}
     */
    RhMessage.prototype.getFields = /**
     * Get the field IDs of the structure
     * @return {?}
     */
    function () {
        /** @type {?} */
        var fields = [];
        for (var _i = 0, _a = this.value; _i < _a.length; _i++) {
            var field = _a[_i];
            fields.push(field.id);
        }
        return fields;
    };
    /**
     * Helper function to get individual fields from the struct's list of fields.
     * @param {string} id The ID of the field/member to return
     */
    /**
     * Helper function to get individual fields from the struct's list of fields.
     * @param {?} id
     * @return {?}
     */
    RhMessage.prototype.field = /**
     * Helper function to get individual fields from the struct's list of fields.
     * @param {?} id
     * @return {?}
     */
    function (id) {
        for (var _i = 0, _a = this.value; _i < _a.length; _i++) {
            var field = _a[_i];
            if (field.id === id) {
                return field;
            }
        }
        return undefined;
    };
    /**
     * Convenience method for taking structures that have a 'value' that is a list
     * of id-value pairs like RhMessage and turning them into a 'normal' object
     * whose members are created using the de-namespaced 'id'.
     *
     * For example, an id of TestMessage::something on a field results in an object
     * with a 'something' member set to that field's value.
     * @return A populated Object from this message's members.
     */
    /**
     * Convenience method for taking structures that have a 'value' that is a list
     * of id-value pairs like RhMessage and turning them into a 'normal' object
     * whose members are created using the de-namespaced 'id'.
     *
     * For example, an id of TestMessage::something on a field results in an object
     * with a 'something' member set to that field's value.
     * @template T
     * @return {?} A populated Object from this message's members.
     */
    RhMessage.prototype.asObject = /**
     * Convenience method for taking structures that have a 'value' that is a list
     * of id-value pairs like RhMessage and turning them into a 'normal' object
     * whose members are created using the de-namespaced 'id'.
     *
     * For example, an id of TestMessage::something on a field results in an object
     * with a 'something' member set to that field's value.
     * @template T
     * @return {?} A populated Object from this message's members.
     */
    function () {
        /** @type {?} */
        var obj = (/** @type {?} */ ({}));
        for (var _i = 0, _a = this.value; _i < _a.length; _i++) {
            var field = _a[_i];
            /** @type {?} */
            var id = field.id.split('::').pop();
            obj[id] = field.value;
        }
        return obj;
    };
    return RhMessage;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Message's convey these simplified properties which are id-value pairs
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK Message Event model(s)
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var ResourceStateChange = {
    STOPPED: 0,
    STARTED: 1,
    UNKNOWN: 2,
};
ResourceStateChange[ResourceStateChange.STOPPED] = 'STOPPED';
ResourceStateChange[ResourceStateChange.STARTED] = 'STARTED';
ResourceStateChange[ResourceStateChange.UNKNOWN] = 'UNKNOWN';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var SourceCategory = {
    DEVICE_MANAGER: 0,
    DEVICE: 1,
    APPLICATION_FACTORY: 2,
    APPLICATION: 3,
    SERVICE: 4,
    UNKNOWN: 5,
};
SourceCategory[SourceCategory.DEVICE_MANAGER] = 'DEVICE_MANAGER';
SourceCategory[SourceCategory.DEVICE] = 'DEVICE';
SourceCategory[SourceCategory.APPLICATION_FACTORY] = 'APPLICATION_FACTORY';
SourceCategory[SourceCategory.APPLICATION] = 'APPLICATION';
SourceCategory[SourceCategory.SERVICE] = 'SERVICE';
SourceCategory[SourceCategory.UNKNOWN] = 'UNKNOWN';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * ODM Event Enumerations
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * All ODM Events have the same basic two properties: sourceId and sourceName.
 * This is a base class and only partially deserializes the event.
 */
var OdmEvent = /** @class */ (function () {
    function OdmEvent() {
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    OdmEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).sourceId = input.sourceId;
        (/** @type {?} */ (this)).sourceName = input.sourceName;
        return (/** @type {?} */ (this));
    };
    return OdmEvent;
}());

var __extends$16 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Base class for REDHAWK Domain Management object events (add/remove)
 */
var DomainManagementObjectEvent = /** @class */ (function (_super) {
    __extends$16(DomainManagementObjectEvent, _super);
    function DomainManagementObjectEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    DomainManagementObjectEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).producerId = input.producerId;
        return (/** @type {?} */ (this));
    };
    return DomainManagementObjectEvent;
}(OdmEvent));

var __extends$18 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Domain Object Removed Event
 */
var DomainManagementObjectRemovedEvent = /** @class */ (function (_super) {
    __extends$18(DomainManagementObjectRemovedEvent, _super);
    function DomainManagementObjectRemovedEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    DomainManagementObjectRemovedEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).sourceCategory = fromString$4(input.sourceCategory.value);
        return (/** @type {?} */ (this));
    };
    return DomainManagementObjectRemovedEvent;
}(DomainManagementObjectEvent));
/**
 * @param {?} category
 * @return {?}
 */
function fromString$4(category) {
    /** @type {?} */
    var out = SourceCategory.UNKNOWN;
    switch (category) {
        case 'DEVICE_MANAGER':
            out = SourceCategory.DEVICE_MANAGER;
            break;
        case 'DEVICE':
            out = SourceCategory.DEVICE;
            break;
        case 'APPLICATION_FACTORY':
            out = SourceCategory.APPLICATION_FACTORY;
            break;
        case 'APPLICATION':
            out = SourceCategory.APPLICATION;
            break;
        case 'SERVICE':
            out = SourceCategory.SERVICE;
            break;
        default:
            // Do anything?
            break;
    }
    return out;
}

var __extends$17 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Domain Object Added Event
 */
var DomainManagementObjectAddedEvent = /** @class */ (function (_super) {
    __extends$17(DomainManagementObjectAddedEvent, _super);
    function DomainManagementObjectAddedEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    DomainManagementObjectAddedEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).sourceIOR = {};
        return (/** @type {?} */ (this));
    };
    return DomainManagementObjectAddedEvent;
}(DomainManagementObjectRemovedEvent));

var __extends$19 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK ODM Resource State Change Event
 */
var ResourceStateChangeEvent = /** @class */ (function (_super) {
    __extends$19(ResourceStateChangeEvent, _super);
    function ResourceStateChangeEvent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    ResourceStateChangeEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).stateChangeFrom = fromString$5(input.stateChangeFrom.value);
        (/** @type {?} */ (this)).stateChangeTo = fromString$5(input.stateChangeTo.value);
        return (/** @type {?} */ (this));
    };
    return ResourceStateChangeEvent;
}(OdmEvent));
/**
 * @param {?} state
 * @return {?}
 */
function fromString$5(state) {
    /** @type {?} */
    var out = ResourceStateChange.UNKNOWN;
    switch (state) {
        case 'STOPPED':
            out = ResourceStateChange.STOPPED;
            break;
        case 'STARTED':
            out = ResourceStateChange.STARTED;
            break;
        default:
            // Do anything?
            break;
    }
    return out;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
exports.deserializeOdmEvent = (/**
 * @param {?} input
 * @return {?}
 */
function (input) {
    if (input.hasOwnProperty('producerId')) {
        if (input.hasOwnProperty('sourceIOR')) {
            return new DomainManagementObjectAddedEvent().deserialize(input);
        }
        else {
            return new DomainManagementObjectRemovedEvent().deserialize(input);
        }
    }
    else if (input.hasOwnProperty('stateChangeFrom')) {
        return new ResourceStateChangeEvent().deserialize(input);
    }
    return null;
});

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK ODM Event model(s) and interfaces
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * All REDHAWK Event and Message model(s) and interfaces
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK Model of the SCA FileSystem interface.
 */
var FileSystem = /** @class */ (function () {
    /** Constructor */
    function FileSystem() {
        this.files = [];
        this.directories = [];
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    FileSystem.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).files = input.files;
        (/** @type {?} */ (this)).directories = input.directories;
        (/** @type {?} */ (this)).contents = input.contents;
        return (/** @type {?} */ (this));
    };
    return FileSystem;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Module for the SCA FileSystem model(s)
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Serializable REDHAWK 'Redhawk' top-level model which is a domain listing.
 */
var Redhawk = /** @class */ (function () {
    /** constructor */
    function Redhawk() {
        this.domains = [];
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    Redhawk.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        (/** @type {?} */ (this)).domains = input.domains;
        return (/** @type {?} */ (this));
    };
    return Redhawk;
}());

var __extends$20 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Represents REDHAWK update event structure indicating the state of domain
 * changes (added, removed, current listing)
 */
var RedhawkEvent = /** @class */ (function (_super) {
    __extends$20(RedhawkEvent, _super);
    /** Constructor */
    function RedhawkEvent() {
        var _this = _super.call(this) || this;
        _this.added = [];
        _this.removed = [];
        return _this;
    }
    /** Deserializes a JSON object into this class */
    /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    RedhawkEvent.prototype.deserialize = /**
     * Deserializes a JSON object into this class
     * @template THIS
     * @this {THIS}
     * @param {?} input
     * @return {THIS}
     */
    function (input) {
        _super.prototype.deserialize.call(this, input);
        (/** @type {?} */ (this)).added = input.added;
        (/** @type {?} */ (this)).removed = input.removed;
        return (/** @type {?} */ (this));
    };
    return RedhawkEvent;
}(Redhawk));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK top-level REDHAWK model and event
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This is a utility module useful for serializing JSON objects from the server
 * into useful models on the client side.
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This module represents all models and serialization that exist in the
 * REST-Python server and sockets interfaces that can be retrieved and managed
 * using Angular-REDHAWK's services and directives.
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Behaves like a toString() operator inside templates for the AdministrativeState
 * enumeration.
 */
var AdministrativeStatePipe = /** @class */ (function () {
    function AdministrativeStatePipe() {
    }
    /**
     * @param {?} state
     * @return {?}
     */
    AdministrativeStatePipe.prototype.transform = /**
     * @param {?} state
     * @return {?}
     */
    function (state) {
        return AdministrativeState[state];
    };
    AdministrativeStatePipe.decorators = [
        { type: core.Pipe, args: [{ name: 'administrativeState' },] },
    ];
    return AdministrativeStatePipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Behaves like a toString() operator inside templates for the OperationalState
 * enumeration
 */
var OperationalStatePipe = /** @class */ (function () {
    function OperationalStatePipe() {
    }
    /**
     * @param {?} state
     * @return {?}
     */
    OperationalStatePipe.prototype.transform = /**
     * @param {?} state
     * @return {?}
     */
    function (state) {
        return OperationalState[state];
    };
    OperationalStatePipe.decorators = [
        { type: core.Pipe, args: [{ name: 'operationalState' },] },
    ];
    return OperationalStatePipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 *  Behaves like a toString() operator inside templates for the UsageState enumeration
 */
var UsageStatePipe = /** @class */ (function () {
    function UsageStatePipe() {
    }
    /**
     * @param {?} state
     * @return {?}
     */
    UsageStatePipe.prototype.transform = /**
     * @param {?} state
     * @return {?}
     */
    function (state) {
        return UsageState[state];
    };
    UsageStatePipe.decorators = [
        { type: core.Pipe, args: [{ name: 'usageState' },] },
    ];
    return UsageStatePipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This is a factory that returns websocket instances in the form of Subjects.
 * The Subject `subscribe` and `unsubscribe` methods are bound to opening and
 * closing the socket, respectively.  When subscribing, map the output to the
 * type you expect.  Sometimes it's helpful to map this response into your own
 * local subject or observable, behaving as the buffer abstraction for your
 * design.  Use `next` to send data back through the socket.
 * @param {?} url
 * @param {?=} type
 * @return {?}
 */
function basicSocket(url, type) {
    type = type || 'blob';
    /** @type {?} */
    var ws = new WebSocket(url);
    /** @type {?} */
    var buffer = [];
    /**
     * @param {?} data
     * @return {?}
     */
    function handleData(data) {
        if (type === 'blob') {
            return JSON.stringify(data);
        }
        else {
            return data;
        }
    }
    /** @type {?} */
    var observable = rxjs.Observable.create((/**
     * @param {?} obs
     * @return {?}
     */
    function (obs) {
        ws.binaryType = type;
        ws.onmessage = (/**
         * @param {?} msg
         * @return {?}
         */
        function (msg) {
            if (msg.data instanceof ArrayBuffer) {
                obs.next(msg);
            }
            else {
                /** @type {?} */
                var newMsg = new MessageEvent(msg.type, {
                    data: msg.data.replace(/(\s?)(Infinity|-Infinity|NaN)(\s?\,?)/g, '$1\"$2\"$3'),
                    origin: msg.origin,
                    source: msg.source,
                    // msg.ports is readonly, and cannot be assigned to ports without copying first
                    ports: msg.ports.slice(0)
                });
                obs.next(newMsg);
            }
        });
        ws.onerror = obs.error.bind(obs);
        ws.onclose = obs.complete.bind(obs);
        ws.onopen = (/**
         * @return {?}
         */
        function () {
            /** @type {?} */
            var l = buffer.length;
            while (l--) {
                ws.send(handleData(buffer[l]));
                buffer.splice(l, 1);
            }
        });
        return ws.close.bind(ws);
    }));
    /** @type {?} */
    var observer = {
        next: (/**
         * @param {?} data
         * @return {?}
         */
        function (data) {
            switch (ws.readyState) {
                case WebSocket.OPEN:
                    ws.send(handleData(data));
                    break;
                case WebSocket.CONNECTING:
                    buffer.push(data);
                    break;
                case WebSocket.CLOSED:
                    alert('Attempted to send data and WebSocket is closed');
                    break;
                default:
                    break;
            }
        })
    };
    return rxjs.Subject.create(observer, observable);
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Models, URL service, and basic socket creator
/**
 * The EventChannelService is a basic event channel interface.  You can
 * subscribe to any channel (WebSocket topics) based on domain ID.
 */
var EventChannelService = /** @class */ (function () {
    /**
     * Constructor
     * @param restPython The REST Python service for mapping to the socket interface
     */
    function EventChannelService(restPython) {
        this.socketInterface = (/** @type {?} */ (basicSocket(restPython.eventSocketUrl())
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            /** @type {?} */
            var data = JSON.parse(response.data);
            if (data.hasOwnProperty('id') && data.hasOwnProperty('value')) {
                /** @type {?} */
                var retval = new RhMessage().deserialize(data);
                return retval;
            }
            else if (data.hasOwnProperty('sourceName')) {
                /** @type {?} */
                var retval = exports.deserializeOdmEvent(data);
                return retval;
            }
            else if (data.hasOwnProperty('stateChangeFrom')) {
                /** @type {?} */
                var retval = exports.deserializeIdmEvent(data);
                return retval;
            }
            else {
                console.error('Event Received is not of a recognized type.');
                return null;
            }
        })))));
    }
    Object.defineProperty(EventChannelService.prototype, "events$", {
        /**
         * All events coming from this web socket
         */
        get: /**
         * All events coming from this web socket
         * @return {?}
         */
        function () {
            return (/** @type {?} */ (this.socketInterface.asObservable()));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Connects to the named event channel per the provided domain ID
     * @param {string} domainId The Domain ID for the event channel
     * @param {string} channelName The event channel to listen to
     */
    /**
     * Connects to the named event channel per the provided domain ID
     * @param {?} domainId
     * @param {?} channelName
     * @return {?}
     */
    EventChannelService.prototype.connect = /**
     * Connects to the named event channel per the provided domain ID
     * @param {?} domainId
     * @param {?} channelName
     * @return {?}
     */
    function (domainId, channelName) {
        /** @type {?} */
        var cmd = {
            command: 'ADD',
            domainId: domainId,
            topic: channelName
        };
        this.socketInterface.next(cmd);
    };
    /**
     * Disconnects from the named event channel per the provided domain ID
     * @param {string} domainId The Domain ID for the event channel
     * @param {string} channelName The event channel to stop listening to
     */
    /**
     * Disconnects from the named event channel per the provided domain ID
     * @param {?} domainId
     * @param {?} channelName
     * @return {?}
     */
    EventChannelService.prototype.disconnect = /**
     * Disconnects from the named event channel per the provided domain ID
     * @param {?} domainId
     * @param {?} channelName
     * @return {?}
     */
    function (domainId, channelName) {
        /** @type {?} */
        var cmd = {
            command: 'REMOVE',
            domainId: domainId,
            topic: channelName
        };
        this.socketInterface.next(cmd);
    };
    /**
     * FUTURE USE
     * @param payload The object to send across the socket.
     */
    /**
     * FUTURE USE
     * @param {?} payload The object to send across the socket.
     * @return {?}
     */
    EventChannelService.prototype.send = /**
     * FUTURE USE
     * @param {?} payload The object to send across the socket.
     * @return {?}
     */
    function (payload) {
        alert('This method is reserved for future use.');
    };
    EventChannelService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    EventChannelService.ctorParameters = function () { return [
        { type: RestPythonService }
    ]; };
    return EventChannelService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The command interface for adding or removing event channels to the socket.
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Generic Event Channel socket and control
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Provides an instantiation of the IDM Listener Service
 * @param {?} ecs An EventChannelService instance to utilize
 * @return {?}
 */
function configureIdmListenerService(ecs) {
    /** @type {?} */
    var s = new IdmListenerService(ecs);
    return s;
}
/**
 * Returns providers for a pre-configured ODM Listener Service
 * @return {?}
 */
function idmListenerServiceProvider() {
    return [
        EventChannelService,
        {
            provide: IdmListenerService,
            useFactory: configureIdmListenerService,
            deps: [EventChannelService]
        }
    ];
}
/**
 * The IdmListenerService is similar to the IDMListener in the REDHAWK sandbox.
 */
var IdmListenerService = /** @class */ (function () {
    /**
     * Constructor
     * @param eventChannel The Event Channel (Service) to use for connections
     */
    function IdmListenerService(eventChannel) {
        var _this = this;
        this.eventChannel = eventChannel;
        this.allEvents = new rxjs.Subject();
        this.administrativeStateChanged = new rxjs.Subject();
        this.operationalStateChanged = new rxjs.Subject();
        this.usageStateChanged = new rxjs.Subject();
        this.abnormalComponentTerminationChanged = new rxjs.Subject();
        this.eventChannel
            .events$
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        function (data) {
            if (data instanceof IdmEvent) {
                _this.allEvents.next(data);
                if (data instanceof AdministrativeStateEvent) {
                    _this.administrativeStateChanged.next(data);
                }
                else if (data instanceof OperationalStateEvent) {
                    _this.operationalStateChanged.next(data);
                }
                else if (data instanceof UsageStateEvent) {
                    _this.usageStateChanged.next(data);
                }
                else if (data instanceof AbnormalComponentTerminationEvent) {
                    _this.abnormalComponentTerminationChanged.next(data);
                }
            }
        }));
    }
    Object.defineProperty(IdmListenerService.prototype, "allEvents$", {
        /**
         * Observable for all possible events on the IDM Channel
         */
        get: /**
         * Observable for all possible events on the IDM Channel
         * @return {?}
         */
        function () {
            return this.allEvents.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IdmListenerService.prototype, "administrativeStateChanged$", {
        /**
         * Observable for specifically Administrative State Changed events.
         */
        get: /**
         * Observable for specifically Administrative State Changed events.
         * @return {?}
         */
        function () {
            return this.administrativeStateChanged.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IdmListenerService.prototype, "operationalStateChanged$", {
        /**
         * Observable for specifically Operational State Changed events.
         */
        get: /**
         * Observable for specifically Operational State Changed events.
         * @return {?}
         */
        function () {
            return this.operationalStateChanged.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IdmListenerService.prototype, "usageStateChanged$", {
        /**
         * Observable for specifically Usage State Changed events.
         */
        get: /**
         * Observable for specifically Usage State Changed events.
         * @return {?}
         */
        function () {
            return this.usageStateChanged.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IdmListenerService.prototype, "abnormalComponentTerminationChanged$", {
        /**
         * Observable for specifically Abnormal Component Termination Changed events.
         */
        get: /**
         * Observable for specifically Abnormal Component Termination Changed events.
         * @return {?}
         */
        function () {
            return this.abnormalComponentTerminationChanged.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Connect to a Domain's IDM Event Channel
     * @param domainId The Domain ID (Name)
     */
    /**
     * Connect to a Domain's IDM Event Channel
     * @param {?} domainId The Domain ID (Name)
     * @return {?}
     */
    IdmListenerService.prototype.connect = /**
     * Connect to a Domain's IDM Event Channel
     * @param {?} domainId The Domain ID (Name)
     * @return {?}
     */
    function (domainId) {
        this.eventChannel.connect(domainId, 'IDM_Channel');
    };
    /**
     * Disconnect from a Domain's IDM Event Channel
     * @param domainId The Domain ID (Name)
     */
    /**
     * Disconnect from a Domain's IDM Event Channel
     * @param {?} domainId The Domain ID (Name)
     * @return {?}
     */
    IdmListenerService.prototype.disconnect = /**
     * Disconnect from a Domain's IDM Event Channel
     * @param {?} domainId The Domain ID (Name)
     * @return {?}
     */
    function (domainId) {
        this.eventChannel.disconnect(domainId, 'IDM_Channel');
    };
    IdmListenerService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    IdmListenerService.ctorParameters = function () { return [
        { type: EventChannelService }
    ]; };
    return IdmListenerService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// All pipes defined in this module
/** @type {?} */
var PIPES = [
    AdministrativeStatePipe,
    OperationalStatePipe,
    UsageStatePipe
];
/**
 * The IDM Event Module
 */
var IdmEventModule = /** @class */ (function () {
    function IdmEventModule() {
    }
    IdmEventModule.decorators = [
        { type: core.NgModule, args: [{
                    exports: PIPES,
                    declarations: PIPES
                },] },
    ];
    return IdmEventModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Acts like 'toString' for the ResourceStateChange enumeration
 */
var ResourceStateChangePipe = /** @class */ (function () {
    function ResourceStateChangePipe() {
    }
    /**
     * @param {?} change
     * @return {?}
     */
    ResourceStateChangePipe.prototype.transform = /**
     * @param {?} change
     * @return {?}
     */
    function (change) {
        return ResourceStateChange[change];
    };
    ResourceStateChangePipe.decorators = [
        { type: core.Pipe, args: [{ name: 'resourceStateChange' },] },
    ];
    return ResourceStateChangePipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Acts like 'toString' for the SourceCategory enumeration
 */
var SourceCategoryPipe = /** @class */ (function () {
    function SourceCategoryPipe() {
    }
    /**
     * @param {?} category
     * @return {?}
     */
    SourceCategoryPipe.prototype.transform = /**
     * @param {?} category
     * @return {?}
     */
    function (category) {
        return SourceCategory[category];
    };
    SourceCategoryPipe.decorators = [
        { type: core.Pipe, args: [{ name: 'arSourceCategory' },] },
    ];
    return SourceCategoryPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The ODM Event Channel name
 * @type {?}
 */
var ODM_CHANNEL_NAME = 'ODM_Channel';
/**
 * Provides an instantiation of the ODM Listener Service
 * @param {?} ecs An EventChannelService instance to utilize
 * @return {?}
 */
function configureOdmListenerService(ecs) {
    /** @type {?} */
    var s = new OdmListenerService(ecs);
    return s;
}
/**
 * Returns providers for a pre-configured ODM Listener Service
 * @return {?}
 */
function odmListenerServiceProvider() {
    return [
        EventChannelService,
        {
            provide: OdmListenerService,
            useFactory: configureOdmListenerService,
            deps: [EventChannelService]
        }
    ];
}
/**
 * The OdmListenerService is similar to the ODMListener in the REDHAWK sandbox.
 */
var OdmListenerService = /** @class */ (function () {
    /**
     * Constructor
     * @param eventChannel The Event Channel (Service) to use for connections
     */
    function OdmListenerService(eventChannel) {
        var _this = this;
        this.eventChannel = eventChannel;
        this.allEvents = new rxjs.Subject();
        this.deviceManagerAdded = new rxjs.Subject();
        this.deviceManagerRemoved = new rxjs.Subject();
        this.deviceAdded = new rxjs.Subject();
        this.deviceRemoved = new rxjs.Subject();
        this.applicationFactoryAdded = new rxjs.Subject();
        this.applicationFactoryRemoved = new rxjs.Subject();
        this.applicationAdded = new rxjs.Subject();
        this.applicationRemoved = new rxjs.Subject();
        this.serviceAdded = new rxjs.Subject();
        this.serviceRemoved = new rxjs.Subject();
        this.eventChannel
            .events$
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        function (data) {
            if (data instanceof OdmEvent) {
                _this.allEvents.next(data);
                if (data instanceof DomainManagementObjectAddedEvent) {
                    _this.handleAdd(data);
                }
                else if (data instanceof DomainManagementObjectRemovedEvent) {
                    _this.handleRemove(data);
                }
            }
        }));
    }
    Object.defineProperty(OdmListenerService.prototype, "allEvents$", {
        /**
         * Obsevable for all possible events on the ODM Event Channel
         */
        get: /**
         * Obsevable for all possible events on the ODM Event Channel
         * @return {?}
         */
        function () {
            return this.allEvents.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "deviceManagerAdded$", {
        /**
         * Observable for specifically Device Manager Added events.
         */
        get: /**
         * Observable for specifically Device Manager Added events.
         * @return {?}
         */
        function () {
            return this.deviceManagerAdded.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "deviceManagerRemoved$", {
        /**
         * Observable for specifically DeviceManager Removed events.
         */
        get: /**
         * Observable for specifically DeviceManager Removed events.
         * @return {?}
         */
        function () {
            return this.deviceManagerRemoved.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "deviceAdded$", {
        /**
         * Observable for specifically Device Added events.
         */
        get: /**
         * Observable for specifically Device Added events.
         * @return {?}
         */
        function () {
            return this.deviceAdded.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "deviceRemoved$", {
        /**
         * Observable for specifically Device Removed events.
         */
        get: /**
         * Observable for specifically Device Removed events.
         * @return {?}
         */
        function () {
            return this.deviceRemoved.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "applicationFactoryAdded$", {
        /**
         * Observable for specifically Application Factory Added events.
         */
        get: /**
         * Observable for specifically Application Factory Added events.
         * @return {?}
         */
        function () {
            return this.applicationFactoryAdded.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "applicationFactoryRemoved$", {
        /**
         * Observable for specifically Application Factory Removed events.
         */
        get: /**
         * Observable for specifically Application Factory Removed events.
         * @return {?}
         */
        function () {
            return this.applicationFactoryRemoved.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "applicationAdded$", {
        /**
         * Observable for specifically Application Added events.
         */
        get: /**
         * Observable for specifically Application Added events.
         * @return {?}
         */
        function () {
            return this.applicationAdded.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "applicationRemoved$", {
        /**
         * Observable for specifically Application Removed events.
         */
        get: /**
         * Observable for specifically Application Removed events.
         * @return {?}
         */
        function () {
            return this.applicationRemoved.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "serviceAdded$", {
        /**
         * Observable for specifically Service Added events.
         */
        get: /**
         * Observable for specifically Service Added events.
         * @return {?}
         */
        function () {
            return this.serviceAdded.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OdmListenerService.prototype, "serviceRemoved$", {
        /**
         * Observable for specifically Service Removed events.
         */
        get: /**
         * Observable for specifically Service Removed events.
         * @return {?}
         */
        function () {
            return this.serviceRemoved.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Connect to a Domain's ODM Event Channel
     * @param domainId The Domain ID (Name)
     */
    /**
     * Connect to a Domain's ODM Event Channel
     * @param {?} domainId The Domain ID (Name)
     * @return {?}
     */
    OdmListenerService.prototype.connect = /**
     * Connect to a Domain's ODM Event Channel
     * @param {?} domainId The Domain ID (Name)
     * @return {?}
     */
    function (domainId) {
        this.eventChannel.connect(domainId, ODM_CHANNEL_NAME);
    };
    /**
     * Disconnect from a Domain's ODM Event Channel
     * @param domainId The Domain ID (Name)
     */
    /**
     * Disconnect from a Domain's ODM Event Channel
     * @param {?} domainId The Domain ID (Name)
     * @return {?}
     */
    OdmListenerService.prototype.disconnect = /**
     * Disconnect from a Domain's ODM Event Channel
     * @param {?} domainId The Domain ID (Name)
     * @return {?}
     */
    function (domainId) {
        this.eventChannel.disconnect(domainId, ODM_CHANNEL_NAME);
    };
    /**
     * Uses the event's source category to determine the subject to update.
     * @param event The Event to handle
     */
    /**
     * Uses the event's source category to determine the subject to update.
     * @private
     * @param {?} event The Event to handle
     * @return {?}
     */
    OdmListenerService.prototype.handleAdd = /**
     * Uses the event's source category to determine the subject to update.
     * @private
     * @param {?} event The Event to handle
     * @return {?}
     */
    function (event) {
        switch (event.sourceCategory) {
            case SourceCategory.DEVICE_MANAGER:
                this.deviceManagerAdded.next(event);
                break;
            case SourceCategory.DEVICE:
                this.deviceAdded.next(event);
                break;
            case SourceCategory.APPLICATION_FACTORY:
                this.applicationFactoryAdded.next(event);
                break;
            case SourceCategory.APPLICATION:
                this.applicationAdded.next(event);
                break;
            case SourceCategory.SERVICE:
                this.serviceAdded.next(event);
                break;
            default:
                break;
        }
    };
    /**
     * Uses the event's source category to determine the subject to update.
     * @param event The Event to handle
     */
    /**
     * Uses the event's source category to determine the subject to update.
     * @private
     * @param {?} event The Event to handle
     * @return {?}
     */
    OdmListenerService.prototype.handleRemove = /**
     * Uses the event's source category to determine the subject to update.
     * @private
     * @param {?} event The Event to handle
     * @return {?}
     */
    function (event) {
        switch (event.sourceCategory) {
            case SourceCategory.DEVICE_MANAGER:
                this.deviceManagerRemoved.next(event);
                break;
            case SourceCategory.DEVICE:
                this.deviceRemoved.next(event);
                break;
            case SourceCategory.APPLICATION_FACTORY:
                this.applicationFactoryRemoved.next(event);
                break;
            case SourceCategory.APPLICATION:
                this.applicationRemoved.next(event);
                break;
            case SourceCategory.SERVICE:
                this.serviceRemoved.next(event);
                break;
            default:
                break;
        }
    };
    OdmListenerService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    OdmListenerService.ctorParameters = function () { return [
        { type: EventChannelService }
    ]; };
    return OdmListenerService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var PIPES$1 = [
    ResourceStateChangePipe,
    SourceCategoryPipe
];
/**
 * REDHAWK ODM Event Module
 */
var OdmEventModule = /** @class */ (function () {
    function OdmEventModule() {
    }
    OdmEventModule.decorators = [
        { type: core.NgModule, args: [{
                    exports: PIPES$1,
                    declarations: PIPES$1
                },] },
    ];
    return OdmEventModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Submodules
/**
 * The Event Channel Module represents all traffic that can occur on a REDHAWK
 * Event Channel including ODM, IDM, and Messages.
 */
var EventChannelModule = /** @class */ (function () {
    function EventChannelModule() {
    }
    EventChannelModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        RestPythonModule,
                        IdmEventModule,
                        OdmEventModule
                    ],
                    exports: [
                        IdmEventModule,
                        OdmEventModule
                    ]
                },] },
    ];
    return EventChannelModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var ControlType = {
    /**
    * ==========================================================================
    * X DIMENSION
    * ==========================================================================
    */
    /**
     * Adjusts the maximum "width" of the incoming data, forcing a neighbor-mean
     * at the server to reduce the amount of data received at the client.
     * If `value` is positive, the server will attempt to accommodate that width
     * of data.  Setting `value` to 0 or a negative value disables this feature.
     */
    xMax: 0,
    /**
     * Sets the beginning index for a zoom function. The indices are inclusive,
     * and they are based on the data received at the UI, meaning they are based
     * on data that is more than likely down-sampled. The server adjusts the
     * indices for the actual packet size. This parameter does not take effect
     * until the zoom level is set greater than 0.
     */
    xBegin: 1,
    /**
     * Sets the ending index for a zoom function. The indices are inclusive,
     * and they are based on the data received at the UI, meaning they are based
     * on data that is more than likely down-sampled. The server adjusts the
     * indices for the actual packet size. This parameter does not take effect
     * until the zoom level is set greater than 0.
     */
    xEnd: 2,
    /**
     * Commands a zoom-in with the current xBegin and xEnd. The value does not
     * matter since issuing the command will trigger the zoom in.
     */
    xZoomIn: 3,
    /**
     * Commands a zoom reset to remove xBegin and xEnd. The value does not
     * matter since issuing the command will trigger the zoom reset.
     */
    xZoomReset: 4,
    /**
    * ==========================================================================
    * Y DIMENSION
    * ==========================================================================
    */
    /**
     * Adjusts the maximum "width" of the incoming data, forcing a neighbor-mean
     * at the server to reduce the amount of data received at the client.
     * If `value` is positive, the server will attempt to accommodate that width
     * of data.  Setting `value` to 0 or a negative value disables this feature.
     */
    yMax: 5,
    /**
     * Sets the beginning index for a zoom function. The indices are inclusive,
     * and they are based on the data received at the UI, meaning they are based
     * on data that is more than likely down-sampled. The server adjusts the
     * indices for the actual packet size. This parameter does not take effect
     * until the zoom level is set greater than 0.
     */
    yBegin: 6,
    /**
     * Sets the ending index for a zoom function. The indices are inclusive,
     * and they are based on the data received at the UI, meaning they are based
     * on data that is more than likely down-sampled. The server adjusts the
     * indices for the actual packet size. This parameter does not take effect
     * until the zoom level is set greater than 0.
     */
    yEnd: 7,
    /**
     * Commands a zoom-in with the current yBegin and yEnd. The value does not
     * matter since issuing the command will trigger the zoom in.
     */
    yZoomIn: 8,
    /**
     * Commands a zoom reset to remove yBegin and yEnd. The value does not
     * matter since issuing the command will trigger the zoom reset.
     */
    yZoomReset: 9,
    /**
     * Controls the maximum number of packets per second sent by the server.
     * This reduces the amount of data received at the client by dropping
     * bulkio messages at the server.
     *
     * Only positive numbers are interpreted.
     *
     * This does not guarantee the server will achieve this maximum.
     */
    MaxPPS: 10,
};
ControlType[ControlType.xMax] = 'xMax';
ControlType[ControlType.xBegin] = 'xBegin';
ControlType[ControlType.xEnd] = 'xEnd';
ControlType[ControlType.xZoomIn] = 'xZoomIn';
ControlType[ControlType.xZoomReset] = 'xZoomReset';
ControlType[ControlType.yMax] = 'yMax';
ControlType[ControlType.yBegin] = 'yBegin';
ControlType[ControlType.yEnd] = 'yEnd';
ControlType[ControlType.yZoomIn] = 'yZoomIn';
ControlType[ControlType.yZoomReset] = 'yZoomReset';
ControlType[ControlType.MaxPPS] = 'MaxPPS';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var BULKIO_SOCKET_URL = new core.InjectionToken('bulkio.url');
/**
 * The BULKIO Listener Service provides access to BULKIO sockets including control
 * interfaces that allow additional server-side processing to lighten the network
 * and UI load (for plotting data, etc.).
 */
var BulkioListenerService = /** @class */ (function () {
    /**
     * Constructor
     * @param {string} url - The base URL (ws:// or wss://) of the port
     */
    function BulkioListenerService(url) {
        /**
         * The amount of time deserializing a packet took (diagnostics.
         */
        this._deserializeTime = 0;
        /**
         * Length of the packet
         */
        this._packetLength = 0;
        /**
         * Packet's subsize
         */
        this._packetSubsize = 0;
        /**
         * Mode of the packet
         */
        this._packetMode = 0;
        this._url = url;
        this.packet = new rxjs.Subject();
        this.disconnect();
    }
    Object.defineProperty(BulkioListenerService.prototype, "url", {
        /** Get the current URL */
        get: /**
         * Get the current URL
         * @return {?}
         */
        function () { return this._url; },
        /** Set the URL.  If connected, this will disconnect and reconnect */
        set: /**
         * Set the URL.  If connected, this will disconnect and reconnect
         * @param {?} url
         * @return {?}
         */
        function (url) {
            this._url = url;
            if (this.connected) {
                this.disconnect();
                this.connect(this._connectionId);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "packet$", {
        /**
         * Subscribe to receive the bulkio packets.
         * @member {Observable<BulkioPacket>}
         */
        get: /**
         * Subscribe to receive the bulkio packets.
         * \@member {Observable<BulkioPacket>}
         * @return {?}
         */
        function () {
            return (/** @type {?} */ (this.packet.asObservable()));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "deserializeTime", {
        /**
         * The amount of time it took to deserialize the most recent packet.
         * @member {number}
         */
        get: /**
         * The amount of time it took to deserialize the most recent packet.
         * \@member {number}
         * @return {?}
         */
        function () { return this._deserializeTime; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "packetLength", {
        /**
         * The number of data words in the most recent packet.
         * @member {number}
         */
        get: /**
         * The number of data words in the most recent packet.
         * \@member {number}
         * @return {?}
         */
        function () { return this._packetLength; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "packetSubsize", {
        /**
         * The frame size of the most recent packet.
         *      0 - One dimensional data (no frames)
         *     >0 - Two dimensional data
         * @member {number}
         */
        get: /**
         * The frame size of the most recent packet.
         *      0 - One dimensional data (no frames)
         *     >0 - Two dimensional data
         * \@member {number}
         * @return {?}
         */
        function () { return this._packetSubsize; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "packetMode", {
        /**
         * The complex flag for the most recent packet.
         *     0 - Scalar data
         *     1 - Complex data
         * @member {number}
         */
        get: /**
         * The complex flag for the most recent packet.
         *     0 - Scalar data
         *     1 - Complex data
         * \@member {number}
         * @return {?}
         */
        function () { return this._packetMode; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "xMax", {
        /**
         * Set the max number of samples for the X axis (causes inter-sample
         * averaging).  The REST Python server will try to adjust to near this limit
         * based on the data size. Setting the width to less than or equal to 0 will
         * disable this feature.
         * @param {number} value
         */
        set: /**
         * Set the max number of samples for the X axis (causes inter-sample
         * averaging).  The REST Python server will try to adjust to near this limit
         * based on the data size. Setting the width to less than or equal to 0 will
         * disable this feature.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.xMax,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "xBegin", {
        /**
         * Set the beginning index of the zoom region for the X axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {number} value
         */
        set: /**
         * Set the beginning index of the zoom region for the X axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.xBegin,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "xEnd", {
        /**
         * Set the ending index of the zoom region for the X axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {number} value
         */
        set: /**
         * Set the ending index of the zoom region for the X axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.xEnd,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "xZoomIn", {
        /**
         * Command a zoom in on the X axis. Command will be executed
         * regardless of the value set.
         * @param {number} value
         */
        set: /**
         * Command a zoom in on the X axis. Command will be executed
         * regardless of the value set.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.xZoomIn,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "xZoomReset", {
        /**
         * Command a zoom reset on the X axis. Command will be executed
         * regardless of the value set.
         * @param {number} value
         */
        set: /**
         * Command a zoom reset on the X axis. Command will be executed
         * regardless of the value set.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.xZoomReset,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "yMax", {
        /**
         * Set the max number of samples for the Y axis (causes inter-sample
         * averaging).  The REST Python server will try to adjust to near this limit
         * based on the data size. Setting the width to less than or equal to 0 will
         * disable this feature.
         * @param {number} value
         */
        set: /**
         * Set the max number of samples for the Y axis (causes inter-sample
         * averaging).  The REST Python server will try to adjust to near this limit
         * based on the data size. Setting the width to less than or equal to 0 will
         * disable this feature.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.yMax,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "yBegin", {
        /**
         * Set the beginning index of the zoom region for the Y axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {number} value
         */
        set: /**
         * Set the beginning index of the zoom region for the Y axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.yBegin,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "yEnd", {
        /**
         * Set the ending index of the zoom region for the Y axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {number} value
         */
        set: /**
         * Set the ending index of the zoom region for the Y axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.yEnd,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "yZoomIn", {
        /**
         * Command a zoom in on the Y axis. Command will be executed
         * regardless of the value set.
         * @param {number} value
         */
        set: /**
         * Command a zoom in on the Y axis. Command will be executed
         * regardless of the value set.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.yZoomIn,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "yZoomReset", {
        /**
         * Command a zoom reset on the Y axis. Command will be executed
         * regardless of the value set.
         * @param {number} value
         */
        set: /**
         * Command a zoom reset on the Y axis. Command will be executed
         * regardless of the value set.
         * @param {?} value
         * @return {?}
         */
        function (value) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.yZoomReset,
                    value: value
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "packetsPerSecond", {
        /**
         * Set the (maximum) socket data rate (packets per second)
         * @param {number} pps - The (maximum) number of packets per second to receive (< 0 to disable)
         */
        set: /**
         * Set the (maximum) socket data rate (packets per second)
         * @param {?} pps
         * @return {?}
         */
        function (pps) {
            if (this.socketInterface) {
                /** @type {?} */
                var msg = {
                    type: ControlType.MaxPPS,
                    value: pps
                };
                this.socketInterface.next(msg);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "connected", {
        /**
         * Returns whether the service is already connected.
         * @return {boolean} True: WebSocket is connected, False: it is not.
         */
        get: /**
         * Returns whether the service is already connected.
         * @return {?}
         */
        function () { return this.socketSubscription != null; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioListenerService.prototype, "active", {
        /**
         * Returns whether anything is actually subscribed to receive packets.
         * @return {boolean} True: Subscribers are present, False: No subscribers.
         */
        get: /**
         * Returns whether anything is actually subscribed to receive packets.
         * @return {?}
         */
        function () { return !this.packet.isStopped; },
        enumerable: true,
        configurable: true
    });
    /**
     * Connect to the BULKIO socket at the url.
     * @param [connectionId] The connection ID to issue (also, the allocation ID if connecting to
     *        an allocated multi-port FEI Device).
     */
    /**
     * Connect to the BULKIO socket at the url.
     * @param {?=} connectionId
     * @return {?}
     */
    BulkioListenerService.prototype.connect = /**
     * Connect to the BULKIO socket at the url.
     * @param {?=} connectionId
     * @return {?}
     */
    function (connectionId) {
        var _this = this;
        this.disconnect();
        if (this.url) {
            this._connectionId = connectionId;
            /** @type {?} */
            var connectionUrl = this.url;
            if (this._connectionId) {
                connectionUrl += '/' + this._connectionId;
            }
            this.socketInterface = (/** @type {?} */ (basicSocket(connectionUrl)
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) {
                /** @type {?} */
                var d = new Date();
                /** @type {?} */
                var start = d.getTime();
                /** @type {?} */
                var data = JSON.parse(response.data);
                /** @type {?} */
                var packet = new BulkioPacket().deserialize(data);
                /** @type {?} */
                var end = d.getTime();
                _this._deserializeTime = end - start;
                _this._packetLength = packet.dataBuffer.length;
                _this._packetSubsize = packet.SRI.subsize;
                _this._packetMode = packet.SRI.mode;
                return packet;
            })))));
            this.socketSubscription = this.socketInterface
                .subscribe((/**
             * @param {?} packet
             * @return {?}
             */
            function (packet) { return _this.packet.next((/** @type {?} */ (packet))); }));
        }
        else {
            console.error('No URL provided for websocket!');
        }
    };
    /**
     * Disconnect from the BULKIO socket.
     */
    /**
     * Disconnect from the BULKIO socket.
     * @return {?}
     */
    BulkioListenerService.prototype.disconnect = /**
     * Disconnect from the BULKIO socket.
     * @return {?}
     */
    function () {
        if (this.socketSubscription) {
            this.socketSubscription.unsubscribe();
        }
        if (this.socketInterface) {
            this.socketInterface.complete();
        }
        this.socketInterface = null;
        this.socketSubscription = null;
        this._deserializeTime = 0;
    };
    BulkioListenerService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    BulkioListenerService.ctorParameters = function () { return [
        { type: String, decorators: [{ type: core.Inject, args: [BULKIO_SOCKET_URL,] }] }
    ]; };
    return BulkioListenerService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * BULKIO Control Message format
 * \@property {ControlType} type - The type of control requested.
 * \@property {number} value - The adjustment to make.
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * REDHAWK BULKIO Socket and interfaces
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The REDHAWK Listener Service provides notifications for when Domains are
 * added and removed to the naming service.
 */
var RedhawkListenerService = /** @class */ (function () {
    /**
     * Constructor
     * @param restPython The REST Python service that provides the URL mapping to REST Python
     */
    function RedhawkListenerService(restPython) {
        this.socketInterface = (/** @type {?} */ (basicSocket(restPython.redhawkSocketUrl())
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            return new RedhawkEvent().deserialize(JSON.parse(response.data));
        })))));
    }
    Object.defineProperty(RedhawkListenerService.prototype, "events$", {
        /**
         * Observable event indicating which domains were added and removed as well as
         * the current listing of Domains.
         */
        get: /**
         * Observable event indicating which domains were added and removed as well as
         * the current listing of Domains.
         * @return {?}
         */
        function () {
            return this.socketInterface.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    RedhawkListenerService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    RedhawkListenerService.ctorParameters = function () { return [
        { type: RestPythonService }
    ]; };
    return RedhawkListenerService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Service interface to REST-Python
/**
 * The SocketsModule provides access to other modules involving websockets
 * including the event services and BULKIO data transfers.
 */
var SocketsModule = /** @class */ (function () {
    function SocketsModule() {
    }
    SocketsModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        RestPythonModule,
                        EventChannelModule
                    ],
                    exports: [
                        EventChannelModule,
                    ]
                },] },
    ];
    return SocketsModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The BaseService class is an abstract base class for all REST-Python -facing
 * service interfaces back to the REDHAWK system.  The premise of these classes
 * is that once injected, setting the uniqueId begins a process of pulling the
 * initial state of the model (which can be observed at model$).  There
 * forward, calling update() should be enough to maintain the model.
 *
 * Derived classes may also instantiate additional websocket service interfaces.
 * Please refer to the associated class for more information.
 * @abstract
 * @template T
 */
var BaseService = /** @class */ (function () {
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     */
    function BaseService(http$$1, restPython) {
        var _this = this;
        this.http = http$$1;
        this.restPython = restPython;
        this._model = new rxjs.ReplaySubject();
        this._configured = new rxjs.ReplaySubject();
        this._configured.next({ success: false, uriChanged: false });
        this._updating = false;
        this._rpChanged = this.restPython.changed$.subscribe((/**
         * @return {?}
         */
        function () {
            // Ensures that when RP URL is changed, the service tries to 
            // reconnect to the server.            
            _this.reconfigure(_this.uniqueId);
        }));
    }
    Object.defineProperty(BaseService.prototype, "isUpdating", {
        /** Returns true if this service is in the middle of updating the model */
        get: /**
         * Returns true if this service is in the middle of updating the model
         * @return {?}
         */
        function () { return this._updating; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseService.prototype, "configured$", {
        /**
         * Indicates the 'configured' state of the service.  This will be 'true' if
         * the URL is set.
         */
        get: /**
         * Indicates the 'configured' state of the service.  This will be 'true' if
         * the URL is set.
         * @return {?}
         */
        function () { return this._configured.asObservable(); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseService.prototype, "uniqueId", {
        /** Get the unique ID of the underlying system */
        get: /**
         * Get the unique ID of the underlying system
         * @return {?}
         */
        function () {
            return this._uniqueId;
        },
        /**
         * Set the unique ID of the underlying system
         * NOTE: This will cause the service to reconfigure (update).
         * @param id The new UniqueID
         */
        set: /**
         * Set the unique ID of the underlying system
         * NOTE: This will cause the service to reconfigure (update).
         * @param {?} id The new UniqueID
         * @return {?}
         */
        function (id) {
            this.reconfigure(id);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseService.prototype, "baseUrl", {
        /** Get the Base (REST) URL of this system */
        get: /**
         * Get the Base (REST) URL of this system
         * @return {?}
         */
        function () {
            return this._baseUrl;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseService.prototype, "model$", {
        /** Get an observable of this service's model */
        get: /**
         * Get an observable of this service's model
         * @return {?}
         */
        function () {
            return this._model.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Pass the observable to this method to update your local model
     * NOTE: Setting the uniqueID of this service triggers this update.
     *
     * @param {Observable<T>} obj An optional model to make the "next" model
     *        subscribers will see.
     * @param {boolean} uriChanged An optional flag indicating if this update
     *        was because of a URI change (end point change)
     */
    /**
     * Pass the observable to this method to update your local model
     * NOTE: Setting the uniqueID of this service triggers this update.
     *
     *        subscribers will see.
     *        was because of a URI change (end point change)
     * @param {?=} obj
     * @param {?=} uriChanged
     * @return {?}
     */
    BaseService.prototype.update = /**
     * Pass the observable to this method to update your local model
     * NOTE: Setting the uniqueID of this service triggers this update.
     *
     *        subscribers will see.
     *        was because of a URI change (end point change)
     * @param {?=} obj
     * @param {?=} uriChanged
     * @return {?}
     */
    function (obj, uriChanged) {
        var _this = this;
        if (uriChanged === void 0) { uriChanged = false; }
        this._updating = true;
        /** @type {?} */
        var inst = obj || this.uniqueQuery$();
        inst.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        function (o) {
            _this.modelUpdated(o);
            _this._configured.next({ success: true, uriChanged: uriChanged });
        }), (/**
         * @param {?} error
         * @return {?}
         */
        function (error) {
            _this._configured.next({ success: false, uriChanged: uriChanged });
        }), (/**
         * @return {?}
         */
        function () {
            _this._updating = false;
        }));
    };
    /** Generic error handler */
    /**
     * Generic error handler
     * @protected
     * @param {?} error
     * @return {?}
     */
    BaseService.prototype.handleError = /**
     * Generic error handler
     * @protected
     * @param {?} error
     * @return {?}
     */
    function (error) {
        /** @type {?} */
        var errMsg = (error.message) ? error.message : error.status ? error.status + " - " + error.statusText : 'Server error';
        return rxjs.throwError(errMsg);
    };
    /**
     * Call this method from a function that needs a slight delay (for the server)
     * before calling update.
     * @param msec The number of milliseconds to delay
     */
    /**
     * Call this method from a function that needs a slight delay (for the server)
     * before calling update.
     * @protected
     * @param {?=} msec The number of milliseconds to delay
     * @return {?}
     */
    BaseService.prototype.delayedUpdate = /**
     * Call this method from a function that needs a slight delay (for the server)
     * before calling update.
     * @protected
     * @param {?=} msec The number of milliseconds to delay
     * @return {?}
     */
    function (msec) {
        var _this = this;
        setTimeout((/**
         * @return {?}
         */
        function () { _this.update(); }), msec || 1000);
    };
    /**
     * This method is called when the uniqueId is set and begins the update cycle
     * which includes reconfiguring the base URL and retrieving a fresh copy
     * of the model for any subscribers to $model.
     * @param id The new Unique ID to set for reconfiguration.
     * @param force Force a reconfiguration of the service (end point(s), etc.).
     */
    /**
     * This method is called when the uniqueId is set and begins the update cycle
     * which includes reconfiguring the base URL and retrieving a fresh copy
     * of the model for any subscribers to $model.
     * @protected
     * @param {?} id The new Unique ID to set for reconfiguration.
     * @param {?=} force Force a reconfiguration of the service (end point(s), etc.).
     * @return {?}
     */
    BaseService.prototype.reconfigure = /**
     * This method is called when the uniqueId is set and begins the update cycle
     * which includes reconfiguring the base URL and retrieving a fresh copy
     * of the model for any subscribers to $model.
     * @protected
     * @param {?} id The new Unique ID to set for reconfiguration.
     * @param {?=} force Force a reconfiguration of the service (end point(s), etc.).
     * @return {?}
     */
    function (id, force) {
        if (force === void 0) { force = false; }
        /** @type {?} */
        var changed = (id !== this._uniqueId || force);
        this._uniqueId = id;
        this.setBaseUrl(id);
        this.update(undefined, changed);
    };
    /**
     * This method is called during update() calls and pushes the model to any
     * subscribers of $model.  Subclasses can overload this method to either
     * call it before or after internal changes are made related to the model.
     * @param model The model maintained by this service.
     */
    /**
     * This method is called during update() calls and pushes the model to any
     * subscribers of $model.  Subclasses can overload this method to either
     * call it before or after internal changes are made related to the model.
     * @protected
     * @param {?} model The model maintained by this service.
     * @return {?}
     */
    BaseService.prototype.modelUpdated = /**
     * This method is called during update() calls and pushes the model to any
     * subscribers of $model.  Subclasses can overload this method to either
     * call it before or after internal changes are made related to the model.
     * @protected
     * @param {?} model The model maintained by this service.
     * @return {?}
     */
    function (model) {
        this._model.next(model);
    };
    return BaseService;
}());

var __extends$22 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Abstract service extension that adds the ability to fetch the Port model.
 * @abstract
 * @template T
 */
var PortBearingService = /** @class */ (function (_super) {
    __extends$22(PortBearingService, _super);
    function PortBearingService() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Gets the port via its name or a port listing if no name is provided.
     * @param portName The name of the port
     */
    /**
     * Gets the port via its name or a port listing if no name is provided.
     * @param {?=} portName The name of the port
     * @return {?}
     */
    PortBearingService.prototype.ports$ = /**
     * Gets the port via its name or a port listing if no name is provided.
     * @param {?=} portName The name of the port
     * @return {?}
     */
    function (portName) {
        if (portName) {
            return this.http
                .get(this.restPython.portUrl(this.baseUrl, portName), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return deserializePort(response); })), operators.catchError(this.handleError));
        }
        else {
            return this.http
                .get(this.restPython.portUrl(this.baseUrl), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return deserializePorts(response['ports']); })), operators.catchError(this.handleError));
        }
    };
    return PortBearingService;
}(BaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

var __extends$21 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The REDHAWK Service provides access to the REDHAWK Model on the REST server as well as
 * serves as the starting point for the Depenency Injection (DI) hierarchy of other services
 * such as {\@link DomainService}, {\@link DeviceManagerService}, and so on.
 */
var RedhawkService = /** @class */ (function (_super) {
    __extends$21(RedhawkService, _super);
    /**
     * Constructor
     * @param http The HTTP service for REST calls
     * @param restPython The REST Python URL service
     * @param rhListenerService The REDHAWK (Domain) Listener Service
     */
    function RedhawkService(http$$1, restPython, rhListenerService) {
        var _this = _super.call(this, http$$1, restPython) || this;
        _this.http = http$$1;
        _this.restPython = restPython;
        _this.rhListenerService = rhListenerService;
        _this.modelUpdated(new Redhawk());
        _this.setBaseUrl('');
        if (_this.rhListenerService === null) {
            /** @type {?} */
            var injector = core.ReflectiveInjector.resolveAndCreate([RedhawkListenerService]);
            _this.rhListenerService = injector.get(RedhawkListenerService);
        }
        _this.rhListenerService.events$.subscribe((/**
         * @param {?} rh
         * @return {?}
         */
        function (rh) {
            _this._model.next(rh);
        }));
        return _this;
    }
    /**
     * Internal, sets up the base URL
     * @param url IGNORED
     */
    /**
     * Internal, sets up the base URL
     * @param {?} url IGNORED
     * @return {?}
     */
    RedhawkService.prototype.setBaseUrl = /**
     * Internal, sets up the base URL
     * @param {?} url IGNORED
     * @return {?}
     */
    function (url) {
        this._baseUrl = this.restPython.redhawkUrl();
    };
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    RedhawkService.prototype.uniqueQuery$ = /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    function () {
        return this.http
            .get(this.restPython.domainUrl(this.baseUrl), { responseType: 'json' })
            .pipe(operators.map((/**
         * @param {?} res
         * @return {?}
         */
        function (res) { return new Redhawk().deserialize(res); })), operators.catchError(this.handleError));
    };
    /** Get a list of online domain names */
    /**
     * Get a list of online domain names
     * @return {?}
     */
    RedhawkService.prototype.scan$ = /**
     * Get a list of online domain names
     * @return {?}
     */
    function () {
        return this.http
            .get(this.restPython.domainUrl(this.baseUrl), { responseType: 'json' })
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) { return (/** @type {?} */ (response['domains'])); })), operators.catchError(this.handleError));
    };
    /**
     * Retrieves a Domain model
     * @param domainId The Domain model to fetch (this corresponds to the Domain's "name")
     */
    /**
     * Retrieves a Domain model
     * @param {?} domainId The Domain model to fetch (this corresponds to the Domain's "name")
     * @return {?}
     */
    RedhawkService.prototype.attach$ = /**
     * Retrieves a Domain model
     * @param {?} domainId The Domain model to fetch (this corresponds to the Domain's "name")
     * @return {?}
     */
    function (domainId) {
        return this.http
            .get(this.restPython.domainUrl(this.baseUrl, domainId), { responseType: 'json' })
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) { return new Domain().deserialize(response); })), operators.catchError(this.handleError));
    };
    /** Get a list of online Event Channels */
    /**
     * Get a list of online Event Channels
     * @return {?}
     */
    RedhawkService.prototype.scanChannels$ = /**
     * Get a list of online Event Channels
     * @return {?}
     */
    function () {
        return this.http
            .get(this.restPython.eventChannelsUrl(), { responseType: 'json' })
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) { return (/** @type {?} */ (response['eventChannels'])); })), operators.catchError(this.handleError));
    };
    RedhawkService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    RedhawkService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: RestPythonService },
        { type: RedhawkListenerService, decorators: [{ type: core.Optional }] }
    ]; };
    return RedhawkService;
}(BaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} service
 * @param {?} http
 * @param {?} restPython
 * @param {?} rhls
 * @return {?}
 */
function serviceSelect(service, http$$1, restPython, rhls) {
    if (service === null) {
        service = new RedhawkService(http$$1, restPython, rhls);
    }
    return service;
}
/**
 * This is a default Service Provider factory that automatically selects the
 * "external" service (if already in the DI graph) or injects a new one using
 * the required set of external dependencies.
 * @return {?}
 */
function redhawkServiceProvider() {
    return [
        RedhawkListenerService,
        {
            provide: RedhawkService,
            useFactory: serviceSelect,
            deps: [
                [RedhawkService, new core.Optional(), new core.SkipSelf()],
                http.HttpClient,
                RestPythonService,
                RedhawkListenerService
            ]
        }
    ];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The REDHAWK Directive is the entry point, top-level directive for dependency
 * injection when accessing the REST services for a REDHAWK Domain.
 *
 * \@example
 * <div arRedhawk [(arModel)]="my_model">
 */
var RedhawkDirective = /** @class */ (function () {
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    function RedhawkDirective(service) {
        var _this = this;
        this.service = service;
        this.modelChange = new core.EventEmitter();
        this.subscription = this.service.model$.subscribe((/**
         * @param {?} it
         * @return {?}
         */
        function (it) {
            _this.model = it;
            _this.modelChange.emit(_this.model);
        }));
    }
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @return {?}
     */
    RedhawkDirective.prototype.ngOnInit = /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @return {?}
     */
    function () {
        this.service.uniqueId = this.serviceName || 'Default';
    };
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    RedhawkDirective.prototype.ngOnDestroy = /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    function () {
        this.subscription.unsubscribe();
    };
    RedhawkDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[arRedhawk]',
                    exportAs: 'arRedhawk',
                    providers: [
                        redhawkServiceProvider()
                    ]
                },] },
    ];
    /** @nocollapse */
    RedhawkDirective.ctorParameters = function () { return [
        { type: RedhawkService }
    ]; };
    RedhawkDirective.propDecorators = {
        serviceName: [{ type: core.Input }],
        model: [{ type: core.Input, args: ['arModel',] }],
        modelChange: [{ type: core.Output, args: ['arModelChange',] }]
    };
    return RedhawkDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The RedhawkModule includes a directive and service for interfacing the
 * REDHAWK System (in the general sense).
 */
var RedhawkModule = /** @class */ (function () {
    function RedhawkModule() {
    }
    RedhawkModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                        RestPythonModule,
                        SocketsModule
                    ],
                    exports: [RedhawkDirective],
                    declarations: [RedhawkDirective]
                },] },
    ];
    return RedhawkModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Returns a sub-list of properties from a list of properties using an array of IDs.
 */
var PropertiesPipe = /** @class */ (function () {
    function PropertiesPipe() {
    }
    /**
     * @param {?} properties
     * @param {?} ids
     * @return {?}
     */
    PropertiesPipe.prototype.transform = /**
     * @param {?} properties
     * @param {?} ids
     * @return {?}
     */
    function (properties, ids) {
        /** @type {?} */
        var set = [];
        properties.filter((/**
         * @param {?} prop
         * @return {?}
         */
        function (prop) {
            for (var _i = 0, ids_1 = ids; _i < ids_1.length; _i++) {
                var id = ids_1[_i];
                if (prop.id === id) {
                    set.push(prop);
                }
            }
        }));
        return set;
    };
    PropertiesPipe.decorators = [
        { type: core.Pipe, args: [{ name: 'arProperties' },] },
    ];
    return PropertiesPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Returns a specific property by its ID out of a list.
 */
var PropertyPipe = /** @class */ (function () {
    function PropertyPipe() {
    }
    /**
     * @param {?} properties
     * @param {?} id
     * @return {?}
     */
    PropertyPipe.prototype.transform = /**
     * @param {?} properties
     * @param {?} id
     * @return {?}
     */
    function (properties, id) {
        /** @type {?} */
        var p = properties.filter((/**
         * @param {?} prop
         * @return {?}
         */
        function (prop) { return prop.id === id; }))[0] || undefined;
        return p;
    };
    PropertyPipe.decorators = [
        { type: core.Pipe, args: [{ name: 'arProperty' },] },
    ];
    return PropertyPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Property command structure
 * @record
 */

/**
 * Standard 'command' interface for controlling properties on most entities.
 */
var PropertyCommand = /** @class */ (function () {
    /**
     * Constructor
     * @param properties The Properties to include in the command
     */
    function PropertyCommand(properties) {
        this.properties = properties;
    }
    return PropertyCommand;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Returns a sub-list of properties from a list of properties that match the
 * specified kind.  The default kind is 'property'.
 */
var PropretiesOfKindPipe = /** @class */ (function () {
    function PropretiesOfKindPipe() {
    }
    /**
     * @param {?} properties
     * @param {?=} kind
     * @return {?}
     */
    PropretiesOfKindPipe.prototype.transform = /**
     * @param {?} properties
     * @param {?=} kind
     * @return {?}
     */
    function (properties, kind) {
        if (kind === void 0) { kind = 'property'; }
        /** @type {?} */
        var set = [];
        properties.filter((/**
         * @param {?} prop
         * @return {?}
         */
        function (prop) {
            if (prop.kinds instanceof Array) {
                /** @type {?} */
                var kinds = prop.kinds;
                if (kinds.indexOf(kind) > -1) {
                    set.push(prop);
                }
            }
            else if (kind === prop.kinds) {
                set.push(prop);
            }
        }));
        return set;
    };
    PropretiesOfKindPipe.decorators = [
        { type: core.Pipe, args: [{ name: 'arPropretiesOfKind' },] },
    ];
    return PropretiesOfKindPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Pipes
/** @type {?} */
var PIPES$2 = [
    PropretiesOfKindPipe,
    PropertiesPipe,
    PropertyPipe
];
/**
 * The PropertyModule provides a number of pipes to facilitate in-template
 * sorting of Property types and subclasses.
 */
var PropertyModule = /** @class */ (function () {
    function PropertyModule() {
    }
    PropertyModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [],
                    exports: PIPES$2,
                    declarations: PIPES$2
                },] },
    ];
    return PropertyModule;
}());

var __extends$23 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Models and base class
// URL Builder
// Parent service
// Command interfaces
// ODM Socket
/**
 * The Domain Service provides access to the Domain model and other interfaces
 * at the REST server including a socket to the ODM Event Channel for monitoring
 * changes to the Domain (applications coming and going, etc.).
 */
var DomainService = /** @class */ (function (_super) {
    __extends$23(DomainService, _super);
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param redhawkService The REDHAWK service that can contains this Domain
     * @param [odmListener] The ODM Listener Service for tracking Domain events
     */
    function DomainService(http$$1, restPython, redhawkService, odmListener) {
        var _this = _super.call(this, http$$1, restPython) || this;
        _this.http = http$$1;
        _this.restPython = restPython;
        _this.redhawkService = redhawkService;
        _this.odmListener = odmListener;
        _this.modelUpdated(new Domain());
        if (!_this.odmListener) {
            /** @type {?} */
            var injector = core.ReflectiveInjector.resolveAndCreate([OdmListenerService]);
            _this.odmListener = injector.get(OdmListenerService);
        }
        // Bind update() to apps, factories, and device manager changes.
        _this.odmListener.applicationAdded$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        function (o) { return _this.update(); }));
        _this.odmListener.applicationRemoved$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        function (o) { return _this.update(); }));
        _this.odmListener.applicationFactoryAdded$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        function (o) { return _this.update(); }));
        _this.odmListener.applicationFactoryRemoved$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        function (o) { return _this.update(); }));
        _this.odmListener.deviceManagerAdded$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        function (o) { return _this.update(); }));
        _this.odmListener.deviceManagerRemoved$.subscribe((/**
         * @param {?} o
         * @return {?}
         */
        function (o) { return _this.update(); }));
        return _this;
    }
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    DomainService.prototype.setBaseUrl = /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    function (url) {
        this._baseUrl = this.restPython.domainUrl(this.redhawkService.baseUrl, url);
    };
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    DomainService.prototype.uniqueQuery$ = /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    function () {
        return this.redhawkService.attach$(this.uniqueId);
    };
    /**
     * Configures the domain's properties properties
     * @param properties The list of properties to configure
     */
    /**
     * Configures the domain's properties properties
     * @param {?} properties The list of properties to configure
     * @return {?}
     */
    DomainService.prototype.configure = /**
     * Configures the domain's properties properties
     * @param {?} properties The list of properties to configure
     * @return {?}
     */
    function (properties) {
        /** @type {?} */
        var command = new PropertyCommand(properties);
        this.http
            .put(this.restPython.propertyUrl(this.baseUrl), command)
            .pipe(operators.catchError(this.handleError));
        this.delayedUpdate();
    };
    /**
     * Get a list of running apps or a specific instance
     * @param [waveformId] The ID of the waveform model to get.  If none provided, a list is returned.
     * @returns Observable Waveform or ResourceRefs
     */
    /**
     * Get a list of running apps or a specific instance
     * @param {?=} waveformId
     * @return {?} Observable Waveform or ResourceRefs
     */
    DomainService.prototype.apps$ = /**
     * Get a list of running apps or a specific instance
     * @param {?=} waveformId
     * @return {?} Observable Waveform or ResourceRefs
     */
    function (waveformId) {
        if (waveformId) {
            return this.http
                .get(this.restPython.waveformUrl(this.baseUrl, waveformId), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return new Waveform().deserialize(response); })), operators.catchError(this.handleError));
        }
        else {
            return this.http
                .get(this.restPython.waveformUrl(this.baseUrl), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return deserializeResourceRefs(response['applications']); })), operators.catchError(this.handleError));
        }
    };
    /**
     * Get a list of launchable waveforms
     * Note: this is also on the [Domain's model]{@link Domain#waveforms}
     * @returns Observable WaveformSADRefs
     */
    /**
     * Get a list of launchable waveforms
     * Note: this is also on the [Domain's model]{\@link Domain#waveforms}
     * @return {?} Observable WaveformSADRefs
     */
    DomainService.prototype.catalogSads$ = /**
     * Get a list of launchable waveforms
     * Note: this is also on the [Domain's model]{\@link Domain#waveforms}
     * @return {?} Observable WaveformSADRefs
     */
    function () {
        return this.http
            .get(this.baseUrl, { responseType: 'json' })
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) { return deserializeWaveformSADRefs(response['waveforms']); })), operators.catchError(this.handleError));
    };
    /**
     * Launch a waveform
     * @param waveformName The [name]{@link WaveformSAD#name} of the Waveform
     * @param [started] Whether or not to also start (or not) the waveform (default stopped).
     * @returns Obsevable IWaveformLaunchCommandResponse
     */
    /**
     * Launch a waveform
     * @param {?} waveformName The [name]{\@link WaveformSAD#name} of the Waveform
     * @param {?=} started
     * @return {?} Obsevable IWaveformLaunchCommandResponse
     */
    DomainService.prototype.launch$ = /**
     * Launch a waveform
     * @param {?} waveformName The [name]{\@link WaveformSAD#name} of the Waveform
     * @param {?=} started
     * @return {?} Obsevable IWaveformLaunchCommandResponse
     */
    function (waveformName, started) {
        var _this = this;
        /** @type {?} */
        var command = { name: waveformName, started: started || false };
        return this.http
            .post(this.restPython.waveformUrl(this.baseUrl), command)
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            _this.delayedUpdate();
            return response;
        })), operators.catchError(this.handleError));
    };
    /**
     * Get a list of device managers or a specific instance
     * @param [deviceManagerId] The device manager model to retrieve.  If none provided, returns a listing.
     * @returns Observable DeviceManager or DeviceManagerRefs
     */
    /**
     * Get a list of device managers or a specific instance
     * @param {?=} deviceManagerId
     * @return {?} Observable DeviceManager or DeviceManagerRefs
     */
    DomainService.prototype.devMgrs$ = /**
     * Get a list of device managers or a specific instance
     * @param {?=} deviceManagerId
     * @return {?} Observable DeviceManager or DeviceManagerRefs
     */
    function (deviceManagerId) {
        if (deviceManagerId) {
            return this.http
                .get(this.restPython.deviceManagerUrl(this.baseUrl, deviceManagerId), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return new DeviceManager().deserialize(response); })), operators.catchError(this.handleError));
        }
        else {
            return this.http
                .get(this.restPython.deviceManagerUrl(this.baseUrl))
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return deserializeDeviceManagerRefs(response['deviceManagers']); })), operators.catchError(this.handleError));
        }
    };
    /**
     * Get a device model or a listing of available devices
     * @param deviceManagerId The device manager's ID containing the Device(s)
     * @param [deviceId] The device ID to retrieve.  If none, a listing is returned.
     * @returns Observable Device or ResourceRefs
     */
    /**
     * Get a device model or a listing of available devices
     * @param {?} deviceManagerId The device manager's ID containing the Device(s)
     * @param {?=} deviceId
     * @return {?} Observable Device or ResourceRefs
     */
    DomainService.prototype.devices$ = /**
     * Get a device model or a listing of available devices
     * @param {?} deviceManagerId The device manager's ID containing the Device(s)
     * @param {?=} deviceId
     * @return {?} Observable Device or ResourceRefs
     */
    function (deviceManagerId, deviceId) {
        /** @type {?} */
        var devMgrUrl = this.restPython.deviceManagerUrl(this.baseUrl, deviceManagerId);
        if (deviceId) {
            return this.http
                .get(this.restPython.deviceUrl(devMgrUrl, deviceId), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return new Device().deserialize(response); })), operators.catchError(this.handleError));
        }
        else {
            return this.http
                .get(this.restPython.deviceUrl(devMgrUrl), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return deserializeResourceRefs(response['devices']); })), operators.catchError(this.handleError));
        }
    };
    /** Common 'reconfigure' method to reconnect to the ODM listener when the uniqueID changes. */
    /**
     * Common 'reconfigure' method to reconnect to the ODM listener when the uniqueID changes.
     * @protected
     * @param {?} id
     * @param {?=} force
     * @return {?}
     */
    DomainService.prototype.reconfigure = /**
     * Common 'reconfigure' method to reconnect to the ODM listener when the uniqueID changes.
     * @protected
     * @param {?} id
     * @param {?=} force
     * @return {?}
     */
    function (id, force) {
        if (force === void 0) { force = false; }
        if (this._uniqueId) {
            this.odmListener.disconnect(this._uniqueId);
        }
        _super.prototype.reconfigure.call(this, id, force);
        this.odmListener.connect(this.uniqueId);
    };
    DomainService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    DomainService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: RestPythonService },
        { type: RedhawkService },
        { type: OdmListenerService, decorators: [{ type: core.Optional }] }
    ]; };
    return DomainService;
}(BaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This method instantiates a new instance for service if none is provided.
 * @param {?} service
 * @param {?} http The HTTP service for server callbacks
 * @param {?} restPython The REST Python service for URL serialization
 * @param {?} rh The REDHAWK service that has this Domain in it
 * @param {?} odm The ODM Listener services for the ODM Event Channel
 * @return {?}
 */
function serviceSelect$1(service, http$$1, restPython, rh, odm) {
    if (service === null) {
        service = new DomainService(http$$1, restPython, rh, odm);
    }
    return service;
}
/**
 * This is a default Service Provider factory that automatically selects the
 * "external" service (if already in the DI graph) or injects a new one using
 * the required set of external dependencies.
 * @return {?}
 */
function domainServiceProvider() {
    return [
        OdmListenerService,
        {
            provide: DomainService,
            useFactory: serviceSelect$1,
            deps: [
                [DomainService, new core.Optional(), new core.SkipSelf()],
                http.HttpClient,
                RestPythonService,
                RedhawkService,
                OdmListenerService
            ]
        }
    ];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The Domain Directive provides access to a specific Domain model
 *
 * \@example
 * <div [arDomain]="'DCE:...'" [(arModel)]="my_model">
 */
var DomainDirective = /** @class */ (function () {
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    function DomainDirective(service) {
        var _this = this;
        this.service = service;
        /**
         * Internal subscription for the model
         */
        this.subscription = null;
        this.modelChange = new core.EventEmitter();
        this.subscription = this.service.model$.subscribe((/**
         * @param {?} it
         * @return {?}
         */
        function (it) {
            _this.model = it;
            _this.modelChange.emit(_this.model);
        }));
    }
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    DomainDirective.prototype.ngOnChanges = /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    function (changes) {
        /** @type {?} */
        var domainId = 'domainId';
        if (changes.hasOwnProperty(domainId) && this.domainId !== undefined) {
            this.service.uniqueId = this.domainId;
        }
    };
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    DomainDirective.prototype.ngOnDestroy = /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    function () {
        this.subscription.unsubscribe();
    };
    DomainDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[arDomain]',
                    exportAs: 'arDomain',
                    providers: [
                        odmListenerServiceProvider(),
                        domainServiceProvider()
                    ]
                },] },
    ];
    /** @nocollapse */
    DomainDirective.ctorParameters = function () { return [
        { type: DomainService }
    ]; };
    DomainDirective.propDecorators = {
        domainId: [{ type: core.Input, args: ['arDomain',] }],
        model: [{ type: core.Input, args: ['arModel',] }],
        modelChange: [{ type: core.Output, args: ['arModelChange',] }]
    };
    return DomainDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The DomainModule includes a directive and service for interfacing with a
 * Domain on the REST server.
 */
var DomainModule = /** @class */ (function () {
    function DomainModule() {
    }
    DomainModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                        RestPythonModule,
                        RedhawkModule,
                        SocketsModule
                    ],
                    exports: [DomainDirective],
                    declarations: [DomainDirective]
                },] },
    ];
    return DomainModule;
}());

var __extends$24 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// This model and base class
// URL Builder
// Parent Service
/**
 * TBD
 * The FileSystemService provides access to the Domain's File System.
 */
var FileSystemService = /** @class */ (function (_super) {
    __extends$24(FileSystemService, _super);
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param domainService The Domain service that has this FileSystem in it
     */
    function FileSystemService(http$$1, restPython, domainService) {
        var _this = _super.call(this, http$$1, restPython) || this;
        _this.http = http$$1;
        _this.restPython = restPython;
        _this.domainService = domainService;
        _this.modelUpdated(new FileSystem());
        // If the domain service changed, reconfigure.
        _this.domainService.configured$.subscribe((/**
         * @param {?} cstat
         * @return {?}
         */
        function (cstat) {
            if (cstat.uriChanged && cstat.success) {
                _this.reconfigure(_this.uniqueId, cstat.uriChanged);
            }
        }));
        return _this;
    }
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    FileSystemService.prototype.setBaseUrl = /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    function (url) {
        this._baseUrl = this.restPython.fileSystemUrl(this.domainService.baseUrl, url);
    };
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    FileSystemService.prototype.uniqueQuery$ = /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    function () {
        return this.http
            .get(this.baseUrl, { responseType: 'json' })
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) { return new FileSystem().deserialize(response); })));
    };
    FileSystemService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    FileSystemService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: RestPythonService },
        { type: DomainService }
    ]; };
    return FileSystemService;
}(BaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This method instantiates a new instance for service if none is provided.
 * @param {?} service
 * @param {?} http The HTTP service for server callbacks
 * @param {?} restPython The REST Python service for URL serialization
 * @param {?} domainService The Domain service that has this FileSystem in it
 * @return {?}
 */
function serviceSelect$2(service, http$$1, restPython, domainService) {
    if (service === null) {
        service = new FileSystemService(http$$1, restPython, domainService);
    }
    return service;
}
/**
 * This is a default Service Provider factory that automatically selects the
 * "external" service (if already in the DI graph) or injects a new one using
 * the required set of external dependencies.
 * @return {?}
 */
function fileSystemServiceProvider() {
    return [{
            provide: FileSystemService,
            useFactory: serviceSelect$2,
            deps: [
                [FileSystemService, new core.Optional(), new core.SkipSelf()],
                http.HttpClient,
                RestPythonService,
                DomainService
            ]
        }];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The FileSystemModule includes a directive and service for interfacing with a
 * FileSystem on the REST server.
 */
var FileSystemModule = /** @class */ (function () {
    function FileSystemModule() {
    }
    FileSystemModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                        RestPythonModule,
                        DomainModule
                    ],
                    exports: [],
                    declarations: []
                },] },
    ];
    return FileSystemModule;
}());

var __extends$25 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// URL Builder
// Parent service & base class
/**
 * The DeviceManagerService provides access to methods for retrieving the DeviceManager model
 * as well as models of its devices and services.
 */
var DeviceManagerService = /** @class */ (function (_super) {
    __extends$25(DeviceManagerService, _super);
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param domainService The Domain service that has this DeviceManager in it
     */
    function DeviceManagerService(http$$1, restPython, domainService) {
        var _this = _super.call(this, http$$1, restPython) || this;
        _this.http = http$$1;
        _this.restPython = restPython;
        _this.domainService = domainService;
        _this.modelUpdated(new DeviceManager());
        // If the domain service changed, reconfigure.
        _this.domainService.configured$.subscribe((/**
         * @param {?} cstat
         * @return {?}
         */
        function (cstat) {
            if (cstat.uriChanged && cstat.success) {
                _this.reconfigure(_this.uniqueId, cstat.uriChanged);
            }
        }));
        return _this;
    }
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    DeviceManagerService.prototype.setBaseUrl = /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    function (url) {
        this._baseUrl = this.restPython.deviceManagerUrl(this.domainService.baseUrl, url);
    };
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @returns Observable DeviceManager
     */
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?} Observable DeviceManager
     */
    DeviceManagerService.prototype.uniqueQuery$ = /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?} Observable DeviceManager
     */
    function () {
        return (/** @type {?} */ (this.domainService.devMgrs$(this.uniqueId)));
    };
    /**
     * Retrieve a specific device or a list of devices in the Device Manager
     * @param [deviceId] The Device model to fetch.  If none, a list is returned.
     * @returns Observable Device or ResourceRefs
     */
    /**
     * Retrieve a specific device or a list of devices in the Device Manager
     * @param {?=} deviceId
     * @return {?} Observable Device or ResourceRefs
     */
    DeviceManagerService.prototype.devs$ = /**
     * Retrieve a specific device or a list of devices in the Device Manager
     * @param {?=} deviceId
     * @return {?} Observable Device or ResourceRefs
     */
    function (deviceId) {
        return this.domainService.devices$(this.uniqueId, deviceId);
    };
    /**
     * Retrieve a specific service model or list of services in the Device Manager
     * **Note:** Services are not fully supported at this time.
     *
     * @param [serviceId] The Service model to fetch.  If none, a list is returned.
     * @returns Observable any or list of anys.
     */
    /**
     * Retrieve a specific service model or list of services in the Device Manager
     * **Note:** Services are not fully supported at this time.
     *
     * @param {?=} serviceId
     * @return {?} Observable any or list of anys.
     */
    DeviceManagerService.prototype.services$ = /**
     * Retrieve a specific service model or list of services in the Device Manager
     * **Note:** Services are not fully supported at this time.
     *
     * @param {?=} serviceId
     * @return {?} Observable any or list of anys.
     */
    function (serviceId) {
        if (serviceId) {
            return this.http
                .get(this.restPython.serviceUrl(this.baseUrl, serviceId))
                .pipe(operators.catchError(this.handleError));
        }
        else {
            return this.http
                .get(this.restPython.serviceUrl(this.baseUrl), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return response['services']; })), operators.catchError(this.handleError));
        }
    };
    DeviceManagerService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    DeviceManagerService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: RestPythonService },
        { type: DomainService }
    ]; };
    return DeviceManagerService;
}(BaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This method instantiates a new instance for service if none is provided.
 * @param {?} service
 * @param {?} http The HTTP service for server callbacks
 * @param {?} restPython The REST Python service for URL serialization
 * @param {?} domain The Domain service that has this DeviceManager in it
 * @return {?}
 */
function serviceSelect$3(service, http$$1, restPython, domain) {
    if (service === null) {
        service = new DeviceManagerService(http$$1, restPython, domain);
    }
    return service;
}
/**
 * This is a default Service Provider factory that automatically selects the
 * "external" service (if already in the DI graph) or injects a new one using
 * the required set of external dependencies.
 * @return {?}
 */
function deviceManagerServiceProvider() {
    return [{
            provide: DeviceManagerService,
            useFactory: serviceSelect$3,
            deps: [
                [DeviceManagerService, new core.Optional(), new core.SkipSelf()],
                http.HttpClient,
                RestPythonService,
                DomainService
            ]
        }];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The DeviceManager Directive provides access to a specific DeviceManager model
 *
 * \@example
 * <div [arDeviceManager]="'DCE:...'" [(arModel)]="my_model">
 */
var DeviceManagerDirective = /** @class */ (function () {
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    function DeviceManagerDirective(service) {
        var _this = this;
        this.service = service;
        /**
         * Internal subscription for the model
         */
        this.subscription = null;
        this.modelChange = new core.EventEmitter();
        this.subscription = this.service.model$.subscribe((/**
         * @param {?} it
         * @return {?}
         */
        function (it) {
            _this.model = it;
            _this.modelChange.emit(_this.model);
        }));
    }
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    DeviceManagerDirective.prototype.ngOnChanges = /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    function (changes) {
        if (changes.hasOwnProperty('deviceManagerId') && this.deviceManagerId) {
            this.service.uniqueId = this.deviceManagerId;
        }
    };
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    DeviceManagerDirective.prototype.ngOnDestroy = /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    function () {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
    };
    DeviceManagerDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[arDeviceManager]',
                    exportAs: 'arDeviceManager',
                    providers: [deviceManagerServiceProvider()]
                },] },
    ];
    /** @nocollapse */
    DeviceManagerDirective.ctorParameters = function () { return [
        { type: DeviceManagerService }
    ]; };
    DeviceManagerDirective.propDecorators = {
        deviceManagerId: [{ type: core.Input, args: ['arDeviceManager',] }],
        model: [{ type: core.Input, args: ['arModel',] }],
        modelChange: [{ type: core.Output, args: ['arModelChange',] }]
    };
    return DeviceManagerDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The DeviceManagerModule includes a directive and service for interfacing with a
 * DeviceManager on the REST server.
 */
var DeviceManagerModule = /** @class */ (function () {
    function DeviceManagerModule() {
    }
    DeviceManagerModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                        RestPythonModule,
                        DomainModule
                    ],
                    exports: [DeviceManagerDirective],
                    declarations: [DeviceManagerDirective]
                },] },
    ];
    return DeviceManagerModule;
}());

var __extends$26 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Model, base class, other external modules
/**
 * The default delay in checking for a server response when using configure,
 * allocate, or deallocate.
 * @type {?}
 */
var DEFAULT_DELAY_RESPONSE_MS = 10000;
/**
 * The Waveform Service provides access to the Waveform Model on the REST server as well as
 * access to its components, ports, and properties.
 */
var WaveformService = /** @class */ (function (_super) {
    __extends$26(WaveformService, _super);
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param domainService The Domain service that can contains this Waveform
     */
    function WaveformService(http$$1, restPython, domainService) {
        var _this = _super.call(this, http$$1, restPython) || this;
        _this.http = http$$1;
        _this.restPython = restPython;
        _this.domainService = domainService;
        _this.modelUpdated(new Waveform());
        // If the domain service changed, reconfigure.
        _this.domainService.configured$.subscribe((/**
         * @param {?} cstat
         * @return {?}
         */
        function (cstat) {
            if (cstat.uriChanged && cstat.success) {
                _this.reconfigure(_this.uniqueId, cstat.uriChanged);
            }
        }));
        return _this;
    }
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    WaveformService.prototype.setBaseUrl = /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    function (url) {
        this._baseUrl = this.restPython.waveformUrl(this.domainService.baseUrl, url);
    };
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    WaveformService.prototype.uniqueQuery$ = /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    function () {
        return (/** @type {?} */ (this.domainService.apps$(this.uniqueId)));
    };
    /**
     * Returns an observable Component model if the Component ID is provided and exists.
     * If no ID is provided, this provides a reference listing of the components in the
     * Waveform.
     * @param [componentId] The Component ID to retrieve
     */
    /**
     * Returns an observable Component model if the Component ID is provided and exists.
     * If no ID is provided, this provides a reference listing of the components in the
     * Waveform.
     * @param {?=} componentId
     * @return {?}
     */
    WaveformService.prototype.comps$ = /**
     * Returns an observable Component model if the Component ID is provided and exists.
     * If no ID is provided, this provides a reference listing of the components in the
     * Waveform.
     * @param {?=} componentId
     * @return {?}
     */
    function (componentId) {
        if (componentId) {
            return this.http
                .get(this.restPython.componentUrl(this.baseUrl, componentId))
                .pipe(operators.catchError(this.handleError));
        }
        else {
            return this.http
                .get(this.restPython.componentUrl(this.baseUrl), { responseType: 'json' })
                .pipe(operators.map((/**
             * @param {?} response
             * @return {?}
             */
            function (response) { return (/** @type {?} */ (response['components'])); })), operators.catchError(this.handleError));
        }
    };
    /**
     * Starts the Waveform and returns the success/failure of that command.
     */
    /**
     * Starts the Waveform and returns the success/failure of that command.
     * @return {?}
     */
    WaveformService.prototype.start$ = /**
     * Starts the Waveform and returns the success/failure of that command.
     * @return {?}
     */
    function () {
        /** @type {?} */
        var command = { started: true };
        return this.controlCommand$(command);
    };
    /**
     * Stops the Waveform and returns the success/failure of that command.
     */
    /**
     * Stops the Waveform and returns the success/failure of that command.
     * @return {?}
     */
    WaveformService.prototype.stop$ = /**
     * Stops the Waveform and returns the success/failure of that command.
     * @return {?}
     */
    function () {
        /** @type {?} */
        var command = { started: false };
        return this.controlCommand$(command);
    };
    /**
     * Releases (removes) the Waveform and returns confirmation.
     */
    /**
     * Releases (removes) the Waveform and returns confirmation.
     * @return {?}
     */
    WaveformService.prototype.release$ = /**
     * Releases (removes) the Waveform and returns confirmation.
     * @return {?}
     */
    function () {
        return this.http
            .delete(this.baseUrl)
            .pipe(operators.catchError(this.handleError));
    };
    /**
     * Calls 'configure' on the Application and then pulls an update of the model.
     * @param properties The properties to 'configure' on the Application
     * @param delayResponseMs The optional model update delay after sending the
     * changes.
     */
    /**
     * Calls 'configure' on the Application and then pulls an update of the model.
     * @param {?} properties The properties to 'configure' on the Application
     * @param {?=} delayResponseMs The optional model update delay after sending the
     * changes.
     * @return {?}
     */
    WaveformService.prototype.configure$ = /**
     * Calls 'configure' on the Application and then pulls an update of the model.
     * @param {?} properties The properties to 'configure' on the Application
     * @param {?=} delayResponseMs The optional model update delay after sending the
     * changes.
     * @return {?}
     */
    function (properties, delayResponseMs) {
        var _this = this;
        /** @type {?} */
        var command = new PropertyCommand(properties);
        return this.http
            .put(this.restPython.propertyUrl(this.baseUrl), command)
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            _this.delayedUpdate(delayResponseMs || DEFAULT_DELAY_RESPONSE_MS);
            return response; // This will be null/undefined/empty
        })), operators.catchError(this.handleError));
    };
    /**
     * Common method shared by start and stop for issuing the command to the server.
     * @param command The command to issue (start/stop)
     */
    /**
     * Common method shared by start and stop for issuing the command to the server.
     * @private
     * @param {?} command The command to issue (start/stop)
     * @return {?}
     */
    WaveformService.prototype.controlCommand$ = /**
     * Common method shared by start and stop for issuing the command to the server.
     * @private
     * @param {?} command The command to issue (start/stop)
     * @return {?}
     */
    function (command) {
        return this.http
            .put(this.baseUrl, command)
            .pipe(operators.catchError(this.handleError));
    };
    WaveformService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    WaveformService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: RestPythonService },
        { type: DomainService }
    ]; };
    return WaveformService;
}(PortBearingService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This method instantiates a new instance for service if none is provided.
 * @param {?} service
 * @param {?} http The HTTP service for server callbacks
 * @param {?} restPython The REST Python service for URL serialization
 * @param {?} domain
 * @return {?}
 */
function serviceSelect$4(service, http$$1, restPython, domain) {
    if (service === null) {
        service = new WaveformService(http$$1, restPython, domain);
    }
    return service;
}
/**
 * This is a default Service Provider factory that automatically selects the
 * "external" service (if already in the DI graph) or injects a new one using
 * the required set of external dependencies.
 * @return {?}
 */
function waveformServiceProvider() {
    return [{
            provide: WaveformService,
            useFactory: serviceSelect$4,
            deps: [
                [WaveformService, new core.Optional(), new core.SkipSelf()],
                http.HttpClient,
                RestPythonService,
                DomainService
            ]
        }];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The Waveform directive provides the dependency injection start point for
 * a running Waveform (Application) in the Domain
 *
 * \@example
 * <div [arWaveform]="'DCE:...'" [(arModel)]="my_model">
 */
var WaveformDirective = /** @class */ (function () {
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    function WaveformDirective(service) {
        var _this = this;
        this.service = service;
        /**
         * Internal subscription for the model
         */
        this.subscription = null;
        this.modelChange = new core.EventEmitter();
        this.subscription = this.service.model$.subscribe((/**
         * @param {?} it
         * @return {?}
         */
        function (it) {
            _this.model = it;
            _this.modelChange.emit(_this.model);
        }));
    }
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    WaveformDirective.prototype.ngOnChanges = /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    function (changes) {
        if (changes.hasOwnProperty('waveformId') && this.waveformId) {
            this.service.uniqueId = this.waveformId;
        }
    };
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    WaveformDirective.prototype.ngOnDestroy = /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    function () {
        this.subscription.unsubscribe();
    };
    WaveformDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[arWaveform]',
                    exportAs: 'arWaveform',
                    providers: [waveformServiceProvider()]
                },] },
    ];
    /** @nocollapse */
    WaveformDirective.ctorParameters = function () { return [
        { type: WaveformService }
    ]; };
    WaveformDirective.propDecorators = {
        waveformId: [{ type: core.Input, args: ['arWaveform',] }],
        model: [{ type: core.Input, args: ['arModel',] }],
        modelChange: [{ type: core.Output, args: ['arModelChange',] }]
    };
    return WaveformDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The Waveform Control Command Response indicates whether the command to start
 * or stop was successful.  In the case of launching, the response indicates if
 * the waveform is started.
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Waveform Control command allows you to start (true) or stop (false) the
 * application's components.
 */
var IWaveformControlCommand = /** @class */ (function () {
    function IWaveformControlCommand() {
    }
    return IWaveformControlCommand;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Launch Command response indicates the success or failure of an attempt to
 * launch a waveform.  The returned applications list is the up-to-date list of
 * running applications in the domain and launched is the newly launched
 * instances's ID.
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Waveform Launch Command is used to launch (and optionally start) waveforms.
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Waveform release response contains the ID of the recently released waveform
 * and the up-to-date list of any running applications.
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The WaveformModule includes a directive and service for interfacing with a
 * Waveform on the REST server.
 */
var WaveformModule = /** @class */ (function () {
    function WaveformModule() {
    }
    WaveformModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                        RestPythonModule,
                        DomainModule
                    ],
                    exports: [WaveformDirective],
                    declarations: [WaveformDirective]
                },] },
    ];
    return WaveformModule;
}());

var __extends$28 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * DevicePropertyCommand is an extension to the standard PropertyCommand that
 * adds the device-specific 'method' field to support configure, allocate, and
 * deallocate methods.
 * @record
 */

/**
 * Concrete implementation of the interface, in case that is preferable.
 */
var DevicePropertyCommand = /** @class */ (function (_super) {
    __extends$28(DevicePropertyCommand, _super);
    /**
     * Constructor
     * @param method The method to apply to the properties (configure, allocate, deallocate)
     * @param properties The list of properties to manipulate
     */
    function DevicePropertyCommand(method, properties) {
        var _this = _super.call(this, properties) || this;
        _this.method = method;
        return _this;
    }
    return DevicePropertyCommand;
}(PropertyCommand));

var __extends$27 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Base class, served model and properties
// Parent service
// This model and helpers
/**
 * The default delay in checking for a server response when using configure,
 * allocate, or deallocate.
 * @type {?}
 */
var DEFAULT_DELAY_RESPONSE_MS$1 = 10000;
/**
 * The Device Service provides access to the Device Model on the REST server as well as
 * serves as methods for controlling it and its ports and properties.
 */
var DeviceService = /** @class */ (function (_super) {
    __extends$27(DeviceService, _super);
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param dmService The DeviceManager service that has this Device in it
     */
    function DeviceService(http$$1, restPython, dmService) {
        var _this = _super.call(this, http$$1, restPython) || this;
        _this.http = http$$1;
        _this.restPython = restPython;
        _this.dmService = dmService;
        _this.modelUpdated(new Device());
        // If the dmService service changed, reconfigure.
        _this.dmService.configured$.subscribe((/**
         * @param {?} cstat
         * @return {?}
         */
        function (cstat) {
            if (cstat.uriChanged && cstat.success) {
                _this.reconfigure(_this.uniqueId, cstat.uriChanged);
            }
        }));
        return _this;
    }
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    DeviceService.prototype.setBaseUrl = /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    function (url) {
        this._baseUrl = this.restPython.deviceUrl(this.dmService.baseUrl, url);
    };
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    DeviceService.prototype.uniqueQuery$ = /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    function () {
        return (/** @type {?} */ (this.dmService.devs$(this.uniqueId)));
    };
    /**
     * Calls 'configure' on the Device and then pulls an update of the model.
     * @param properties The properties to 'configure' on the Device
     * @param responseDelayMs The optional model update delay after sending the
     * changes.
     */
    /**
     * Calls 'configure' on the Device and then pulls an update of the model.
     * @param {?} properties The properties to 'configure' on the Device
     * @param {?=} responseDelayMs The optional model update delay after sending the
     * changes.
     * @return {?}
     */
    DeviceService.prototype.configure$ = /**
     * Calls 'configure' on the Device and then pulls an update of the model.
     * @param {?} properties The properties to 'configure' on the Device
     * @param {?=} responseDelayMs The optional model update delay after sending the
     * changes.
     * @return {?}
     */
    function (properties, responseDelayMs) {
        /** @type {?} */
        var command = new DevicePropertyCommand('configure', properties);
        return this.sendDevicePropertyCommand$(command);
    };
    /**
     * Calls 'allocate' on the Device and then pulls an update of the model.
     * @param properties The properties to 'allocate' on the Device
     * @param responseDelayMs The optional model update delay after sending the
     * changes.
     */
    /**
     * Calls 'allocate' on the Device and then pulls an update of the model.
     * @param {?} properties The properties to 'allocate' on the Device
     * @param {?=} responseDelayMs The optional model update delay after sending the
     * changes.
     * @return {?}
     */
    DeviceService.prototype.allocate$ = /**
     * Calls 'allocate' on the Device and then pulls an update of the model.
     * @param {?} properties The properties to 'allocate' on the Device
     * @param {?=} responseDelayMs The optional model update delay after sending the
     * changes.
     * @return {?}
     */
    function (properties, responseDelayMs) {
        /** @type {?} */
        var command = new DevicePropertyCommand('allocate', properties);
        return this.sendDevicePropertyCommand$(command);
    };
    /**
     * Calls 'deallocate' on the Device and then pulls an update of the model.
     * @param properties The properties to 'deallocate' on the Device
     * @param responseDelayMs The optional model update delay after sending the
     * changes (default is 5000 Ms)
     */
    /**
     * Calls 'deallocate' on the Device and then pulls an update of the model.
     * @param {?} properties The properties to 'deallocate' on the Device
     * @param {?=} responseDelayMs The optional model update delay after sending the
     * changes (default is 5000 Ms)
     * @return {?}
     */
    DeviceService.prototype.deallocate$ = /**
     * Calls 'deallocate' on the Device and then pulls an update of the model.
     * @param {?} properties The properties to 'deallocate' on the Device
     * @param {?=} responseDelayMs The optional model update delay after sending the
     * changes (default is 5000 Ms)
     * @return {?}
     */
    function (properties, responseDelayMs) {
        /** @type {?} */
        var command = new DevicePropertyCommand('deallocate', properties);
        return this.sendDevicePropertyCommand$(command);
    };
    /**
     * Common device property command method
     * @internal
     * @param command The command to issue
     * @param responseDelayMs Any delay (milliseconds to delay before the model is updated)
     */
    /**
     * Common device property command method
     * \@internal
     * @private
     * @param {?} command The command to issue
     * @param {?=} responseDelayMs Any delay (milliseconds to delay before the model is updated)
     * @return {?}
     */
    DeviceService.prototype.sendDevicePropertyCommand$ = /**
     * Common device property command method
     * \@internal
     * @private
     * @param {?} command The command to issue
     * @param {?=} responseDelayMs Any delay (milliseconds to delay before the model is updated)
     * @return {?}
     */
    function (command, responseDelayMs) {
        var _this = this;
        return this.http
            .put(this.restPython.propertyUrl(this.baseUrl), command)
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            _this.delayedUpdate(responseDelayMs || DEFAULT_DELAY_RESPONSE_MS$1);
            return response;
        })), operators.catchError(this.handleError));
    };
    DeviceService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    DeviceService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: RestPythonService },
        { type: DeviceManagerService }
    ]; };
    return DeviceService;
}(PortBearingService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This method instantiates a new instance for service if none is provided.
 * @param {?} service
 * @param {?} http The HTTP service for server callbacks
 * @param {?} restPython The REST Python service for URL serialization
 * @param {?} dm The DeviceManager service that has this Device in it
 * @return {?}
 */
function serviceSelect$5(service, http$$1, restPython, dm) {
    if (service === null) {
        service = new DeviceService(http$$1, restPython, dm);
    }
    return service;
}
/**
 * This is a default Service Provider factory that automatically selects the
 * "external" service (if already in the DI graph) or injects a new one using
 * the required set of external dependencies.
 * @return {?}
 */
function deviceServiceProvider() {
    return [{
            provide: DeviceService,
            useFactory: serviceSelect$5,
            deps: [
                [DeviceService, new core.Optional(), new core.SkipSelf()],
                http.HttpClient,
                RestPythonService,
                DeviceManagerService
            ]
        }];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Model
// This service
/**
 * The Device Directive provides access to a specific Device model including
 * the configuration, allocation, and deallocation of its properties and access
 * to its ports.
 *
 * \@example
 * <div [arDevice]="'DCE:...'" [(arModel)]="my_model">
 */
var DeviceDirective = /** @class */ (function () {
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    function DeviceDirective(service) {
        var _this = this;
        this.service = service;
        /**
         * Internal subscription for the model
         */
        this.subscription = null;
        this.modelChange = new core.EventEmitter();
        this.subscription = this.service.model$.subscribe((/**
         * @param {?} it
         * @return {?}
         */
        function (it) {
            _this.model = it;
            _this.modelChange.emit(_this.model);
        }));
    }
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    DeviceDirective.prototype.ngOnChanges = /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    function (changes) {
        if (changes.hasOwnProperty('deviceId') && this.deviceId) {
            this.service.uniqueId = this.deviceId;
        }
    };
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    DeviceDirective.prototype.ngOnDestroy = /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    function () {
        this.subscription.unsubscribe();
    };
    DeviceDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[arDevice]',
                    exportAs: 'arDevice',
                    providers: [deviceServiceProvider()]
                },] },
    ];
    /** @nocollapse */
    DeviceDirective.ctorParameters = function () { return [
        { type: DeviceService }
    ]; };
    DeviceDirective.propDecorators = {
        deviceId: [{ type: core.Input, args: ['arDevice',] }],
        model: [{ type: core.Input, args: ['arModel',] }],
        modelChange: [{ type: core.Output, args: ['arModelChange',] }]
    };
    return DeviceDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This is the server's response from having issued either a configure, allocate,
 * or deallocate command.  The response indicates the command that was received
 * and whether or not it succeeeded.  For configure, there is no response in the
 * server if the configure fails, so the status is always true unless an
 * exception is thrown.
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The DeviceModule includes a directive and service for interfacing with a
 * Device on the REST server.
 */
var DeviceModule = /** @class */ (function () {
    function DeviceModule() {
    }
    DeviceModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                        RestPythonModule,
                        DeviceManagerModule
                    ],
                    exports: [DeviceDirective],
                    declarations: [DeviceDirective]
                },] },
    ];
    return DeviceModule;
}());

var __extends$29 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Base class, served model, and properties
// URL Builder
// Parent service & base class
/**
 * The default delay in checking for a server response when using configure,
 * allocate, or deallocate.
 * @type {?}
 */
var DEFAULT_DELAY_RESPONSE_MS$2 = 10000;
/**
 * The Component Service provides the service interface to a specific Component
 * model in a REDHAWK system.
 */
var ComponentService = /** @class */ (function (_super) {
    __extends$29(ComponentService, _super);
    /**
     * Constructor
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param waveformService The Waveform service that has this Component in it
     */
    function ComponentService(http$$1, restPython, waveformService) {
        var _this = _super.call(this, http$$1, restPython) || this;
        _this.http = http$$1;
        _this.restPython = restPython;
        _this.waveformService = waveformService;
        _this.modelUpdated(new Component());
        // If the waveform service changed, reconfigure.
        _this.waveformConfigSub = _this.waveformService.configured$.subscribe((/**
         * @param {?} cstat
         * @return {?}
         */
        function (cstat) {
            if (cstat.uriChanged && cstat.success) {
                _this.reconfigure(_this.uniqueId, cstat.uriChanged);
            }
        }));
        return _this;
    }
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    ComponentService.prototype.setBaseUrl = /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    function (url) {
        this._baseUrl = this.restPython.componentUrl(this.waveformService.baseUrl, url);
    };
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    ComponentService.prototype.uniqueQuery$ = /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    function () {
        if (this.uniqueId) {
            return (/** @type {?} */ (this.waveformService.comps$(this.uniqueId)));
        }
        else {
            return rxjs.EMPTY;
        }
    };
    /**
     * Calls 'configure' on the Component and then pulls an update of the model.
     * @param properties The properties to 'configure' on the Component
     * @param delayResponseMs The optional model update delay after sending the
     * changes.
     */
    /**
     * Calls 'configure' on the Component and then pulls an update of the model.
     * @param {?} properties The properties to 'configure' on the Component
     * @param {?=} delayResponseMs The optional model update delay after sending the
     * changes.
     * @return {?}
     */
    ComponentService.prototype.configure$ = /**
     * Calls 'configure' on the Component and then pulls an update of the model.
     * @param {?} properties The properties to 'configure' on the Component
     * @param {?=} delayResponseMs The optional model update delay after sending the
     * changes.
     * @return {?}
     */
    function (properties, delayResponseMs) {
        var _this = this;
        /** @type {?} */
        var command = new PropertyCommand(properties);
        return this.http
            .put(this.restPython.propertyUrl(this.baseUrl), command)
            .pipe(operators.map((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            _this.delayedUpdate(delayResponseMs || DEFAULT_DELAY_RESPONSE_MS$2);
            return response; // This will be null/undefined/empty
        })), operators.catchError(this.handleError));
    };
    /**
     * @return {?}
     */
    ComponentService.prototype.cleanUp = /**
     * @return {?}
     */
    function () {
        this.waveformConfigSub.unsubscribe();
    };
    ComponentService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    ComponentService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: RestPythonService },
        { type: WaveformService }
    ]; };
    return ComponentService;
}(PortBearingService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This method instantiates a new instance for service if none is provided.
 * @param {?} service
 * @param {?} http The HTTP service for server callbacks
 * @param {?} restPython The REST Python service for URL serialization
 * @param {?} waveform
 * @return {?}
 */
function serviceSelect$6(service, http$$1, restPython, waveform) {
    if (service === null) {
        service = new ComponentService(http$$1, restPython, waveform);
    }
    return service;
}
/**
 * This is a default Service Provider factory that automatically selects the
 * "external" service (if already in the DI graph) or injects a new one using
 * the required set of external dependencies.
 * @return {?}
 */
function componentServiceProvider() {
    return [{
            provide: ComponentService,
            useFactory: serviceSelect$6,
            deps: [
                [ComponentService, new core.Optional(), new core.SkipSelf()],
                http.HttpClient,
                RestPythonService,
                WaveformService
            ]
        }];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// This service
/**
 * The Component Directive provides access to a specific Component model including
 * the configuration of its properties and access to its ports.
 *
 * \@example
 * <div [arComponent]="'DCE:...'" [(arModel)]="my_model">
 */
var ComponentDirective = /** @class */ (function () {
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    function ComponentDirective(service) {
        var _this = this;
        this.service = service;
        /**
         * Internal subscription for the model
         */
        this.subscription = null;
        this.modelChange = new core.EventEmitter();
        this.subscription = this.service.model$.subscribe((/**
         * @param {?} it
         * @return {?}
         */
        function (it) {
            _this.model = it;
            _this.modelChange.emit(_this.model);
        }));
    }
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    ComponentDirective.prototype.ngOnChanges = /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    function (changes) {
        if (changes.hasOwnProperty('componentId') && this.componentId) {
            this.service.uniqueId = this.componentId;
        }
    };
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    ComponentDirective.prototype.ngOnDestroy = /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    function () {
        this.service.cleanUp();
        this.subscription.unsubscribe();
    };
    ComponentDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[arComponent]',
                    exportAs: 'arComponent',
                    providers: [componentServiceProvider()]
                },] },
    ];
    /** @nocollapse */
    ComponentDirective.ctorParameters = function () { return [
        { type: ComponentService }
    ]; };
    ComponentDirective.propDecorators = {
        componentId: [{ type: core.Input, args: ['arComponent',] }],
        model: [{ type: core.Input, args: ['arModel',] }],
        modelChange: [{ type: core.Output, args: ['arModelChange',] }]
    };
    return ComponentDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The ComponentModule includes a directive and service for interfacing with a
 * Component on the REST server.
 */
var ComponentModule = /** @class */ (function () {
    function ComponentModule() {
    }
    ComponentModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                        RestPythonModule,
                        WaveformModule
                    ],
                    exports: [ComponentDirective],
                    declarations: [ComponentDirective]
                },] },
    ];
    return ComponentModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * TBD
 * Base class for port references.
 */
var PortRef = /** @class */ (function () {
    /**
     * Constructor
     * @param url REST URL of the port
     */
    function PortRef(url) {
        this.url = url;
    }
    /**
     * If this port reference is being deleted/removed, call this method.
     */
    /**
     * If this port reference is being deleted/removed, call this method.
     * @return {?}
     */
    PortRef.prototype.release = /**
     * If this port reference is being deleted/removed, call this method.
     * @return {?}
     */
    function () { };
    
    return PortRef;
}());

var __extends$31 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The PortReceiver interface receives BulkioPacket pushes from
 * the bulkio port service.
 * @record
 */

/**
 * BulkioRef is akin to the internal "ref" member found in the Python Shell.
 */
var BulkioRef = /** @class */ (function (_super) {
    __extends$31(BulkioRef, _super);
    /**
     * Constructor
     * @param url The REST URL for the port
     * @param rp the REST Python service
     */
    function BulkioRef(url, rp) {
        var _this = _super.call(this, url) || this;
        _this.url = url;
        _this.bulkioService = new BulkioListenerService(rp.bulkioSocketUrl(url));
        return _this;
    }
    /**
     * Connect to the packet stream of the bulkio service listener
     * @param {PortReceiver} target - The callback for when new packets are received.
     * @param {string} connection_id - The connection_id (stream_id), if applicable.
     * @return {Subscription} The RxJS Subscription for this connection.
     */
    /**
     * Connect to the packet stream of the bulkio service listener
     * @param {?} target
     * @param {?=} connection_id
     * @return {?}
     */
    BulkioRef.prototype.connectPort = /**
     * Connect to the packet stream of the bulkio service listener
     * @param {?} target
     * @param {?=} connection_id
     * @return {?}
     */
    function (target, connection_id) {
        if (connection_id !== this.connectionId) {
            this.disconnectPort();
        }
        if (!this.bulkioService.connected) {
            this.bulkioService.connect(connection_id);
            this.connectionId = connection_id;
        }
        return this.bulkioService.packet$.subscribe(target);
    };
    /**
     * Disconnect this connection.
     * NOTE: This is equivalent call unsubscribe() on the Subscription and
     *       also disconnects the service from the server.
     * @param {Subscription} connection - The connection (subscription) returned
     *     from the connectPort call.
     */
    /**
     * Disconnect this connection.
     * NOTE: This is equivalent call unsubscribe() on the Subscription and
     *       also disconnects the service from the server.
     *     from the connectPort call.
     * @param {?=} connection
     * @return {?}
     */
    BulkioRef.prototype.disconnectPort = /**
     * Disconnect this connection.
     * NOTE: This is equivalent call unsubscribe() on the Subscription and
     *       also disconnects the service from the server.
     *     from the connectPort call.
     * @param {?=} connection
     * @return {?}
     */
    function (connection) {
        if (connection) {
            connection.unsubscribe();
        }
        this.bulkioService.disconnect();
    };
    Object.defineProperty(BulkioRef.prototype, "xMax", {
        /**
         * Set the max number of samples for the X axis (causes inter-sample
         * averaging).  The REST Python server will try to adjust to near this limit
         * based on the data size. Setting the width to less than or equal to 0 will
         * disable this feature.
         * @param {number} value
         */
        set: /**
         * Set the max number of samples for the X axis (causes inter-sample
         * averaging).  The REST Python server will try to adjust to near this limit
         * based on the data size. Setting the width to less than or equal to 0 will
         * disable this feature.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.xMax = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "xBegin", {
        /**
         * Set the beginning index of the zoom region for the X axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {number} value
         */
        set: /**
         * Set the beginning index of the zoom region for the X axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.xBegin = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "xEnd", {
        /**
         * Set the ending index of the zoom region for the X axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {number} value
         */
        set: /**
         * Set the ending index of the zoom region for the X axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.xEnd = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "xZoomIn", {
        /**
         * Command a zoom in on the X axis. Command will be executed
         * regardless of the value set.
         * @param {number} value
         */
        set: /**
         * Command a zoom in on the X axis. Command will be executed
         * regardless of the value set.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.xZoomIn = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "xZoomReset", {
        /**
         * Command a zoom reset on the X axis. Command will be executed
         * regardless of the value set.
         * @param {number} value
         */
        set: /**
         * Command a zoom reset on the X axis. Command will be executed
         * regardless of the value set.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.xZoomReset = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "yMax", {
        /**
         * Set the max number of samples for the Y axis (causes inter-sample
         * averaging).  The REST Python server will try to adjust to near this limit
         * based on the data size. Setting the width to less than or equal to 0 will
         * disable this feature.
         * @param {number} value
         */
        set: /**
         * Set the max number of samples for the Y axis (causes inter-sample
         * averaging).  The REST Python server will try to adjust to near this limit
         * based on the data size. Setting the width to less than or equal to 0 will
         * disable this feature.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.yMax = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "yBegin", {
        /**
         * Set the beginning index of the zoom region for the Y axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {number} value
         */
        set: /**
         * Set the beginning index of the zoom region for the Y axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.yBegin = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "yEnd", {
        /**
         * Set the ending index of the zoom region for the Y axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {number} value
         */
        set: /**
         * Set the ending index of the zoom region for the Y axis. The index is
         * inclusive and based on data available at the UI (the server will adjust
         * the index for the actual packet size). The zoom will not be enabled until
         * the zoom level is set.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.yEnd = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "yZoomIn", {
        /**
         * Command a zoom in on the Y axis. Command will be executed
         * regardless of the value set.
         * @param {number} value
         */
        set: /**
         * Command a zoom in on the Y axis. Command will be executed
         * regardless of the value set.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.yZoomIn = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "yZoomReset", {
        /**
         * Command a zoom reset on the Y axis. Command will be executed
         * regardless of the value set.
         * @param {number} value
         */
        set: /**
         * Command a zoom reset on the Y axis. Command will be executed
         * regardless of the value set.
         * @param {?} value
         * @return {?}
         */
        function (value) { this.bulkioService.yZoomReset = value; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "packetsPerSecond", {
        /**
         * Set the data update rate of the connection.  This is a maximum update
         * rate and may be approximated.  Setting the value to less than or equal
         * to zero disables this feature (i.e., lets the service push as quickly
         * as the socket and server will allow).
         * @param {number} pps - The maximum number of packets per second to receive.
         */
        set: /**
         * Set the data update rate of the connection.  This is a maximum update
         * rate and may be approximated.  Setting the value to less than or equal
         * to zero disables this feature (i.e., lets the service push as quickly
         * as the socket and server will allow).
         * @param {?} pps
         * @return {?}
         */
        function (pps) {
            this.bulkioService.packetsPerSecond = pps;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "deserializeTime", {
        /**
         * Statistic indicating how long it took to deserialize the packet.
         * @return {number} The time required to deserialize the BulkioPacket
         */
        get: /**
         * Statistic indicating how long it took to deserialize the packet.
         * @return {?}
         */
        function () {
            return this.bulkioService.deserializeTime;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "packetLength", {
        /**
         * The number of data words in the most recent packet.
         * @return {number}
         */
        get: /**
         * The number of data words in the most recent packet.
         * @return {?}
         */
        function () {
            return this.bulkioService.packetLength;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "packetSubsize", {
        /**
         * The frame size of the most recent packet.
         *      0 - One dimensional data (no frames)
         *     >0 - Two dimensional data
         * @return {number}
         */
        get: /**
         * The frame size of the most recent packet.
         *      0 - One dimensional data (no frames)
         *     >0 - Two dimensional data
         * @return {?}
         */
        function () {
            return this.bulkioService.packetSubsize;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BulkioRef.prototype, "packetMode", {
        /**
         * The complex flag for the most recent packet.
         *     0 - Scalar data
         *     1 - Complex data
         * @return {number}
         */
        get: /**
         * The complex flag for the most recent packet.
         *     0 - Scalar data
         *     1 - Complex data
         * @return {?}
         */
        function () {
            return this.bulkioService.packetMode;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Release the port's underlying socket service.
     */
    /**
     * Release the port's underlying socket service.
     * @return {?}
     */
    BulkioRef.prototype.release = /**
     * Release the port's underlying socket service.
     * @return {?}
     */
    function () {
        this.bulkioService.disconnect();
        _super.prototype.release.call(this);
    };
    return BulkioRef;
}(PortRef));

var __extends$32 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Generic FEI Device that queries (Http) against the port to fetch its
 * extended information.  This is simply a base class for the other FEI types.
 */
var FeiRef = /** @class */ (function (_super) {
    __extends$32(FeiRef, _super);
    /**
     * Constructor
     * @param url The URL of the port.
     */
    function FeiRef(url) {
        var _this = _super.call(this, url) || this;
        _this.url = url;
        /** @type {?} */
        var providers = core.ReflectiveInjector.resolve([http.HttpClient]);
        /** @type {?} */
        var injector = core.ReflectiveInjector.fromResolvedProviders(providers);
        _this.http = injector.get(http.HttpClient);
        return _this;
    }
    /**
     * Queries the FEI port for the named parameter.
     */
    /**
     * Queries the FEI port for the named parameter.
     * @protected
     * @param {?=} param
     * @return {?}
     */
    FeiRef.prototype.query$ = /**
     * Queries the FEI port for the named parameter.
     * @protected
     * @param {?=} param
     * @return {?}
     */
    function (param) {
        /** @type {?} */
        var target = this.url;
        if (param) {
            target = target + '/' + param;
        }
        return this.http.get(target);
    };
    return FeiRef;
}(PortRef));

var __extends$33 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * TBD
 * Provides access to FEI RFInfo methods
 */
var FeiRFInfoRef = /** @class */ (function (_super) {
    __extends$33(FeiRFInfoRef, _super);
    function FeiRFInfoRef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return FeiRFInfoRef;
}(FeiRef));

var __extends$34 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * TBD
 * Provides access to FEI RFSource methods
 */
var FeiRFSourceRef = /** @class */ (function (_super) {
    __extends$34(FeiRFSourceRef, _super);
    function FeiRFSourceRef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return FeiRFSourceRef;
}(FeiRef));

var __extends$35 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * TBD
 * Provides access to FEI GPS methods
 */
var FeiGPSRef = /** @class */ (function (_super) {
    __extends$35(FeiGPSRef, _super);
    function FeiGPSRef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return FeiGPSRef;
}(FeiRef));

var __extends$36 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * TBD
 * Provides access to FEI NavData methods
 */
var FeiNavDataRef = /** @class */ (function (_super) {
    __extends$36(FeiNavDataRef, _super);
    function FeiNavDataRef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return FeiNavDataRef;
}(FeiRef));

var __extends$37 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * TBD
 * Provides access to FEI Tuner methods (base class)
 */
var FeiTunerRef = /** @class */ (function (_super) {
    __extends$37(FeiTunerRef, _super);
    function FeiTunerRef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return FeiTunerRef;
}(FeiRef));

var __extends$38 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * TBD
 * Provides access to FEI Analog Tuner methods
 */
var FeiAnalogTunerRef = /** @class */ (function (_super) {
    __extends$38(FeiAnalogTunerRef, _super);
    function FeiAnalogTunerRef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return FeiAnalogTunerRef;
}(FeiTunerRef));

var __extends$39 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * TBD
 * Provides access to FEI Digital Tuner methods
 */
var FeiDigitalTunerRef = /** @class */ (function (_super) {
    __extends$39(FeiDigitalTunerRef, _super);
    function FeiDigitalTunerRef() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return FeiDigitalTunerRef;
}(FeiAnalogTunerRef));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

var __extends$30 = (undefined && undefined.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Model and Enumerations
// URL Builder
// Possible parent services
// And base service
// Common port "ref" and the specific ones.
/**
 * The Port Service provides unique interfaces to different types of ports
 * through the 'ref' member.  That member is a sub-service which may
 * include REST callbacks for FEI ports vs. websocket controls for BULKIO.
 */
var PortService = /** @class */ (function (_super) {
    __extends$30(PortService, _super);
    /**
     * Constructor
     * **NOTE:** One of _wave, _device, or _component must be provided!
     *
     * @param http The HTTP service for server callbacks
     * @param restPython The REST Python service for URL serialization
     * @param [_wave] The Waveform service that has this Port in it
     * @param [_device] The Device service that has this Port in it
     * @param [_component] The Component service that has this Port in it
     */
    function PortService(http$$1, restPython, _wave, _device, _component) {
        var _this = _super.call(this, http$$1, restPython) || this;
        _this.http = http$$1;
        _this.restPython = restPython;
        /**
         * The internal port "reference" controller
         */
        _this._ref = null;
        _this.modelUpdated(new Port());
        if (_wave) {
            if (_component) {
                _this.parent = _component;
            }
            else {
                _this.parent = _wave;
            }
        }
        else if (_device) {
            _this.parent = _device;
        }
        else {
            console.error('Failed to provide a port bearing service');
        }
        // If the parent service changed, reconfigure.
        _this.parent.configured$.subscribe((/**
         * @param {?} cstat
         * @return {?}
         */
        function (cstat) {
            if (cstat.uriChanged && cstat.success) {
                _this._forceReconfigRef = true;
                _this.reconfigure(_this.uniqueId, cstat.uriChanged);
            }
        }));
        return _this;
    }
    Object.defineProperty(PortService.prototype, "ref", {
        /**
         * The port's sub-reference interfaces.  For BulkIO, this will be a
         * BulkioRef giving connectPort and disconnectPort.  For FEI, these will
         * be interfaces that look like those defined in the associated IDL.
         *
         * Use model.hasBulkioWebsocket to determine if this is a BulkioRef.
         * Use model.isFEIControllable to determine if this is one of the FEI Refs.
         *
         * Then use model.idl.type to determine the sub-type (either the data type
         * of the BulkioRef, or the FeiXXXXRef ref type).
         */
        get: /**
         * The port's sub-reference interfaces.  For BulkIO, this will be a
         * BulkioRef giving connectPort and disconnectPort.  For FEI, these will
         * be interfaces that look like those defined in the associated IDL.
         *
         * Use model.hasBulkioWebsocket to determine if this is a BulkioRef.
         * Use model.isFEIControllable to determine if this is one of the FEI Refs.
         *
         * Then use model.idl.type to determine the sub-type (either the data type
         * of the BulkioRef, or the FeiXXXXRef ref type).
         * @return {?}
         */
        function () { return this._ref; },
        enumerable: true,
        configurable: true
    });
    /**
     * Internal, sets up the base URL
     * @param url Sets the base URL for this service
     */
    /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    PortService.prototype.setBaseUrl = /**
     * Internal, sets up the base URL
     * @param {?} url Sets the base URL for this service
     * @return {?}
     */
    function (url) {
        this._baseUrl = this.restPython.portUrl(this.parent.baseUrl, this.uniqueId);
    };
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     */
    /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    PortService.prototype.uniqueQuery$ = /**
     * Internal, initiates the server call that uniquely identifies this entity
     * to retrieve its model.
     * @return {?}
     */
    function () {
        if (this.uniqueId) {
            return (/** @type {?} */ (this.parent.ports$(this.uniqueId)));
        }
        else {
            return rxjs.EMPTY;
        }
    };
    /**
     * Scans the model to determine the type of 'ref' to create for any subfeatures.
     * @param model The new Port model from the recent refresh
     */
    /**
     * Scans the model to determine the type of 'ref' to create for any subfeatures.
     * @param {?} model The new Port model from the recent refresh
     * @return {?}
     */
    PortService.prototype.modelUpdated = /**
     * Scans the model to determine the type of 'ref' to create for any subfeatures.
     * @param {?} model The new Port model from the recent refresh
     * @return {?}
     */
    function (model) {
        if (this._previousUniqueId !== this.uniqueId || this._forceReconfigRef) {
            this._forceReconfigRef = false;
            if (this._ref) {
                this._ref.release();
                this._ref = null;
            }
            if (model.hasBulkioWebsocket) {
                this._ref = new BulkioRef(this.baseUrl, this.restPython);
            }
            else if (model.isFEIControllable) {
                switch (model.idl.type) {
                    case PortFEIIDLType.AnalogTuner:
                        this._ref = new FeiAnalogTunerRef(this.baseUrl);
                        break;
                    case PortFEIIDLType.DigitalTuner:
                        this._ref = new FeiDigitalTunerRef(this.baseUrl);
                        break;
                    case PortFEIIDLType.GPS:
                        this._ref = new FeiGPSRef(this.baseUrl);
                        break;
                    case PortFEIIDLType.NavData:
                        this._ref = new FeiNavDataRef(this.baseUrl);
                        break;
                    case PortFEIIDLType.RFInfo:
                        this._ref = new FeiRFInfoRef(this.baseUrl);
                        break;
                    case PortFEIIDLType.RFSource:
                        this._ref = new FeiRFSourceRef(this.baseUrl);
                        break;
                    default:
                        console.warn('Provides (controllable) FEI port has unknown Port Type');
                        break;
                }
            }
            // Still not set? Use default.
            if (!this._ref) {
                this._ref = new PortRef(this.baseUrl);
            }
            // Set previousUniqueId to this one.
            this._previousUniqueId = this.uniqueId;
        }
        _super.prototype.modelUpdated.call(this, model);
    };
    PortService.decorators = [
        { type: core.Injectable },
    ];
    /** @nocollapse */
    PortService.ctorParameters = function () { return [
        { type: http.HttpClient },
        { type: RestPythonService },
        { type: WaveformService, decorators: [{ type: core.Optional }] },
        { type: DeviceService, decorators: [{ type: core.Optional }] },
        { type: ComponentService, decorators: [{ type: core.Optional }] }
    ]; };
    return PortService;
}(BaseService));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * This method instantiates a new instance for service if none is provided.
 * @param {?} service
 * @param {?} http The HTTP service for server callbacks
 * @param {?} restPython The REST Python service for URL serialization
 * @param {?} waveform
 * @param {?} device
 * @param {?} component
 * @return {?}
 */
function serviceSelect$7(service, http$$1, restPython, waveform, device, component) {
    if (service === null) {
        service = new PortService(http$$1, restPython, waveform, device, component);
    }
    return service;
}
/**
 * This is a default Service Provider factory that automatically selects the
 * "external" service (if already in the DI graph) or injects a new one using
 * the required set of external dependencies.
 * @return {?}
 */
function portServiceProvider() {
    return [{
            provide: PortService,
            useFactory: serviceSelect$7,
            deps: [
                [PortService, new core.Optional(), new core.SkipSelf()],
                http.HttpClient,
                RestPythonService,
                [WaveformService, new core.Optional()],
                [DeviceService, new core.Optional()],
                [ComponentService, new core.Optional()]
            ]
        }];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// This model, rest service, and provider
/**
 * The Port directive provides access to the variety of port types in REDHAWK.
 * Port-specific features can be accessed through the 'service'.
 *
 * \@example
 * <div [arPort]="'dataShort_out'" [(arModel)]="my_model">
 */
var PortDirective = /** @class */ (function () {
    /**
     * Constructor
     * @param service The service either imported from up the hierarchy or instantiated
     *                by this directive.
     */
    function PortDirective(service) {
        var _this = this;
        this.service = service;
        /**
         * Internal subscription for the model
         */
        this.subscription = null;
        this.modelChange = new core.EventEmitter();
        this.subscription = this.service.model$.subscribe((/**
         * @param {?} it
         * @return {?}
         */
        function (it) {
            _this.model = it;
            _this.modelChange.emit(_this.model);
        }));
    }
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param changes The changes made to this component
     */
    /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    PortDirective.prototype.ngOnChanges = /**
     * Implementation of the OnChanges interface updates the service's uniqueID
     * @param {?} changes The changes made to this component
     * @return {?}
     */
    function (changes) {
        if (changes.hasOwnProperty('portId') && this.portId) {
            this.service.uniqueId = this.portId;
        }
    };
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     */
    /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    PortDirective.prototype.ngOnDestroy = /**
     * Implementation of the OnDestroy interface unsubscribes from the model observable.
     * @return {?}
     */
    function () {
        this.subscription.unsubscribe();
    };
    PortDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[arPort]',
                    exportAs: 'arPort',
                    providers: [portServiceProvider()]
                },] },
    ];
    /** @nocollapse */
    PortDirective.ctorParameters = function () { return [
        { type: PortService }
    ]; };
    PortDirective.propDecorators = {
        portId: [{ type: core.Input, args: ['arPort',] }],
        model: [{ type: core.Input, args: ['arModel',] }],
        modelChange: [{ type: core.Output, args: ['arModelChange',] }]
    };
    return PortDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Returns a sub-list of ports from a list of properties using an array of names
 * or a single name.  In either case, the entries can be regular expressions.
 * An optional third argument is provided, 'bulkio', which will further filter
 * the list to only those that support BULKIO web sockets.
 */
var PortsPipe = /** @class */ (function () {
    function PortsPipe() {
    }
    /**
     * @param {?} ports
     * @param {?} names
     * @param {?=} bulkio
     * @return {?}
     */
    PortsPipe.prototype.transform = /**
     * @param {?} ports
     * @param {?} names
     * @param {?=} bulkio
     * @return {?}
     */
    function (ports, names, bulkio) {
        /** @type {?} */
        var set = [];
        if (!(names instanceof Array)) {
            names = [names];
        }
        ports.filter((/**
         * @param {?} port
         * @return {?}
         */
        function (port) {
            for (var _i = 0, names_1 = names; _i < names_1.length; _i++) {
                var name_1 = names_1[_i];
                /** @type {?} */
                var tester = new RegExp(name_1);
                if (tester.test(port.name)) {
                    if (bulkio === undefined) {
                        set.push(port);
                    }
                    else if (bulkio === true && port.hasBulkioWebsocket) {
                        set.push(port);
                    }
                }
            }
        }));
        return set;
    };
    PortsPipe.decorators = [
        { type: core.Pipe, args: [{ name: 'arPorts' },] },
    ];
    return PortsPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * The PortModule provides directives and sub-interfaces (refs) for managing a
 * Port instance on a Component, Waveform, or Device.
 */
var PortModule = /** @class */ (function () {
    function PortModule() {
    }
    PortModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule,
                        RestPythonModule,
                        DeviceModule,
                        ComponentModule,
                        WaveformModule,
                        SocketsModule
                    ],
                    exports: [PortDirective, PortsPipe],
                    declarations: [PortDirective, PortsPipe]
                },] },
    ];
    return PortModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Returns a specific ResourceRef by its ID or Name out of a list matching first
 * the ID if provided, otherwise the name is used to match.
 *
 * Supports Regular Expressions.
 *
 * You can specify the 'key' argument to return just the string member matching
 * that key (in this case, 'id' or 'name' would work).
 */
var ResourceRefPipe = /** @class */ (function () {
    function ResourceRefPipe() {
    }
    /**
     * @param {?} refs
     * @param {?} target
     * @param {?=} key
     * @return {?}
     */
    ResourceRefPipe.prototype.transform = /**
     * @param {?} refs
     * @param {?} target
     * @param {?=} key
     * @return {?}
     */
    function (refs, target, key) {
        /** @type {?} */
        var id = new RegExp(target.id || '.*');
        /** @type {?} */
        var name = new RegExp(target.name || '.*');
        /** @type {?} */
        var ref = refs.filter((/**
         * @param {?} r
         * @return {?}
         */
        function (r) { return (id.test(r.id) && name.test(r.name)); }))[0] || undefined;
        if (ref !== undefined && key !== undefined) {
            return ref[key]; // Returns the key.
        }
        return ref;
    };
    ResourceRefPipe.decorators = [
        { type: core.Pipe, args: [{ name: 'arResourceRef' },] },
    ];
    return ResourceRefPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Returns a list (ResourceRefs) that match either the ID or the Name specified
 * in the filter.
 *
 * Supports Regular Expressions.
 */
var ResourceRefsPipe = /** @class */ (function () {
    function ResourceRefsPipe() {
    }
    /**
     * @param {?} refs
     * @param {?} target
     * @return {?}
     */
    ResourceRefsPipe.prototype.transform = /**
     * @param {?} refs
     * @param {?} target
     * @return {?}
     */
    function (refs, target) {
        /** @type {?} */
        var id = new RegExp(target.id || '.*');
        /** @type {?} */
        var name = new RegExp(target.name || '.*');
        return refs.filter((/**
         * @param {?} r
         * @return {?}
         */
        function (r) {
            return (id.test(r.id) && name.test(r.name));
        }));
    };
    ResourceRefsPipe.decorators = [
        { type: core.Pipe, args: [{ name: 'arResourceRefs' },] },
    ];
    return ResourceRefsPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Filter a ResourceRef listing using either id or name.
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * ResourceModule provides convenience pipes for filtering lists of
 * resource references (i.e., { id: 'something', name: 'something_else'})
 */
var ResourceModule = /** @class */ (function () {
    function ResourceModule() {
    }
    ResourceModule.decorators = [
        { type: core.NgModule, args: [{
                    exports: [ResourceRefPipe, ResourceRefsPipe],
                    declarations: [ResourceRefPipe, ResourceRefsPipe]
                },] },
    ];
    return ResourceModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * System Builder directive's configuration
 * @type {?}
 */
var SYSTEM_BUILDER_CONFIG = new core.InjectionToken('ar.system-builder-config');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Checks the subsystem config to see if the ID and name are considered a match.
 * @param {?} id ID to test against
 * @param {?} name Name to test against
 * @param {?} subsys Subsystem configuration to check
 * @return {?}
 */
function subsystemMatches(id, name, subsys) {
    /** @type {?} */
    var idTest = new RegExp(subsys.id);
    /** @type {?} */
    var nameTest = new RegExp(subsys.name);
    return (idTest.test(id) && nameTest.test(name));
}
/**
 * This Directive must be instantiated once in your application where the 'provideSystemBuilderConfig' was
 * added to the providers.  This directive serves two purposes.  First, it is a nice visual queue in your
 * template that you're using the SystemBuilder.  Second, it acts as a background service for updating
 * your services.  If you need to know whether your service is up or down, observe the 'configured$'
 * member.
 */
var SystemBuilderDirective = /** @class */ (function () {
    /**
     * Constructor
     * @param injector The parent injector for finding the pre-loaded services
     * @param redhawk The REDHAWK Service for locating the entities related to the services
     * @param config The user's SystemBuilder configuration for this directive to manage
     */
    function SystemBuilderDirective(injector, redhawk, config) {
        var _this = this;
        this.injector = injector;
        this.redhawk = redhawk;
        this.config = config;
        // Listen for the domain to show up and handle it.
        redhawk.model$.subscribe((/**
         * @param {?} rh
         * @return {?}
         */
        function (rh) { return _this.checkDomains(rh); }));
    }
    /**
     * This method handles REDHAWK Model updates which indicate changes in the
     * domain listing.  If the DomainService in the config is already configured,
     * this method exits.  Otherwise, it tries to locate the specified domain
     * and configure the service.
     *
     * @param rh The REDHAWK model from the update.
     */
    /**
     * This method handles REDHAWK Model updates which indicate changes in the
     * domain listing.  If the DomainService in the config is already configured,
     * this method exits.  Otherwise, it tries to locate the specified domain
     * and configure the service.
     *
     * @param {?} rh The REDHAWK model from the update.
     * @return {?}
     */
    SystemBuilderDirective.prototype.checkDomains = /**
     * This method handles REDHAWK Model updates which indicate changes in the
     * domain listing.  If the DomainService in the config is already configured,
     * this method exits.  Otherwise, it tries to locate the specified domain
     * and configure the service.
     *
     * @param {?} rh The REDHAWK model from the update.
     * @return {?}
     */
    function (rh) {
        var _this = this;
        // Get the injected domain service.  If it's not configured, the id will
        // be undefined.
        /** @type {?} */
        var domainService = (/** @type {?} */ (this.injector.get(this.config.domain.token)));
        if (domainService.uniqueId !== undefined) {
            return; // Already configured.
        }
        // Iterate over the domain names and pull the models to check the ID and name
        // If a match is found, configure the domainService instance.
        for (var _i = 0, _a = rh.domains; _i < _a.length; _i++) {
            var domName = _a[_i];
            this.redhawk.attach$(domName).subscribe((/**
             * @param {?} d
             * @return {?}
             */
            function (d) {
                if (subsystemMatches(d.id, d.name, _this.config.domain)) {
                    domainService.uniqueId = d.name; // 'name' is not a mistake
                    domainService.model$.subscribe((/**
                     * @param {?} domain
                     * @return {?}
                     */
                    function (domain) {
                        _this.checkDeviceManagers(domain);
                        _this.checkWaveforms(domain);
                    }));
                }
            }));
        }
    };
    /**
     * This method checks the device manager configurations against the updated
     * domain model and configures the services as needed.
     * @param domain The domain model to check
     */
    /**
     * This method checks the device manager configurations against the updated
     * domain model and configures the services as needed.
     * @param {?} domain The domain model to check
     * @return {?}
     */
    SystemBuilderDirective.prototype.checkDeviceManagers = /**
     * This method checks the device manager configurations against the updated
     * domain model and configures the services as needed.
     * @param {?} domain The domain model to check
     * @return {?}
     */
    function (domain) {
        var _this = this;
        if (this.config.domain.deviceManagers) {
            var _loop_1 = function (dmConfig) {
                /** @type {?} */
                var dmService = (/** @type {?} */ (this_1.injector.get(dmConfig.token)));
                if (dmService.uniqueId !== undefined) {
                    return "continue";
                }
                else {
                    // Cross-reference it against domain's listing.
                    for (var _i = 0, _a = domain.deviceManagers; _i < _a.length; _i++) {
                        var dmRef = _a[_i];
                        if (subsystemMatches(dmRef.id, dmRef.name, dmConfig)) {
                            dmService.uniqueId = dmRef.id;
                            dmService.model$.subscribe((/**
                             * @param {?} dm
                             * @return {?}
                             */
                            function (dm) { return _this.checkDevices(dm, dmConfig); }));
                            break;
                        }
                    }
                }
            };
            var this_1 = this;
            for (var _i = 0, _a = this.config.domain.deviceManagers; _i < _a.length; _i++) {
                var dmConfig = _a[_i];
                _loop_1(dmConfig);
            }
        }
    };
    /**
     * This method checks the device configurations in the device manager's config
     * against the devices listing in the device manager model (dm).
     * @param dm The device manager model
     * @param config The device manager configuration related to this model.
     */
    /**
     * This method checks the device configurations in the device manager's config
     * against the devices listing in the device manager model (dm).
     * @param {?} dm The device manager model
     * @param {?} config The device manager configuration related to this model.
     * @return {?}
     */
    SystemBuilderDirective.prototype.checkDevices = /**
     * This method checks the device configurations in the device manager's config
     * against the devices listing in the device manager model (dm).
     * @param {?} dm The device manager model
     * @param {?} config The device manager configuration related to this model.
     * @return {?}
     */
    function (dm, config) {
        if (config.devices) {
            for (var _i = 0, _a = config.devices; _i < _a.length; _i++) {
                var devConfig = _a[_i];
                /** @type {?} */
                var deviceService = (/** @type {?} */ (this.injector.get(devConfig.token)));
                if (deviceService.uniqueId !== undefined) {
                    continue; // Skip, already configured.
                }
                else {
                    // Cross-reference the config against the devices list
                    for (var _b = 0, _c = dm.devices; _b < _c.length; _b++) {
                        var devRef = _c[_b];
                        if (subsystemMatches(devRef.id, devRef.name, devConfig)) {
                            deviceService.uniqueId = devRef.id;
                        }
                    }
                }
            }
        }
    };
    /**
     * This method checks the waveform configurations against the updated
     * domain model and configures the services as needed.
     * @param domain The domain model to check
     */
    /**
     * This method checks the waveform configurations against the updated
     * domain model and configures the services as needed.
     * @param {?} domain The domain model to check
     * @return {?}
     */
    SystemBuilderDirective.prototype.checkWaveforms = /**
     * This method checks the waveform configurations against the updated
     * domain model and configures the services as needed.
     * @param {?} domain The domain model to check
     * @return {?}
     */
    function (domain) {
        var _this = this;
        if (this.config.domain.waveforms) {
            var _loop_2 = function (waveConfig) {
                /** @type {?} */
                var waveService = (/** @type {?} */ (this_2.injector.get(waveConfig.token)));
                if (waveService.uniqueId !== undefined) {
                    return "continue";
                }
                else {
                    // Cross-reference it against the domain's listing.
                    for (var _i = 0, _a = domain.applications; _i < _a.length; _i++) {
                        var waveRef = _a[_i];
                        if (subsystemMatches(waveRef.id, waveRef.name, waveConfig)) {
                            waveService.uniqueId = waveRef.id;
                            waveService.model$.subscribe((/**
                             * @param {?} wave
                             * @return {?}
                             */
                            function (wave) { return _this.checkComponents(wave, waveConfig); }));
                        }
                    }
                }
            };
            var this_2 = this;
            for (var _i = 0, _a = this.config.domain.waveforms; _i < _a.length; _i++) {
                var waveConfig = _a[_i];
                _loop_2(waveConfig);
            }
        }
    };
    /**
     * This method checks the component configurations in the waveform's config
     * against the components listing in the waveform model (wave).
     * @param wave The waveform model
     * @param config The waveform configuration related to the model
     */
    /**
     * This method checks the component configurations in the waveform's config
     * against the components listing in the waveform model (wave).
     * @param {?} wave The waveform model
     * @param {?} config The waveform configuration related to the model
     * @return {?}
     */
    SystemBuilderDirective.prototype.checkComponents = /**
     * This method checks the component configurations in the waveform's config
     * against the components listing in the waveform model (wave).
     * @param {?} wave The waveform model
     * @param {?} config The waveform configuration related to the model
     * @return {?}
     */
    function (wave, config) {
        if (config.components) {
            for (var _i = 0, _a = config.components; _i < _a.length; _i++) {
                var compConfig = _a[_i];
                /** @type {?} */
                var compService = this.injector.get((/** @type {?} */ (compConfig.token)));
                if (compService.uniqueId !== undefined) {
                    continue; // Skip, already configured.
                }
                else {
                    // Cross-reference the config against the components list
                    for (var _b = 0, _c = wave.components; _b < _c.length; _b++) {
                        var compRef = _c[_b];
                        if (subsystemMatches(compRef.id, compRef.name, compConfig)) {
                            compService.uniqueId = compRef.id;
                        }
                    }
                }
            }
        }
    };
    SystemBuilderDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[arSystemBuilder]',
                    exportAs: 'arSystemBuilder'
                },] },
    ];
    /** @nocollapse */
    SystemBuilderDirective.ctorParameters = function () { return [
        { type: core.Injector },
        { type: RedhawkService },
        { type: undefined, decorators: [{ type: core.Inject, args: [SYSTEM_BUILDER_CONFIG,] }] }
    ]; };
    return SystemBuilderDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Device(Service) Factory returns a new instance of the DeviceService.
 * @param {?} http The Http Service
 * @param {?} restPython The RestPythonService
 * @param {?} deviceManager
 * @return {?}
 */
function deviceFactory(http$$1, restPython, deviceManager) {
    return new DeviceService(http$$1, restPython, deviceManager);
}
/**
 * Returns a provider for a device mapped to the token and device manager
 * provider specified.
 * @param {?} token InjectionToken, string or class to represent this instance
 * @param {?} deviceManager The parent DeviceManager provider
 * @return {?}
 */
function deviceProvider(token, deviceManager) {
    return {
        provide: token,
        useFactory: deviceFactory,
        deps: [http.HttpClient, RestPythonService, deviceManager]
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * DeviceManager(Service) Factory returns a new instance of the
 * DeviceManagerService.
 * @param {?} http The Http Service
 * @param {?} restPython The RestPythonService
 * @param {?} domain The DomainService
 * @return {?}
 */
function deviceManagerFactory(http$$1, restPython, domain) {
    return new DeviceManagerService(http$$1, restPython, domain);
}
/**
 * Returns a provider for a device manager mapped to the token and domain
 * provider specified.
 * @param {?} token InjectionToken, string or class to represent this instance
 * @param {?} domain The parent Domain provider
 * @return {?}
 */
function deviceManagerProvider(token, domain) {
    return {
        provide: token,
        useFactory: deviceManagerFactory,
        deps: [http.HttpClient, RestPythonService, domain]
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Domain(Service) Factory returns a new instance of the DomainService.
 * @param {?} http The Http Service
 * @param {?} restPython The RestPythonService
 * @param {?} redhawk The REDHAWK Service
 * @param {?} odm The ODM Listener Service
 * @return {?}
 */
function domainFactory(http$$1, restPython, redhawk, odm) {
    return new DomainService(http$$1, restPython, redhawk, odm);
}
/**
 * Returns a provider for a domain service mapped to the token specified.
 * @param {?} token InjectionToken, string or class to represent this instance
 * @return {?}
 */
function domainProvider(token) {
    return [
        redhawkServiceProvider(),
        odmListenerServiceProvider(),
        {
            provide: token,
            useFactory: domainFactory,
            deps: [
                http.HttpClient,
                RestPythonService,
                RedhawkService,
                OdmListenerService
            ]
        }
    ];
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * DeviceManager(Service) Factory returns a new instance of the
 * DeviceManagerService.
 * @param {?} http The Http Service
 * @param {?} restPython The RestPythonService
 * @param {?} domain The DomainService
 * @return {?}
 */
function waveformFactory(http$$1, restPython, domain) {
    return new WaveformService(http$$1, restPython, domain);
}
/**
 * Returns a provider for a waveform mapped to the token and domain
 * provider specified.
 * @param {?} token InjectionToken, string or class to represent this instance
 * @param {?} domain The parent Domain provider
 * @return {?}
 */
function waveformProvider(token, domain) {
    return {
        provide: token,
        useFactory: waveformFactory,
        deps: [http.HttpClient, RestPythonService, domain]
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Component(Service) Factory returns a new instance of the ComponentService.
 * @param {?} http The Http Service
 * @param {?} restPython The RestPythonService
 * @param {?} waveform
 * @return {?}
 */
function deviceFactory$1(http$$1, restPython, waveform) {
    return new ComponentService(http$$1, restPython, waveform);
}
/**
 * Returns a provider for a component mapped to the token and waveform
 * provider specified.
 * @param {?} token InjectionToken, string or class to represent this instance
 * @param {?} waveform The parent Waveform provider
 * @return {?}
 */
function componentProvider(token, waveform) {
    return {
        provide: token,
        useFactory: deviceFactory$1,
        deps: [http.HttpClient, RestPythonService, waveform]
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Within the component or module where you will use the arSystemBuilder
 * directive, use this function to build the set of providers for your
 * subsystems.
 *
 * @param {?} config The SystemBuilder configuration for your application.
 * @return {?}
 */
function provideSystemBuilderConfig(config) {
    /** @type {?} */
    var providers = [
        // Provide the config to the directive
        { provide: SYSTEM_BUILDER_CONFIG, useValue: config }
    ];
    // Provide the domain
    config.domain.id = config.domain.id || '.*';
    config.domain.name = config.domain.name || '.*';
    providers.push(domainProvider(config.domain.token));
    // Loop over the configuration and add the providers referencing one another.
    if (config.domain.deviceManagers) {
        for (var _i = 0, _a = config.domain.deviceManagers; _i < _a.length; _i++) {
            var node = _a[_i];
            node.id = node.id || '.*';
            node.name = node.name || '.*';
            providers.push(deviceManagerProvider(node.token, config.domain.token));
            if (node.devices) {
                for (var _b = 0, _c = node.devices; _b < _c.length; _b++) {
                    var device = _c[_b];
                    device.id = device.id || '.*';
                    device.name = device.name || '.*';
                    providers.push(deviceProvider(device.token, node.token));
                }
            }
        }
    }
    if (config.domain.waveforms) {
        for (var _d = 0, _e = config.domain.waveforms; _d < _e.length; _d++) {
            var wave = _e[_d];
            wave.id = wave.id || '.*';
            wave.name = wave.name || '.*';
            providers.push(waveformProvider(wave.token, config.domain.token));
            if (wave.components) {
                for (var _f = 0, _g = wave.components; _f < _g.length; _f++) {
                    var component = _g[_f];
                    component.id = component.id || '.*';
                    component.name = component.name || '.*';
                    providers.push(componentProvider(component.token, wave.token));
                }
            }
        }
    }
    return providers;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var REDHAWK_MODULES$1 = [
    DomainModule,
    DeviceModule,
    DeviceManagerModule,
    ComponentModule,
    WaveformModule,
    RestPythonModule,
    SocketsModule
];
/**
 * The SystemBuilder module is designed to bootstrap the dependency injection
 * system of your application to represent unique instances of subsystems in
 * the REDHAWK Domain(s) against which your application is interfacing
 */
var SystemBuilderModule = /** @class */ (function () {
    function SystemBuilderModule() {
    }
    SystemBuilderModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        http.HttpClientModule
                    ].concat(REDHAWK_MODULES$1),
                    declarations: [
                        SystemBuilderDirective
                    ],
                    exports: [
                        SystemBuilderDirective
                    ].concat(REDHAWK_MODULES$1)
                },] },
    ];
    return SystemBuilderModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// Submodules
// These have exports
/** @type {?} */
var REDHAWK_MODULES = [
    RedhawkModule,
    // Submodules
    DomainModule,
    FileSystemModule,
    WaveformModule,
    DeviceManagerModule,
    DeviceModule,
    ComponentModule,
    PortModule,
    PropertyModule,
    ResourceModule,
    SocketsModule,
    SystemBuilderModule
];
var AngularRedhawkModule = /** @class */ (function () {
    function AngularRedhawkModule() {
    }
    AngularRedhawkModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        common.CommonModule,
                        RestPythonModule
                    ].concat(REDHAWK_MODULES),
                    exports: [
                        common.CommonModule
                    ].concat(REDHAWK_MODULES)
                },] },
    ];
    return AngularRedhawkModule;
}());

exports.AngularRedhawkModule = AngularRedhawkModule;
exports.RedhawkDirective = RedhawkDirective;
exports.RedhawkService = RedhawkService;
exports.redhawkServiceProvider = redhawkServiceProvider;
exports.RedhawkModule = RedhawkModule;
exports.DomainService = DomainService;
exports.DomainDirective = DomainDirective;
exports.domainServiceProvider = domainServiceProvider;
exports.DomainModule = DomainModule;
exports.FileSystemService = FileSystemService;
exports.fileSystemServiceProvider = fileSystemServiceProvider;
exports.FileSystemModule = FileSystemModule;
exports.DeviceManagerService = DeviceManagerService;
exports.DeviceManagerDirective = DeviceManagerDirective;
exports.deviceManagerServiceProvider = deviceManagerServiceProvider;
exports.DeviceManagerModule = DeviceManagerModule;
exports.WaveformService = WaveformService;
exports.WaveformDirective = WaveformDirective;
exports.waveformServiceProvider = waveformServiceProvider;
exports.WaveformModule = WaveformModule;
exports.IWaveformControlCommand = IWaveformControlCommand;
exports.DeviceService = DeviceService;
exports.DeviceDirective = DeviceDirective;
exports.deviceServiceProvider = deviceServiceProvider;
exports.DeviceModule = DeviceModule;
exports.DevicePropertyCommand = DevicePropertyCommand;
exports.ComponentService = ComponentService;
exports.ComponentDirective = ComponentDirective;
exports.componentServiceProvider = componentServiceProvider;
exports.ComponentModule = ComponentModule;
exports.PortDirective = PortDirective;
exports.PortsPipe = PortsPipe;
exports.PortService = PortService;
exports.portServiceProvider = portServiceProvider;
exports.PortModule = PortModule;
exports.PortRef = PortRef;
exports.BulkioRef = BulkioRef;
exports.FeiRef = FeiRef;
exports.FeiRFInfoRef = FeiRFInfoRef;
exports.FeiRFSourceRef = FeiRFSourceRef;
exports.FeiGPSRef = FeiGPSRef;
exports.FeiNavDataRef = FeiNavDataRef;
exports.FeiTunerRef = FeiTunerRef;
exports.FeiAnalogTunerRef = FeiAnalogTunerRef;
exports.FeiDigitalTunerRef = FeiDigitalTunerRef;
exports.SocketsModule = SocketsModule;
exports.EventChannelModule = EventChannelModule;
exports.IdmListenerService = IdmListenerService;
exports.idmListenerServiceProvider = idmListenerServiceProvider;
exports.IdmEventModule = IdmEventModule;
exports.OdmListenerService = OdmListenerService;
exports.odmListenerServiceProvider = odmListenerServiceProvider;
exports.OdmEventModule = OdmEventModule;
exports.EventChannelService = EventChannelService;
exports.BULKIO_SOCKET_URL = BULKIO_SOCKET_URL;
exports.BulkioListenerService = BulkioListenerService;
exports.ControlType = ControlType;
exports.RedhawkListenerService = RedhawkListenerService;
exports.PropertyModule = PropertyModule;
exports.PropertiesPipe = PropertiesPipe;
exports.PropertyPipe = PropertyPipe;
exports.PropertyCommand = PropertyCommand;
exports.RestPythonService = RestPythonService;
exports.REST_PYTHON_CONFIG = REST_PYTHON_CONFIG;
exports.RestPythonModule = RestPythonModule;
exports.ResourceModule = ResourceModule;
exports.ResourceRefPipe = ResourceRefPipe;
exports.ResourceRefsPipe = ResourceRefsPipe;
exports.SystemBuilderDirective = SystemBuilderDirective;
exports.provideSystemBuilderConfig = provideSystemBuilderConfig;
exports.SystemBuilderModule = SystemBuilderModule;
exports.BulkioDataType = BulkioDataType;
exports.BulkioPacket = BulkioPacket;
exports.PrecisionUTCTime = PrecisionUTCTime;
exports.SRI = SRI;
exports.Component = Component;
exports.Device = Device;
exports.deserializeDeviceManagerRefs = deserializeDeviceManagerRefs;
exports.DeviceManager = DeviceManager;
exports.DeviceManagerRef = DeviceManagerRef;
exports.Domain = Domain;
exports.AdministrativeState = AdministrativeState;
exports.OperationalState = OperationalState;
exports.StateChangeCategory = StateChangeCategory;
exports.UsageState = UsageState;
exports.AbnormalComponentTerminationEvent = AbnormalComponentTerminationEvent;
exports.AdministrativeStateEvent = AdministrativeStateEvent;
exports.isIdmEvent = isIdmEvent;
exports.IdmEvent = IdmEvent;
exports.IdmStateEvent = IdmStateEvent;
exports.OperationalStateEvent = OperationalStateEvent;
exports.UsageStateEvent = UsageStateEvent;
exports.RhMessage = RhMessage;
exports.ResourceStateChange = ResourceStateChange;
exports.SourceCategory = SourceCategory;
exports.DomainManagementObjectEvent = DomainManagementObjectEvent;
exports.DomainManagementObjectAddedEvent = DomainManagementObjectAddedEvent;
exports.DomainManagementObjectRemovedEvent = DomainManagementObjectRemovedEvent;
exports.OdmEvent = OdmEvent;
exports.ResourceStateChangeEvent = ResourceStateChangeEvent;
exports.FileSystem = FileSystem;
exports.deserializePort = deserializePort;
exports.deserializePorts = deserializePorts;
exports.PortDirection = PortDirection;
exports.PortBulkIOIDLType = PortBulkIOIDLType;
exports.PortFEIIDLType = PortFEIIDLType;
exports.PortUnknownIDLType = PortUnknownIDLType;
exports.PortIDLNameSpace = PortIDLNameSpace;
exports.Port = Port;
exports.PortIDL = PortIDL;
exports.Property = Property;
exports.deserializeProperties = deserializeProperties;
exports.SimpleProperty = SimpleProperty;
exports.SimpleSeqProperty = SimpleSeqProperty;
exports.StructProperty = StructProperty;
exports.StructSeqProperty = StructSeqProperty;
exports.Redhawk = Redhawk;
exports.RedhawkEvent = RedhawkEvent;
exports.deserializeResourceRefs = deserializeResourceRefs;
exports.ResourceRef = ResourceRef;
exports.Resource = Resource;
exports.Waveform = Waveform;
exports.WaveformSAD = WaveformSAD;
exports.deserializeWaveformSADRefs = deserializeWaveformSADRefs;
exports.BaseService = BaseService;
exports.PortBearingService = PortBearingService;

Object.defineProperty(exports, '__esModule', { value: true });

})));
